@@ -24,10 +24,11 @@
 namespace std {};
 using namespace std;
 
-#if defined(__cplusplus) && __cplusplus < 201103
+#if !defined(TARGET_COMPILER_VC) && defined(__cplusplus) && __cplusplus < 201103
 # define unique_ptr auto_ptr
 template<typename T>
 static inline T move(T x) { return x; } // good enough for our purposes
+# include <cstddef>
 # define nullptr NULL
 #endif
 
@@ -39,6 +40,19 @@ static inline T move(T x) { return x; } // good enough for our purposes
 #pragma warning (disable: 4290 4267)
 /* Don't define min and max as macros, define them via STL */
 #define NOMINMAX
+#define ENUM_INT64 : unsigned long long
+#else
+#define ENUM_INT64
+#endif
+
+#ifdef __sun
+// Solaris libc has ambiguous overloads for float, double, long float, so
+// we need to upgrade ints explicitly:
+#include <math.h>
+static inline double sqrt(int x) { return sqrt((double)x); }
+static inline double atan2(int x, int y) { return atan2((double)x, (double)y); }
+static inline double pow(int x, int y) { return std::pow((double)x, y); }
+static inline double pow(int x, double y) { return std::pow((double)x, y); }
 #endif
 
 // The maximum memory that the user-script Lua interpreter can
@@ -407,6 +421,7 @@ static inline void UNUSED(const volatile T &)
 # include "msvc.h"
 #endif
 
+#include "debug.h"
 #include "externs.h"
 
 #ifdef TARGET_COMPILER_VC
