@@ -30,7 +30,7 @@ bool player::see_cell(const coord_def &p) const
     if (!in_bounds(pos()))
         return false; // A non-arena player at (0,0) can't see anything.
     if (xray_vision)
-        return ((pos() - p).abs() <= dist_range(you.current_vision));
+        return ((pos() - p).abs() <= dist_range(current_vision));
     return actor::see_cell(p);
 }
 
@@ -67,7 +67,7 @@ const los_base* player::get_los()
     else if (xray_vision)
     {
         los = los_glob(pos(), LOS_ARENA,
-                       circle_def(you.current_vision, C_ROUND));
+                       circle_def(current_vision, C_ROUND));
         return &los;
     }
     else
