@@ -27,9 +27,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_HUMAN,           SK_ARMOUR,          0),
     APT(SP_HUMAN,           SK_DODGING,         0),
     APT(SP_HUMAN,           SK_STEALTH,         1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HUMAN,           SK_STABBING,        0),
+#endif
     APT(SP_HUMAN,           SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HUMAN,           SK_TRAPS,           0),
+#endif
     APT(SP_HUMAN,           SK_UNARMED_COMBAT,  0),
     APT(SP_HUMAN,           SK_SPELLCASTING,   -1),
     APT(SP_HUMAN,           SK_CONJURATIONS,    0),
@@ -62,9 +66,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_HIGH_ELF,        SK_ARMOUR,         -1),
     APT(SP_HIGH_ELF,        SK_DODGING,         1),
     APT(SP_HIGH_ELF,        SK_STEALTH,         2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HIGH_ELF,        SK_STABBING,       -1),
+#endif
     APT(SP_HIGH_ELF,        SK_SHIELDS,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HIGH_ELF,        SK_TRAPS,           0),
+#endif
     APT(SP_HIGH_ELF,        SK_UNARMED_COMBAT, -2),
     APT(SP_HIGH_ELF,        SK_SPELLCASTING,    1),
     APT(SP_HIGH_ELF,        SK_CONJURATIONS,    1),
@@ -97,9 +105,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_DEEP_ELF,        SK_ARMOUR,         -2),
     APT(SP_DEEP_ELF,        SK_DODGING,         2),
     APT(SP_DEEP_ELF,        SK_STEALTH,         3),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEEP_ELF,        SK_STABBING,        1),
+#endif
     APT(SP_DEEP_ELF,        SK_SHIELDS,        -2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEEP_ELF,        SK_TRAPS,           0),
+#endif
     APT(SP_DEEP_ELF,        SK_UNARMED_COMBAT, -2),
     APT(SP_DEEP_ELF,        SK_SPELLCASTING,    3),
     APT(SP_DEEP_ELF,        SK_CONJURATIONS,    1),
@@ -132,9 +144,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_SLUDGE_ELF,      SK_ARMOUR,         -2),
     APT(SP_SLUDGE_ELF,      SK_DODGING,         2),
     APT(SP_SLUDGE_ELF,      SK_STEALTH,         2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_SLUDGE_ELF,      SK_STABBING,        0),
+#endif
     APT(SP_SLUDGE_ELF,      SK_SHIELDS,        -2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_SLUDGE_ELF,      SK_TRAPS,           0),
+#endif
     APT(SP_SLUDGE_ELF,      SK_UNARMED_COMBAT,  1),
     APT(SP_SLUDGE_ELF,      SK_SPELLCASTING,    1),
     APT(SP_SLUDGE_ELF,      SK_CONJURATIONS,   -2),
@@ -167,9 +183,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_HALFLING,        SK_ARMOUR,         -2),
     APT(SP_HALFLING,        SK_DODGING,         2),
     APT(SP_HALFLING,        SK_STEALTH,         4),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HALFLING,        SK_STABBING,        0),
+#endif
     APT(SP_HALFLING,        SK_SHIELDS,         1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HALFLING,        SK_TRAPS,           0),
+#endif
     APT(SP_HALFLING,        SK_UNARMED_COMBAT, -2),
     APT(SP_HALFLING,        SK_SPELLCASTING,   -3),
     APT(SP_HALFLING,        SK_CONJURATIONS,   -2),
@@ -202,9 +222,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_HILL_ORC,        SK_ARMOUR,          1),
     APT(SP_HILL_ORC,        SK_DODGING,        -2),
     APT(SP_HILL_ORC,        SK_STEALTH,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HILL_ORC,        SK_STABBING,        2),
+#endif
     APT(SP_HILL_ORC,        SK_SHIELDS,         1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_HILL_ORC,        SK_TRAPS,           0),
+#endif
     APT(SP_HILL_ORC,        SK_UNARMED_COMBAT,  1),
     APT(SP_HILL_ORC,        SK_SPELLCASTING,   -3),
     APT(SP_HILL_ORC,        SK_CONJURATIONS,    0),
@@ -237,9 +261,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_KOBOLD,          SK_ARMOUR,         -2),
     APT(SP_KOBOLD,          SK_DODGING,         2),
     APT(SP_KOBOLD,          SK_STEALTH,         4),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_KOBOLD,          SK_STABBING,        2),
+#endif
     APT(SP_KOBOLD,          SK_SHIELDS,        -2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_KOBOLD,          SK_TRAPS,           0),
+#endif
     APT(SP_KOBOLD,          SK_UNARMED_COMBAT,  0),
     APT(SP_KOBOLD,          SK_SPELLCASTING,   -1),
     APT(SP_KOBOLD,          SK_CONJURATIONS,   -1),
@@ -272,9 +300,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_MUMMY,           SK_ARMOUR,         -2),
     APT(SP_MUMMY,           SK_DODGING,        -2),
     APT(SP_MUMMY,           SK_STEALTH,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MUMMY,           SK_STABBING,       -2),
+#endif
     APT(SP_MUMMY,           SK_SHIELDS,        -2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MUMMY,           SK_TRAPS,          -2),
+#endif
     APT(SP_MUMMY,           SK_UNARMED_COMBAT, -2),
     APT(SP_MUMMY,           SK_SPELLCASTING,   -1),
     APT(SP_MUMMY,           SK_CONJURATIONS,   -2),
@@ -307,9 +339,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_NAGA,            SK_ARMOUR,         -2),
     APT(SP_NAGA,            SK_DODGING,        -2),
     APT(SP_NAGA,            SK_STEALTH,         5),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_NAGA,            SK_STABBING,        0),
+#endif
     APT(SP_NAGA,            SK_SHIELDS,        -2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_NAGA,            SK_TRAPS,           0),
+#endif
     APT(SP_NAGA,            SK_UNARMED_COMBAT,  0),
     APT(SP_NAGA,            SK_SPELLCASTING,   -1),
     APT(SP_NAGA,            SK_CONJURATIONS,    0),
@@ -342,9 +378,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_OGRE,            SK_ARMOUR,         -2),
     APT(SP_OGRE,            SK_DODGING,        -1),
     APT(SP_OGRE,            SK_STEALTH,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_OGRE,            SK_STABBING,       -2),
+#endif
     APT(SP_OGRE,            SK_SHIELDS,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_OGRE,            SK_TRAPS,          -2),
+#endif
     APT(SP_OGRE,            SK_UNARMED_COMBAT, -1),
     APT(SP_OGRE,            SK_SPELLCASTING,    1),
     APT(SP_OGRE,            SK_CONJURATIONS,   -3),
@@ -377,9 +417,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_TROLL,           SK_ARMOUR,         -2),
     APT(SP_TROLL,           SK_DODGING,        -2),
     APT(SP_TROLL,           SK_STEALTH,        -4),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_TROLL,           SK_STABBING,       -2),
+#endif
     APT(SP_TROLL,           SK_SHIELDS,        -2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_TROLL,           SK_TRAPS,          -4),
+#endif
     APT(SP_TROLL,           SK_UNARMED_COMBAT,  0),
     APT(SP_TROLL,           SK_SPELLCASTING,   -5),
     APT(SP_TROLL,           SK_CONJURATIONS,   -3),
@@ -412,9 +456,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_RED_DRACONIAN,   SK_ARMOUR,        -99),
     APT(SP_RED_DRACONIAN,   SK_DODGING,        -1),
     APT(SP_RED_DRACONIAN,   SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_RED_DRACONIAN,   SK_STABBING,        0),
+#endif
     APT(SP_RED_DRACONIAN,   SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_RED_DRACONIAN,   SK_TRAPS,           0),
+#endif
     APT(SP_RED_DRACONIAN,   SK_UNARMED_COMBAT,  0),
     APT(SP_RED_DRACONIAN,   SK_SPELLCASTING,   -1),
     APT(SP_RED_DRACONIAN,   SK_CONJURATIONS,    0),
@@ -447,9 +495,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_WHITE_DRACONIAN, SK_ARMOUR,        -99),
     APT(SP_WHITE_DRACONIAN, SK_DODGING,        -1),
     APT(SP_WHITE_DRACONIAN, SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_WHITE_DRACONIAN, SK_STABBING,        0),
+#endif
     APT(SP_WHITE_DRACONIAN, SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_WHITE_DRACONIAN, SK_TRAPS,           0),
+#endif
     APT(SP_WHITE_DRACONIAN, SK_UNARMED_COMBAT,  0),
     APT(SP_WHITE_DRACONIAN, SK_SPELLCASTING,   -1),
     APT(SP_WHITE_DRACONIAN, SK_CONJURATIONS,    0),
@@ -482,9 +534,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_GREEN_DRACONIAN, SK_ARMOUR,        -99),
     APT(SP_GREEN_DRACONIAN, SK_DODGING,        -1),
     APT(SP_GREEN_DRACONIAN, SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_GREEN_DRACONIAN, SK_STABBING,        0),
+#endif
     APT(SP_GREEN_DRACONIAN, SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_GREEN_DRACONIAN, SK_TRAPS,           0),
+#endif
     APT(SP_GREEN_DRACONIAN, SK_UNARMED_COMBAT,  0),
     APT(SP_GREEN_DRACONIAN, SK_SPELLCASTING,   -1),
     APT(SP_GREEN_DRACONIAN, SK_CONJURATIONS,    0),
@@ -517,9 +573,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_YELLOW_DRACONIAN,SK_ARMOUR,        -99),
     APT(SP_YELLOW_DRACONIAN,SK_DODGING,        -1),
     APT(SP_YELLOW_DRACONIAN,SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_YELLOW_DRACONIAN,SK_STABBING,        0),
+#endif
     APT(SP_YELLOW_DRACONIAN,SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_YELLOW_DRACONIAN,SK_TRAPS,           0),
+#endif
     APT(SP_YELLOW_DRACONIAN,SK_UNARMED_COMBAT,  0),
     APT(SP_YELLOW_DRACONIAN,SK_SPELLCASTING,   -1),
     APT(SP_YELLOW_DRACONIAN,SK_CONJURATIONS,    0),
@@ -552,9 +612,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_GREY_DRACONIAN,  SK_ARMOUR,        -99),
     APT(SP_GREY_DRACONIAN,  SK_DODGING,        -1),
     APT(SP_GREY_DRACONIAN,  SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_GREY_DRACONIAN,  SK_STABBING,        0),
+#endif
     APT(SP_GREY_DRACONIAN,  SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_GREY_DRACONIAN,  SK_TRAPS,           0),
+#endif
     APT(SP_GREY_DRACONIAN,  SK_UNARMED_COMBAT,  0),
     APT(SP_GREY_DRACONIAN,  SK_SPELLCASTING,   -1),
     APT(SP_GREY_DRACONIAN,  SK_CONJURATIONS,    0),
@@ -587,9 +651,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_BLACK_DRACONIAN, SK_ARMOUR,        -99),
     APT(SP_BLACK_DRACONIAN, SK_DODGING,        -1),
     APT(SP_BLACK_DRACONIAN, SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_BLACK_DRACONIAN, SK_STABBING,        0),
+#endif
     APT(SP_BLACK_DRACONIAN, SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_BLACK_DRACONIAN, SK_TRAPS,           0),
+#endif
     APT(SP_BLACK_DRACONIAN, SK_UNARMED_COMBAT,  0),
     APT(SP_BLACK_DRACONIAN, SK_SPELLCASTING,   -1),
     APT(SP_BLACK_DRACONIAN, SK_CONJURATIONS,    0),
@@ -622,9 +690,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_PURPLE_DRACONIAN,SK_ARMOUR,        -99),
     APT(SP_PURPLE_DRACONIAN,SK_DODGING,        -1),
     APT(SP_PURPLE_DRACONIAN,SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_PURPLE_DRACONIAN,SK_STABBING,        0),
+#endif
     APT(SP_PURPLE_DRACONIAN,SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_PURPLE_DRACONIAN,SK_TRAPS,           0),
+#endif
     APT(SP_PURPLE_DRACONIAN,SK_UNARMED_COMBAT,  0),
     APT(SP_PURPLE_DRACONIAN,SK_SPELLCASTING,    1),
     APT(SP_PURPLE_DRACONIAN,SK_CONJURATIONS,    0),
@@ -657,9 +729,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_MOTTLED_DRACONIAN,SK_ARMOUR,        -99),
     APT(SP_MOTTLED_DRACONIAN,SK_DODGING,        -1),
     APT(SP_MOTTLED_DRACONIAN,SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MOTTLED_DRACONIAN,SK_STABBING,        0),
+#endif
     APT(SP_MOTTLED_DRACONIAN,SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MOTTLED_DRACONIAN,SK_TRAPS,           0),
+#endif
     APT(SP_MOTTLED_DRACONIAN,SK_UNARMED_COMBAT,  0),
     APT(SP_MOTTLED_DRACONIAN,SK_SPELLCASTING,   -1),
     APT(SP_MOTTLED_DRACONIAN,SK_CONJURATIONS,    0),
@@ -692,9 +768,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_PALE_DRACONIAN,  SK_ARMOUR,        -99),
     APT(SP_PALE_DRACONIAN,  SK_DODGING,        -1),
     APT(SP_PALE_DRACONIAN,  SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_PALE_DRACONIAN,  SK_STABBING,        0),
+#endif
     APT(SP_PALE_DRACONIAN,  SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_PALE_DRACONIAN,  SK_TRAPS,           0),
+#endif
     APT(SP_PALE_DRACONIAN,  SK_UNARMED_COMBAT,  0),
     APT(SP_PALE_DRACONIAN,  SK_SPELLCASTING,   -1),
     APT(SP_PALE_DRACONIAN,  SK_CONJURATIONS,    0),
@@ -727,9 +807,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_BASE_DRACONIAN,  SK_ARMOUR,        -99),
     APT(SP_BASE_DRACONIAN,  SK_DODGING,        -1),
     APT(SP_BASE_DRACONIAN,  SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_BASE_DRACONIAN,  SK_STABBING,        0),
+#endif
     APT(SP_BASE_DRACONIAN,  SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_BASE_DRACONIAN,  SK_TRAPS,           0),
+#endif
     APT(SP_BASE_DRACONIAN,  SK_UNARMED_COMBAT,  0),
     APT(SP_BASE_DRACONIAN,  SK_SPELLCASTING,   -1),
     APT(SP_BASE_DRACONIAN,  SK_CONJURATIONS,    0),
@@ -762,9 +846,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_CENTAUR,         SK_ARMOUR,         -3),
     APT(SP_CENTAUR,         SK_DODGING,        -3),
     APT(SP_CENTAUR,         SK_STEALTH,        -3),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_CENTAUR,         SK_STABBING,       -3),
+#endif
     APT(SP_CENTAUR,         SK_SHIELDS,        -3),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_CENTAUR,         SK_TRAPS,          -2),
+#endif
     APT(SP_CENTAUR,         SK_UNARMED_COMBAT,  0),
     APT(SP_CENTAUR,         SK_SPELLCASTING,   -3),
     APT(SP_CENTAUR,         SK_CONJURATIONS,   -1),
@@ -797,9 +885,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_DEMIGOD,         SK_ARMOUR,         -1),
     APT(SP_DEMIGOD,         SK_DODGING,        -1),
     APT(SP_DEMIGOD,         SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEMIGOD,         SK_STABBING,       -1),
+#endif
     APT(SP_DEMIGOD,         SK_SHIELDS,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEMIGOD,         SK_TRAPS,          -1),
+#endif
     APT(SP_DEMIGOD,         SK_UNARMED_COMBAT, -1),
     APT(SP_DEMIGOD,         SK_SPELLCASTING,   -2),
     APT(SP_DEMIGOD,         SK_CONJURATIONS,   -1),
@@ -832,9 +924,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_SPRIGGAN,        SK_ARMOUR,         -3),
     APT(SP_SPRIGGAN,        SK_DODGING,         4),
     APT(SP_SPRIGGAN,        SK_STEALTH,         5),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_SPRIGGAN,        SK_STABBING,        4),
+#endif
     APT(SP_SPRIGGAN,        SK_SHIELDS,        -3),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_SPRIGGAN,        SK_TRAPS,           3),
+#endif
     APT(SP_SPRIGGAN,        SK_UNARMED_COMBAT, -2),
     APT(SP_SPRIGGAN,        SK_SPELLCASTING,    2),
     APT(SP_SPRIGGAN,        SK_CONJURATIONS,   -3),
@@ -867,9 +963,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_MINOTAUR,        SK_ARMOUR,          2),
     APT(SP_MINOTAUR,        SK_DODGING,         1),
     APT(SP_MINOTAUR,        SK_STEALTH,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MINOTAUR,        SK_STABBING,       -1),
+#endif
     APT(SP_MINOTAUR,        SK_SHIELDS,         2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MINOTAUR,        SK_TRAPS,           0),
+#endif
     APT(SP_MINOTAUR,        SK_UNARMED_COMBAT,  1),
     APT(SP_MINOTAUR,        SK_SPELLCASTING,   -4),
     APT(SP_MINOTAUR,        SK_CONJURATIONS,   -3),
@@ -887,6 +987,45 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_MINOTAUR,        SK_INVOCATIONS,     0),
     APT(SP_MINOTAUR,        SK_EVOCATIONS,      0),
 
+    // SP_GARGOYLE
+    APT(SP_GARGOYLE,         SK_FIGHTING,        1),
+    APT(SP_GARGOYLE,         SK_SHORT_BLADES,   -1),
+    APT(SP_GARGOYLE,         SK_LONG_BLADES,    -1),
+    APT(SP_GARGOYLE,         SK_AXES,           -1),
+    APT(SP_GARGOYLE,         SK_MACES_FLAILS,    1),
+    APT(SP_GARGOYLE,         SK_POLEARMS,       -1),
+    APT(SP_GARGOYLE,         SK_STAVES,          1),
+    APT(SP_GARGOYLE,         SK_SLINGS,         -1),
+    APT(SP_GARGOYLE,         SK_BOWS,            0),
+    APT(SP_GARGOYLE,         SK_CROSSBOWS,       0),
+    APT(SP_GARGOYLE,         SK_THROWING,        0),
+    APT(SP_GARGOYLE,         SK_ARMOUR,          1),
+    APT(SP_GARGOYLE,         SK_DODGING,        -2),
+    APT(SP_GARGOYLE,         SK_STEALTH,         2),
+#if TAG_MAJOR_VERSION == 34
+    APT(SP_GARGOYLE,         SK_STABBING,        0),
+#endif
+    APT(SP_GARGOYLE,         SK_SHIELDS,         1),
+#if TAG_MAJOR_VERSION == 34
+    APT(SP_GARGOYLE,         SK_TRAPS,          -1),
+#endif
+    APT(SP_GARGOYLE,         SK_UNARMED_COMBAT,  1),
+    APT(SP_GARGOYLE,         SK_SPELLCASTING,   -1),
+    APT(SP_GARGOYLE,         SK_CONJURATIONS,    1),
+    APT(SP_GARGOYLE,         SK_HEXES,          -1),
+    APT(SP_GARGOYLE,         SK_CHARMS,         -1),
+    APT(SP_GARGOYLE,         SK_SUMMONINGS,     -1),
+    APT(SP_GARGOYLE,         SK_NECROMANCY,     -2),
+    APT(SP_GARGOYLE,         SK_TRANSLOCATIONS, -1),
+    APT(SP_GARGOYLE,         SK_TRANSMUTATIONS, -2),
+    APT(SP_GARGOYLE,         SK_FIRE_MAGIC,      0),
+    APT(SP_GARGOYLE,         SK_ICE_MAGIC,       0),
+    APT(SP_GARGOYLE,         SK_AIR_MAGIC,      -2),
+    APT(SP_GARGOYLE,         SK_EARTH_MAGIC,     2),
+    APT(SP_GARGOYLE,         SK_POISON_MAGIC,    0),
+    APT(SP_GARGOYLE,         SK_INVOCATIONS,     1),
+    APT(SP_GARGOYLE,         SK_EVOCATIONS,      0),
+
     // SP_DEMONSPAWN
     APT(SP_DEMONSPAWN,      SK_FIGHTING,        0),
     APT(SP_DEMONSPAWN,      SK_SHORT_BLADES,   -1),
@@ -902,9 +1041,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_DEMONSPAWN,      SK_ARMOUR,         -1),
     APT(SP_DEMONSPAWN,      SK_DODGING,        -1),
     APT(SP_DEMONSPAWN,      SK_STEALTH,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEMONSPAWN,      SK_STABBING,       -1),
+#endif
     APT(SP_DEMONSPAWN,      SK_SHIELDS,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEMONSPAWN,      SK_TRAPS,          -1),
+#endif
     APT(SP_DEMONSPAWN,      SK_UNARMED_COMBAT, -1),
     APT(SP_DEMONSPAWN,      SK_SPELLCASTING,   -1),
     APT(SP_DEMONSPAWN,      SK_CONJURATIONS,    0),
@@ -937,9 +1080,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_GHOUL,           SK_ARMOUR,         -1),
     APT(SP_GHOUL,           SK_DODGING,        -1),
     APT(SP_GHOUL,           SK_STEALTH,         2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_GHOUL,           SK_STABBING,        0),
+#endif
     APT(SP_GHOUL,           SK_SHIELDS,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_GHOUL,           SK_TRAPS,          -1),
+#endif
     APT(SP_GHOUL,           SK_UNARMED_COMBAT,  1),
     APT(SP_GHOUL,           SK_SPELLCASTING,   -2),
     APT(SP_GHOUL,           SK_CONJURATIONS,   -2),
@@ -972,9 +1119,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_TENGU,           SK_ARMOUR,          1),
     APT(SP_TENGU,           SK_DODGING,         1),
     APT(SP_TENGU,           SK_STEALTH,         1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_TENGU,           SK_STABBING,        1),
+#endif
     APT(SP_TENGU,           SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_TENGU,           SK_TRAPS,           0),
+#endif
     APT(SP_TENGU,           SK_UNARMED_COMBAT,  1),
     APT(SP_TENGU,           SK_SPELLCASTING,   -1),
     APT(SP_TENGU,           SK_CONJURATIONS,    3),
@@ -1007,9 +1158,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_MERFOLK,         SK_ARMOUR,         -3),
     APT(SP_MERFOLK,         SK_DODGING,         3),
     APT(SP_MERFOLK,         SK_STEALTH,         2),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MERFOLK,         SK_STABBING,        2),
+#endif
     APT(SP_MERFOLK,         SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_MERFOLK,         SK_TRAPS,          -1),
+#endif
     APT(SP_MERFOLK,         SK_UNARMED_COMBAT,  1),
     APT(SP_MERFOLK,         SK_SPELLCASTING,   -1),
     APT(SP_MERFOLK,         SK_CONJURATIONS,   -2),
@@ -1042,9 +1197,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_VAMPIRE,         SK_ARMOUR,         -2),
     APT(SP_VAMPIRE,         SK_DODGING,         1),
     APT(SP_VAMPIRE,         SK_STEALTH,         5),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_VAMPIRE,         SK_STABBING,        1),
+#endif
     APT(SP_VAMPIRE,         SK_SHIELDS,        -1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_VAMPIRE,         SK_TRAPS,           0),
+#endif
     APT(SP_VAMPIRE,         SK_UNARMED_COMBAT,  1),
     APT(SP_VAMPIRE,         SK_SPELLCASTING,   -1),
     APT(SP_VAMPIRE,         SK_CONJURATIONS,   -3),
@@ -1077,9 +1236,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_DEEP_DWARF,      SK_ARMOUR,          1),
     APT(SP_DEEP_DWARF,      SK_DODGING,         1),
     APT(SP_DEEP_DWARF,      SK_STEALTH,         3),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEEP_DWARF,      SK_STABBING,       -1),
+#endif
     APT(SP_DEEP_DWARF,      SK_SHIELDS,         1),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_DEEP_DWARF,      SK_TRAPS,           1),
+#endif
     APT(SP_DEEP_DWARF,      SK_UNARMED_COMBAT, -1),
     APT(SP_DEEP_DWARF,      SK_SPELLCASTING,   -2),
     APT(SP_DEEP_DWARF,      SK_CONJURATIONS,   -1),
@@ -1112,9 +1275,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_FELID,           SK_ARMOUR,        -99),
     APT(SP_FELID,           SK_DODGING,         3),
     APT(SP_FELID,           SK_STEALTH,         4),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_FELID,           SK_STABBING,        3),
+#endif
     APT(SP_FELID,           SK_SHIELDS,       -99),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_FELID,           SK_TRAPS,           2),
+#endif
     APT(SP_FELID,           SK_UNARMED_COMBAT,  0),
     APT(SP_FELID,           SK_SPELLCASTING,   -1),
     APT(SP_FELID,           SK_CONJURATIONS,   -1),
@@ -1147,9 +1314,13 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_OCTOPODE,        SK_ARMOUR,        -99),
     APT(SP_OCTOPODE,        SK_DODGING,         0),
     APT(SP_OCTOPODE,        SK_STEALTH,         4),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_OCTOPODE,        SK_STABBING,        0),
+#endif
     APT(SP_OCTOPODE,        SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
     APT(SP_OCTOPODE,        SK_TRAPS,           1),
+#endif
     APT(SP_OCTOPODE,        SK_UNARMED_COMBAT,  0),
     APT(SP_OCTOPODE,        SK_SPELLCASTING,   -1),
     APT(SP_OCTOPODE,        SK_CONJURATIONS,    0),
@@ -1166,6 +1337,81 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_OCTOPODE,        SK_POISON_MAGIC,    2),
     APT(SP_OCTOPODE,        SK_INVOCATIONS,     1),
     APT(SP_OCTOPODE,        SK_EVOCATIONS,      2),
+
+    // SP_DJINNI
+    APT(SP_DJINNI,          SK_FIGHTING,       -1),
+    APT(SP_DJINNI,          SK_SHORT_BLADES,   -2),
+    APT(SP_DJINNI,          SK_LONG_BLADES,     0),
+    APT(SP_DJINNI,          SK_AXES,           -1),
+    APT(SP_DJINNI,          SK_MACES_FLAILS,    0),
+    APT(SP_DJINNI,          SK_POLEARMS,        0),
+    APT(SP_DJINNI,          SK_STAVES,          0),
+    APT(SP_DJINNI,          SK_SLINGS,         -1),
+    APT(SP_DJINNI,          SK_BOWS,           -1),
+    APT(SP_DJINNI,          SK_CROSSBOWS,       0),
+    APT(SP_DJINNI,          SK_THROWING,       -1),
+    APT(SP_DJINNI,          SK_ARMOUR,          1),
+    APT(SP_DJINNI,          SK_DODGING,        -1),
+    APT(SP_DJINNI,          SK_STEALTH,        -1),
+    APT(SP_DJINNI,          SK_SHIELDS,         0),
+#if TAG_MAJOR_VERSION == 34
+    APT(SP_DJINNI,          SK_TRAPS,          -1),
+#endif
+    APT(SP_DJINNI,          SK_UNARMED_COMBAT, -1),
+    APT(SP_DJINNI,          SK_SPELLCASTING,    1),
+    APT(SP_DJINNI,          SK_CONJURATIONS,    1),
+    APT(SP_DJINNI,          SK_HEXES,           2),
+    APT(SP_DJINNI,          SK_CHARMS,          0),
+    APT(SP_DJINNI,          SK_SUMMONINGS,      0),
+    APT(SP_DJINNI,          SK_NECROMANCY,     -2),
+    APT(SP_DJINNI,          SK_TRANSLOCATIONS,  0),
+    APT(SP_DJINNI,          SK_TRANSMUTATIONS,  0),
+    APT(SP_DJINNI,          SK_FIRE_MAGIC,      3),
+    APT(SP_DJINNI,          SK_ICE_MAGIC,      -3),
+    APT(SP_DJINNI,          SK_AIR_MAGIC,       2),
+    APT(SP_DJINNI,          SK_EARTH_MAGIC,    -3),
+    APT(SP_DJINNI,          SK_POISON_MAGIC,   -1),
+    APT(SP_DJINNI,          SK_INVOCATIONS,     1),
+    APT(SP_DJINNI,          SK_EVOCATIONS,      2),
+
+    // SP_LAVA_ORC
+    APT(SP_LAVA_ORC,        SK_FIGHTING,        2),
+    APT(SP_LAVA_ORC,        SK_SHORT_BLADES,    0),
+    APT(SP_LAVA_ORC,        SK_LONG_BLADES,     1),
+    APT(SP_LAVA_ORC,        SK_AXES,            2),
+    APT(SP_LAVA_ORC,        SK_MACES_FLAILS,    1),
+    APT(SP_LAVA_ORC,        SK_POLEARMS,        1),
+    APT(SP_LAVA_ORC,        SK_STAVES,         -1),
+    APT(SP_LAVA_ORC,        SK_SLINGS,         -2),
+    APT(SP_LAVA_ORC,        SK_BOWS,           -2),
+    APT(SP_LAVA_ORC,        SK_CROSSBOWS,      -2),
+    APT(SP_LAVA_ORC,        SK_THROWING,       -1),
+    APT(SP_LAVA_ORC,        SK_ARMOUR,          1),
+    APT(SP_LAVA_ORC,        SK_DODGING,        -2),
+    APT(SP_LAVA_ORC,        SK_STEALTH,        -1),
+#if TAG_MAJOR_VERSION == 34
+    APT(SP_LAVA_ORC,        SK_STABBING,        2),
+#endif
+    APT(SP_LAVA_ORC,        SK_SHIELDS,         1),
+#if TAG_MAJOR_VERSION == 34
+    APT(SP_LAVA_ORC,        SK_TRAPS,           0),
+#endif
+    APT(SP_LAVA_ORC,        SK_UNARMED_COMBAT,  1),
+    APT(SP_LAVA_ORC,        SK_SPELLCASTING,   -3),
+    APT(SP_LAVA_ORC,        SK_CONJURATIONS,    0),
+    APT(SP_LAVA_ORC,        SK_HEXES,           0),
+    APT(SP_LAVA_ORC,        SK_CHARMS,         -1),
+    APT(SP_LAVA_ORC,        SK_SUMMONINGS,      0),
+    APT(SP_LAVA_ORC,        SK_NECROMANCY,      0),
+    APT(SP_LAVA_ORC,        SK_TRANSLOCATIONS, -2),
+    APT(SP_LAVA_ORC,        SK_TRANSMUTATIONS,  3),
+    APT(SP_LAVA_ORC,        SK_FIRE_MAGIC,      2),
+    APT(SP_LAVA_ORC,        SK_ICE_MAGIC,      -4),
+    APT(SP_LAVA_ORC,        SK_AIR_MAGIC,      -3),
+    APT(SP_LAVA_ORC,        SK_EARTH_MAGIC,     1),
+    APT(SP_LAVA_ORC,        SK_POISON_MAGIC,   -1),
+    APT(SP_LAVA_ORC,        SK_INVOCATIONS,     3),
+    APT(SP_LAVA_ORC,        SK_EVOCATIONS,      1),
 };
 
 #endif
