@@ -17,6 +17,7 @@
 #include "env.h"
 #include "fprop.h"
 #include "libutil.h"
+#include "losglobal.h"
 #include "mon-behv.h"
 #include "mon-iter.h"
 #include "mon-stuff.h"
@@ -43,6 +44,8 @@ enum areaprop_flag
     APROP_SUPPRESSION   = (1 << 8),
     APROP_QUAD          = (1 << 9),
     APROP_DISJUNCTION   = (1 << 10),
+    APROP_SOUL_AURA     = (1 << 11),
+    APROP_HOT           = (1 << 12),
 };
 
 struct area_centre
@@ -54,7 +57,6 @@ struct area_centre
     explicit area_centre (area_centre_type t, coord_def c, int r) : type(t), centre(c), radius(r) { }
 };
 
-// currently, only 4 of 32 bits are used, but meh...
 typedef FixedArray<uint32_t, GXM, GYM> propgrid_t;
 
 static vector<area_centre> _agrid_centres;
@@ -86,7 +88,8 @@ void areas_actor_moved(const actor* act, const coord_def& oldpos)
         (you.entering_level
          || act->halo_radius2() > -1 || act->silence_radius2() > -1
          || act->liquefying_radius2() > -1 || act->umbra_radius2() > -1
-         || act->suppression_radius2() > -1))
+         || act->suppression_radius2() > -1 || act->heat_radius2() > -1)
+         || act->soul_aura_radius2() > -1)
     {
         // Not necessarily new, but certainly potentially interesting.
         invalidate_agrid(true);
@@ -170,6 +173,30 @@ static void _update_agrid()
             no_areas = false;
         }
 
+
+        if ((r = ai->soul_aura_radius2()) >= 0)
+        {
+            _agrid_centres.push_back(area_centre(AREA_SOUL_AURA, ai->pos(), r));
+
+            for (radius_iterator ri(ai->pos(), r, C_CIRCLE, ai->get_los());
+                 ri; ++ri)
+            {
+                _set_agrid_flag(*ri, APROP_SOUL_AURA);
+            }
+            no_areas = false;
+        }
+
+        if ((r = ai->heat_radius2()) >= 0)
+        {
+            _agrid_centres.push_back(area_centre(AREA_HOT, ai->pos(), r));
+
+            for (radius_iterator ri(ai->pos(),r, C_CIRCLE, ai->get_los());
+                ri; ++ri)
+            {
+                _set_agrid_flag(*ri, APROP_HOT);
+            }
+            no_areas = false;
+        }
     }
 
     if (you.char_direction == GDT_ASCENDING && !you.pos().origin())
@@ -191,10 +218,11 @@ static void _update_agrid()
     {
         const int r = 5;
         _agrid_centres.push_back(area_centre(AREA_QUAD, you.pos(), r));
-        for (radius_iterator ri(you.pos(), r, C_CIRCLE, you.get_los());
+        for (radius_iterator ri(you.pos(), r, C_CIRCLE);
              ri; ++ri)
         {
-            _set_agrid_flag(*ri, APROP_QUAD);
+            if (cell_see_cell(you.pos(), *ri, LOS_DEFAULT))
+                _set_agrid_flag(*ri, APROP_QUAD);
         }
         no_areas = false;
     }
@@ -203,10 +231,11 @@ static void _update_agrid()
     {
         const int r = 27;
         _agrid_centres.push_back(area_centre(AREA_DISJUNCTION, you.pos(), r));
-        for (radius_iterator ri(you.pos(), r, C_CIRCLE, you.get_los());
+        for (radius_iterator ri(you.pos(), r, C_CIRCLE);
              ri; ++ri)
         {
-            _set_agrid_flag(*ri, APROP_DISJUNCTION);
+            if (cell_see_cell(you.pos(), *ri, LOS_DEFAULT))
+                _set_agrid_flag(*ri, APROP_DISJUNCTION);
         }
         no_areas = false;
     }
@@ -232,6 +261,8 @@ static area_centre_type _get_first_area(const coord_def& f)
         return AREA_SANCTUARY;
     if (a & APROP_SILENCE)
         return AREA_SILENCE;
+    if (a & APROP_HOT)
+        return AREA_HOT;
     if (a & APROP_HALO)
         return AREA_HALO;
     if (a & APROP_UMBRA)
@@ -521,7 +552,7 @@ static int _silence_range(int dur)
 
 int player::silence_radius2() const
 {
-    return _silence_range(you.duration[DUR_SILENCE]);
+    return _silence_range(duration[DUR_SILENCE]);
 }
 
 int monster::silence_radius2() const
@@ -569,11 +600,11 @@ int player::halo_radius2() const
 {
     int size = -1;
 
-    if (you.religion == GOD_SHINING_ONE && you.piety >= piety_breakpoint(0)
-        && !you.penance[GOD_SHINING_ONE])
+    if (religion == GOD_SHINING_ONE && piety >= piety_breakpoint(0)
+        && !penance[GOD_SHINING_ONE])
     {
         // Preserve the middle of old radii.
-        const int r = you.piety - 10;
+        const int r = piety - 10;
         // The cap is 64, just less than the LOS of 65.
         size = min(LOS_RADIUS*LOS_RADIUS, r * r / 400);
     }
@@ -601,8 +632,6 @@ int monster::halo_radius2() const
     // small ones.
     switch (type)
     {
-    case MONS_SPIRIT:
-        return 5;
     case MONS_ANGEL:
         return 26;
     case MONS_CHERUB:
@@ -611,25 +640,18 @@ int monster::halo_radius2() const
         return 32;
     case MONS_SERAPH:
         return 50;
-    case MONS_PEARL_DRAGON:
-        return 5;
     case MONS_OPHAN:
         return 64; // highest rank among sentient ones
-    case MONS_PHOENIX:
-        return 10;
     case MONS_SHEDU:
         return 10;
-    case MONS_APIS:
-        return 4;
-    case MONS_PALADIN: // If a paladin finds the mace of brilliance
-                       // it needs a larger halo
-        return max(4, size);  // mere humans
     case MONS_SILVER_STAR:
         return 40; // dumb but with an immense power
     case MONS_HOLY_SWINE:
         return 1;  // only notionally holy
+    case MONS_MENNAS:
+        return 4;  // ???  Low on grace or what?
     default:
-        return 4;
+        return -1;
     }
 }
 
@@ -639,7 +661,7 @@ int monster::halo_radius2() const
 
 int player::liquefying_radius2() const
 {
-    return _silence_range(you.duration[DUR_LIQUEFYING]);
+    return _silence_range(duration[DUR_LIQUEFYING]);
 }
 
 int monster::liquefying_radius2() const
@@ -785,3 +807,66 @@ int player::suppression_radius2() const
 {
     return -1;
 }
+
+/////////////
+// Soul aura (currently just a marker for reference)
+
+bool soul_aura(const coord_def& p)
+{
+    if (!map_bounds(p))
+        return false;
+    if (!_agrid_valid)
+        _update_agrid();
+
+    return _check_agrid_flag(p, APROP_SOUL_AURA);
+}
+
+int monster::soul_aura_radius2() const
+{
+    if (type == MONS_LOST_SOUL)
+        return LOS_RADIUS_SQ;
+    else
+        return -1;
+}
+
+int player::soul_aura_radius2() const
+{
+    return -1;
+}
+
+/////////////
+// Heat aura (lava orcs).
+
+// Player radius
+int player::heat_radius2() const
+{
+    if (species != SP_LAVA_ORC)
+        return -1;
+
+    if (!temperature_effect(LORC_HEAT_AURA))
+        return -1;
+
+    return 2; // Surrounds you to radius of 1.
+}
+
+// Stub for monster radius
+int monster::heat_radius2() const
+{
+    return -1;
+}
+
+bool heated(const coord_def& p)
+{
+    if (!map_bounds(p))
+        return false;
+
+    if (!_agrid_valid)
+        _update_agrid();
+
+    return _check_agrid_flag(p, APROP_HOT);
+}
+
+bool actor::heated() const
+{
+    return ::heated(pos());
+}
