@@ -15,7 +15,6 @@
 #include "externs.h"
 #include "items.h"
 #include "itemname.h" // for make_name()
-#include "l_defs.h"
 #include "libutil.h"
 #include "los.h"
 #include "macro.h"
@@ -34,6 +33,7 @@
 #include "spl-util.h"
 #include "state.h"
 #include "stuff.h"
+#include "terrain.h"
 #ifdef USE_TILE
  #include "tileview.h"
 #endif
@@ -47,7 +47,7 @@ extern void world_reacts();
 
 namespace arena
 {
-    void write_error(const string &error);
+    static void write_error(const string &error);
 
     // A faction is just a big list of monsters. Monsters will be dropped
     // around the appropriate marker.
@@ -83,59 +83,58 @@ namespace arena
         }
     };
 
-    string teams;
+    static string teams;
 
-    int total_trials = 0;
+    static int total_trials = 0;
 
-    bool contest_canceled = false;
+    static bool contest_cancelled = false;
 
-    bool is_respawning = false;
+    static bool is_respawning = false;
 
-    int trials_done = 0;
-    int team_a_wins = 0;
-    int ties        = 0;
+    static int trials_done = 0;
+    static int team_a_wins = 0;
+    static int ties        = 0;
 
-    int turns       = 0;
+    static int turns       = 0;
 
-    bool allow_summons       = true;
-    bool allow_animate       = true;
-    bool allow_chain_summons = true;
-    bool allow_zero_xp       = false;
-    bool allow_immobile      = true;
-    bool allow_bands         = true;
-    bool name_monsters       = false;
-    bool random_uniques      = false;
-    bool real_summons        = false;
-    bool move_summons        = false;
-    bool respawn             = false;
-    bool move_respawns       = false;
+    static bool allow_summons       = true;
+    static bool allow_animate       = true;
+    static bool allow_chain_summons = true;
+    static bool allow_zero_xp       = false;
+    static bool allow_immobile      = true;
+    static bool allow_bands         = true;
+    static bool name_monsters       = false;
+    static bool random_uniques      = false;
+    static bool real_summons        = false;
+    static bool move_summons        = false;
+    static bool respawn             = false;
+    static bool move_respawns       = false;
 
-    bool miscasts            = false;
+    static bool miscasts            = false;
 
-    int  summon_throttle     = INT_MAX;
+    static int  summon_throttle     = INT_MAX;
 
-    vector<monster_type> uniques_list;
-    vector<int> a_spawners;
-    vector<int> b_spawners;
-    int8_t           to_respawn[MAX_MONSTERS];
+    static vector<monster_type> uniques_list;
+    static vector<int> a_spawners;
+    static vector<int> b_spawners;
+    static int8_t           to_respawn[MAX_MONSTERS];
 
-    int item_drop_times[MAX_ITEMS];
+    static int item_drop_times[MAX_ITEMS];
 
-    bool banned_glyphs[128];
+    static bool banned_glyphs[128];
 
-    string arena_type = "";
-    faction faction_a(true);
-    faction faction_b(false);
-    coord_def place_a, place_b;
+    static string arena_type = "";
+    static faction faction_a(true);
+    static faction faction_b(false);
+    static coord_def place_a, place_b;
 
-    bool cycle_random     = false;
-    uint32_t cycle_random_pos = 0;
+    static bool cycle_random     = false;
+    static uint32_t cycle_random_pos = 0;
 
-    FILE *file = NULL;
-    int message_pos = 0;
-    level_id place(BRANCH_MAIN_DUNGEON, 20);
+    static FILE *file = NULL;
+    static level_id place(BRANCH_MAIN_DUNGEON, 20);
 
-    void adjust_spells(monster* mons, bool no_summons, bool no_animate)
+    static void adjust_spells(monster* mons, bool no_summons, bool no_animate)
     {
         monster_spells &spells(mons->spells);
         for (int i = 0; i < NUM_MONSTER_SPELL_SLOTS; ++i)
@@ -148,7 +147,7 @@ namespace arena
         }
     }
 
-    void adjust_monsters()
+    static void adjust_monsters()
     {
         for (monster_iterator mon; mon; ++mon)
         {
@@ -158,7 +157,7 @@ namespace arena
         }
     }
 
-    void list_eq(const monster *mon)
+    static void list_eq(const monster *mon)
     {
         if (!Options.arena_list_eq || file == NULL)
             return;
@@ -184,7 +183,7 @@ namespace arena
 
     void faction::place_at(const coord_def &pos)
     {
-        ASSERT(in_bounds(pos));
+        ASSERT_IN_BOUNDS(pos);
         for (int i = 0, size = members.size(); i < size; ++i)
         {
             mons_spec spec = members.get_monster(i);
@@ -213,7 +212,7 @@ namespace arena
         }
     }
 
-    void center_print(unsigned sz, string text, int number = -1)
+    static void center_print(unsigned sz, string text, int number = -1)
     {
         if (number >= 0)
             text = make_stringf("(%d) %s", number, text.c_str());
@@ -225,7 +224,7 @@ namespace arena
         cprintf("%s%s", string((sz - len) / 2, ' ').c_str(), text.c_str());
     }
 
-    void setup_level()
+    static void setup_level()
     {
         turns = 0;
 
@@ -285,7 +284,7 @@ namespace arena
         env.markers.activate_all();
     }
 
-    string find_monster_spec()
+    static string find_monster_spec()
     {
         if (!teams.empty())
             return teams;
@@ -293,7 +292,7 @@ namespace arena
             return "random v random";
     }
 
-    void parse_faction(faction &fact, string spec)
+    static void parse_faction(faction &fact, string spec)
         throw (string)
     {
         fact.clear();
@@ -308,7 +307,7 @@ namespace arena
         }
     }
 
-    void parse_monster_spec()
+    static void parse_monster_spec()
         throw (string)
     {
         string spec = find_monster_spec();
@@ -403,7 +402,7 @@ namespace arena
         }
     }
 
-    void setup_monsters()
+    static void setup_monsters()
         throw (string)
     {
         faction_a.reset();
@@ -412,7 +411,7 @@ namespace arena
         for (int i = 0; i < MAX_MONSTERS; i++)
             to_respawn[i] = -1;
 
-        unwind_var< FixedVector<bool, NUM_MONSTERS> >
+        unwind_var< FixedBitVector<NUM_MONSTERS> >
             uniq(you.unique_creatures);
 
         place_a = dgn_find_feature_marker(DNGN_STONE_STAIRS_UP_I);
@@ -435,7 +434,7 @@ namespace arena
         adjust_monsters();
     }
 
-    void show_fight_banner(bool after_fight = false)
+    static void show_fight_banner(bool after_fight = false)
     {
         int line = 1;
 
@@ -474,7 +473,7 @@ namespace arena
         }
     }
 
-    void setup_others()
+    static void setup_others()
     {
         you.species = SP_HUMAN;
         you.char_class = JOB_FIGHTER;
@@ -498,13 +497,13 @@ namespace arena
         show_fight_banner();
     }
 
-    void expand_mlist(int exp)
+    static void expand_mlist(int exp)
     {
         crawl_view.mlistp.y  -= exp;
         crawl_view.mlistsz.y += exp;
     }
 
-    void setup_fight()
+    static void setup_fight()
         throw (string)
     {
         //no_messages mx;
@@ -517,15 +516,7 @@ namespace arena
         setup_others();
     }
 
-    // Temporarily reset crawl_state.type to force a --more-- to happen.
-    void more()
-    {
-        unwind_var<game_type> type(crawl_state.type, GAME_TYPE_NORMAL);
-
-        ::more();
-    }
-
-    void count_foes()
+    static void count_foes()
     {
         int orig_a = faction_a.active_members;
         int orig_b = faction_b.active_members;
@@ -547,7 +538,7 @@ namespace arena
 
         for (monster_iterator mons; mons; ++mons)
         {
-            if (mons_is_tentacle(mons->type))
+            if (mons_is_tentacle_or_tentacle_segment(mons->type))
                 continue;
             if (mons->attitude == ATT_FRIENDLY)
                 faction_a.active_members++;
@@ -576,7 +567,7 @@ namespace arena
     }
 
     // Returns true as long as at least one member of each faction is alive.
-    bool fight_is_on()
+    static bool fight_is_on()
     {
         if (faction_a.active_members > 0 && faction_b.active_members > 0)
         {
@@ -597,32 +588,7 @@ namespace arena
         return (faction_a.active_members > 0 && faction_b.active_members > 0);
     }
 
-    void report_foes()
-    {
-        for (monster_iterator mons; mons; ++mons)
-        {
-            if (mons->type == MONS_SIGMUND)
-            {
-                coord_def where;
-                if (mons->get_foe())
-                    where = mons->get_foe()->pos();
-                mprf("%s (%d,%d) foe: %s (%d,%d)",
-                     mons->name(DESC_PLAIN).c_str(),
-                     mons->pos().x, mons->pos().y,
-                     mons->get_foe()? mons->get_foe()->name(DESC_PLAIN).c_str()
-                     : "(none)",
-                     where.x, where.y);
-            }
-        }
-    }
-
-    void fixup_foes()
-    {
-        for (monster_iterator mons; mons; ++mons)
-            behaviour_event(*mons, ME_DISTURB, 0, mons->pos());
-    }
-
-    void dump_messages()
+    static void dump_messages()
     {
         if (!Options.arena_dump_msgs || file == NULL)
             return;
@@ -678,7 +644,7 @@ namespace arena
     // Try to prevent random luck from letting one spawner fill up the
     // arena with so many monsters that the other spawner can never get
     // back on even footing.
-    void balance_spawners()
+    static void balance_spawners()
     {
         if (a_spawners.empty() || b_spawners.empty())
             return;
@@ -705,7 +671,7 @@ namespace arena
         }
     }
 
-    void do_miscasts()
+    static void do_miscasts()
     {
         if (!miscasts)
             return;
@@ -720,11 +686,11 @@ namespace arena
         }
     }
 
-    void handle_keypress(int ch)
+    static void handle_keypress(int ch)
     {
         if (key_is_escape(ch) || toalower(ch) == 'q')
         {
-            contest_canceled = true;
+            contest_cancelled = true;
             mpr("Canceled contest at user request");
             return;
         }
@@ -756,7 +722,7 @@ namespace arena
         process_command(cmd);
     }
 
-    void do_respawn(faction &fac)
+    static void do_respawn(faction &fac)
     {
         is_respawning = true;
         for (unsigned int _i = fac.respawn_list.size(); _i > 0; _i--)
@@ -822,7 +788,7 @@ namespace arena
         is_respawning = false;
     }
 
-    void do_fight()
+    static void do_fight()
     {
         viewwindow();
         mesclr(true);
@@ -835,7 +801,7 @@ namespace arena
                     const int ch = getchm();
                     handle_keypress(ch);
                     ASSERT(crawl_state.game_is_arena() && !crawl_state.arena_suspended);
-                    if (contest_canceled)
+                    if (contest_cancelled)
                         return;
                 }
 
@@ -939,12 +905,12 @@ namespace arena
         dump_messages();
     }
 
-    void global_setup(const string& arena_teams)
+    static void global_setup(const string& arena_teams)
     {
         // Clear some things that shouldn't persist across restart_after_game.
         // parse_monster_spec and setup_fight will clear the rest.
         total_trials = trials_done = team_a_wins = ties = 0;
-        contest_canceled = false;
+        contest_cancelled = false;
         is_respawning = false;
         uniques_list.clear();
         memset(banned_glyphs, 0, sizeof(banned_glyphs));
@@ -991,7 +957,7 @@ namespace arena
         }
     }
 
-    void global_shutdown()
+    static void global_shutdown()
     {
         if (file != NULL)
             fclose(file);
@@ -999,7 +965,7 @@ namespace arena
         file = NULL;
     }
 
-    void write_results()
+    static void write_results()
     {
         if (file != NULL)
         {
@@ -1013,7 +979,7 @@ namespace arena
         }
     }
 
-    void write_error(const string &error)
+    static void write_error(const string &error)
     {
         if (file != NULL)
         {
@@ -1023,7 +989,7 @@ namespace arena
         file = NULL;
     }
 
-    void simulate()
+    static void simulate()
     {
         init_level_connectivity();
         do
@@ -1042,7 +1008,7 @@ namespace arena
             if (trials_done < total_trials)
                 delay(Options.arena_delay * 5);
         }
-        while (!contest_canceled && trials_done < total_trials);
+        while (!contest_cancelled && trials_done < total_trials);
 
         if (total_trials > 0)
         {
@@ -1068,7 +1034,7 @@ monster_type arena_pick_random_monster(const level_id &place)
         const vector<monster_type> &uniques = arena::uniques_list;
 
         const monster_type type = uniques[random2(uniques.size())];
-        you.unique_creatures[type] = false;
+        you.unique_creatures.set(type, false);
 
         return type;
     }
@@ -1094,7 +1060,7 @@ monster_type arena_pick_random_monster(const level_id &place)
 
 bool arena_veto_random_monster(monster_type type)
 {
-    if (mons_is_tentacle(type))
+    if (mons_is_tentacle_or_tentacle_segment(type))
         return true;
     if (!arena::allow_immobile && mons_class_is_stationary(type))
         return true;
@@ -1135,8 +1101,8 @@ bool arena_veto_place_monster(const mgen_data &mg, bool first_band_member,
 // is placed via splitting.
 void arena_placed_monster(monster* mons)
 {
-    if (mons_is_tentacle(mons->type))
-        ; // we don't count tentacles, even free-standing
+    if (mons_is_tentacle_or_tentacle_segment(mons->type))
+        ; // we don't count tentacles or tentacle segments, even free-standing
     else if (mons->attitude == ATT_FRIENDLY)
     {
         arena::faction_a.active_members++;
@@ -1235,7 +1201,7 @@ void arena_split_monster(monster* split_from, monster* split_to)
 void arena_monster_died(monster* mons, killer_type killer,
                         int killer_index, bool silent, int corpse)
 {
-    if (mons_is_tentacle(mons->type))
+    if (mons_is_tentacle_or_tentacle_segment(mons->type))
         ; // part of a monster, or a spell
     else if (mons->attitude == ATT_FRIENDLY)
         arena::faction_a.active_members--;
@@ -1272,7 +1238,7 @@ void arena_monster_died(monster* mons, killer_type killer,
         }
     }
 
-    // Only respawn those monsers which were initally placed in the
+    // Only respawn those monsters which were initially placed in the
     // arena.
     const int midx = mons->mindex();
     if (arena::respawn && arena::to_respawn[midx] != -1
