@@ -25,14 +25,13 @@ enum item_origin_dump_selector
 };
 
 class scorefile_entry;
-std::string morgue_directory();
-bool dump_char(const std::string &fname,
-               bool full_id = false,
+string morgue_directory();
+bool dump_char(const string &fname, bool quiet = false, bool full_id = false,
                const scorefile_entry *se = NULL);
 void dump_map(const char* fname, bool debug = false, bool dist = false);
 void dump_map(FILE *fp, bool debug = false, bool dist = false);
 void display_notes();
-std::string munge_description(std::string inStr);
+string munge_description(string inStr);
 const char *hunger_level(void);
 
 #ifdef DGL_WHEREIS
