@@ -22,9 +22,12 @@
 #include "godconduct.h"
 #include "los.h"
 #include "losglobal.h"
+#include "mapmark.h"
 #include "melee_attack.h"
+#include "mgen_data.h"
 #include "misc.h"
 #include "mon-behv.h"
+#include "mon-place.h"
 #include "mutation.h"
 #include "ouch.h"
 #include "random.h"
@@ -46,8 +49,10 @@ static int _actual_spread_rate(cloud_type type, int spread_rate)
 
     switch (type)
     {
+#if TAG_MAJOR_VERSION == 34
     case CLOUD_GLOOM:
         return 50;
+#endif
     case CLOUD_STEAM:
     case CLOUD_GREY_SMOKE:
     case CLOUD_BLACK_SMOKE:
@@ -74,7 +79,9 @@ static beam_type _cloud2beam(cloud_type flavour)
     case CLOUD_STEAM:        return BEAM_STEAM;
     case CLOUD_MIASMA:       return BEAM_MIASMA;
     case CLOUD_CHAOS:        return BEAM_CHAOS;
+#if TAG_MAJOR_VERSION == 34
     case CLOUD_GLOOM:        return BEAM_GLOOM;
+#endif
     case CLOUD_INK:          return BEAM_INK;
     case CLOUD_HOLY_FLAMES:  return BEAM_HOLY_FLAME;
     case CLOUD_PETRIFY:      return BEAM_PETRIFYING_CLOUD;
@@ -286,6 +293,51 @@ static void _dissipate_cloud(int cloudidx, int dissipate)
         delete_cloud(cloudidx);
 }
 
+static void _handle_ghostly_flame(const cloud_struct& cloud)
+{
+    if (actor_at(cloud.pos))
+        return;
+
+    int countn = 0;
+    for (distance_iterator di(cloud.pos, false, false, 2); di; ++di)
+    {
+        if (monster_at(*di) && monster_at(*di)->type == MONS_SPECTRAL_THING)
+            countn++;
+    }
+
+    int rate[5] = {650, 175, 45, 20, 0};
+    int chance = rate[(min(4, countn))];
+
+    if (!x_chance_in_y(chance, you.time_taken * 600))
+        return;
+
+    // No spawns in problematic places.
+    if (!monster_habitable_grid(MONS_IGUANA, grd(cloud.pos)))
+        return;
+
+    monster_type basetype = random_choose_weighted(4,   MONS_ANACONDA,
+                                                   6,   MONS_HYDRA,
+                                                   8,   MONS_ROCK_WORM,
+                                                   3,   MONS_SNAPPING_TURTLE,
+                                                   2,   MONS_ALLIGATOR_SNAPPING_TURTLE,
+                                                   100, RANDOM_MONSTER,
+                                                   0);
+
+    if (basetype == RANDOM_MONSTER && one_chance_in(4))
+    {
+        do
+            basetype = pick_random_zombie();
+        while (!monster_habitable_grid(basetype, grd(cloud.pos)));
+    }
+
+    monster* agent = monster_by_mid(cloud.source);
+    create_monster(mgen_data(MONS_SPECTRAL_THING,
+                             (cloud.whose == KC_OTHER ? BEH_HOSTILE : BEH_FRIENDLY),
+                             NULL, 1, SPELL_GHOSTLY_FLAMES, cloud.pos,
+                             (agent ? agent->foe : MHITYOU), MG_FORCE_PLACE,
+                             GOD_NO_GOD, basetype));
+}
+
 void manage_clouds()
 {
     for (int i = 0; i < MAX_CLOUDS; ++i)
@@ -307,29 +359,8 @@ void manage_clouds()
         // Ink cloud doesn't appear outside of water.
         else if (cloud.type == CLOUD_INK && !feat_is_watery(grd(cloud.pos)))
             dissipate *= 40;
-        else if (cloud.type == CLOUD_GLOOM)
-        {
-            int count = 0;
-            for (adjacent_iterator ai(cloud.pos); ai; ++ai)
-            {
-                if (env.cgrid(*ai) != EMPTY_CLOUD
-                    && env.cloud[env.cgrid(*ai)].type == CLOUD_GLOOM)
-                {
-                        count++;
-                }
-            }
-
-            if (!umbraed(cloud.pos) && haloed(cloud.pos)
-                && !silenced(cloud.pos))
-            {
-                count = 0;
-            }
-
-            if (count < 4)
-                dissipate *= 50;
-            else
-                dissipate /= 20;
-        }
+        else if (cloud.type == CLOUD_GHOSTLY_FLAME)
+            _handle_ghostly_flame(cloud);
 
         _cloud_interacts_with_terrain(cloud);
         expose_items_to_element(_cloud2beam(cloud.type), cloud.pos, 2);
@@ -340,7 +371,7 @@ void manage_clouds()
 
 static void _maybe_leave_water(const cloud_struct& c)
 {
-    ASSERT(in_bounds(c.pos));
+    ASSERT_IN_BOUNDS(c.pos);
 
     // Rain clouds can occasionally leave shallow water or deepen it:
     // If we're near lava, chance of leaving water is lower;
@@ -365,7 +396,8 @@ static void _maybe_leave_water(const cloud_struct& c)
         {
             if (you.pos() == c.pos && you.ground_level())
                 mpr("The rain has left you waist-deep in water!");
-            dungeon_terrain_changed(c.pos, feat);
+            temp_change_terrain(c.pos, feat, random_range(500, 1000),
+                                TERRAIN_CHANGE_FLOOD);
         }
     }
 }
@@ -713,6 +745,8 @@ static int _cloud_base_damage(const actor *act,
     case CLOUD_STEAM:
         return _cloud_damage_calc(_steam_cloud_damage(cloud.decay), 2, 0,
                                   maximum_damage);
+    case CLOUD_GHOSTLY_FLAME:
+        return _cloud_damage_calc(15, 3, 4, maximum_damage);
     default:
         return 0;
     }
@@ -733,7 +767,7 @@ static bool _actor_cloud_immune(const actor *act, const cloud_struct &cloud)
     const bool player = act->is_player();
 
     if (!player
-        && you.religion == GOD_FEDHAS
+        && you_worship(GOD_FEDHAS)
         && fedhas_protects(act->as_monster())
         && (cloud.whose == KC_YOU || cloud.whose == KC_FRIENDLY)
         && (act->as_monster()->friendly() || act->as_monster()->neutral()))
@@ -746,8 +780,10 @@ static bool _actor_cloud_immune(const actor *act, const cloud_struct &cloud)
     case CLOUD_FIRE:
     case CLOUD_FOREST_FIRE:
         return act->is_fiery()
-                || (player && you.duration[DUR_FIRE_SHIELD])
-                || (player && you.mutation[MUT_IGNITE_BLOOD]);
+                || player &&
+                   (you.duration[DUR_FIRE_SHIELD]
+                    || you.mutation[MUT_IGNITE_BLOOD]
+                    || you.species == SP_DJINNI);
     case CLOUD_HOLY_FLAMES:
         return act->res_holy_fire() > 0;
     case CLOUD_COLD:
@@ -765,6 +801,8 @@ static bool _actor_cloud_immune(const actor *act, const cloud_struct &cloud)
         return act->res_rotting() > 0;
     case CLOUD_PETRIFY:
         return act->res_petrify();
+    case CLOUD_GHOSTLY_FLAME:
+        return act->holiness() == MH_UNDEAD;
     default:
         return false;
     }
@@ -925,14 +963,12 @@ bool _actor_apply_cloud_side_effects(actor *act,
             if (player)
             {
                 mpr("Strange energies course through your body.");
-                if (one_chance_in(3))
-                    return you.mutate("mutagenic cloud");
-                else
-                    return give_bad_mutation("mutagenic cloud");
+                return mutate(one_chance_in(5) ? RANDOM_MUTATION : RANDOM_BAD_MUTATION,
+                              "mutagenic cloud");
             }
-            else if (mons->mutate("mutagenic cloud"))
+            else if (mons->malmutate("mutagenic cloud"))
             {
-                if (you.religion == GOD_ZIN && cloud.whose == KC_YOU)
+                if (you_worship(GOD_ZIN) && cloud.whose == KC_YOU)
                     did_god_conduct(DID_DELIBERATE_MUTATING, 5 + random2(3));
                 return true;
             }
@@ -965,7 +1001,7 @@ static int _actor_cloud_base_damage(actor *act,
 
     const int cloud_raw_base_damage =
         _cloud_base_damage(act, cloud, maximum_damage);
-    const int cloud_base_damage = (resist == MAG_IMMUNE?
+    const int cloud_base_damage = (resist == MAG_IMMUNE ?
                                    0 : cloud_raw_base_damage);
     return cloud_base_damage;
 }
@@ -1002,6 +1038,7 @@ static int _actor_cloud_damage(actor *act,
     case CLOUD_HOLY_FLAMES:
     case CLOUD_COLD:
     case CLOUD_STEAM:
+    case CLOUD_GHOSTLY_FLAME:
         final_damage =
             _cloud_damage_output(act, _cloud2beam(cloud.type), resist,
                                  cloud_base_damage,
@@ -1139,7 +1176,9 @@ bool is_harmless_cloud(cloud_type type)
     case CLOUD_TLOC_ENERGY:
     case CLOUD_MAGIC_TRAIL:
     case CLOUD_DUST_TRAIL:
+#if TAG_MAJOR_VERSION == 34
     case CLOUD_GLOOM:
+#endif
     case CLOUD_INK:
     case CLOUD_DEBUGGING:
         return true;
@@ -1178,12 +1217,16 @@ static const char *_terse_cloud_names[] =
     "flame", "noxious fumes", "freezing vapour", "poison gas",
     "black smoke", "grey smoke", "blue smoke",
     "purple smoke", "translocational energy", "fire",
-    "steam", "gloom", "ink",
+    "steam",
+#if TAG_MAJOR_VERSION == 34
+    "gloom",
+#endif
+    "ink",
     "calcifying dust",
     "blessed fire", "foul pestilence", "thin mist",
     "seething chaos", "rain", "mutagenic fog", "magical condensation",
     "raging winds",
-    "sparse dust",
+    "sparse dust", "ghostly flame"
 };
 
 static const char *_verbose_cloud_names[] =
@@ -1192,11 +1235,15 @@ static const char *_verbose_cloud_names[] =
     "roaring flames", "noxious fumes", "freezing vapours", "poison gas",
     "black smoke", "grey smoke", "blue smoke",
     "purple smoke", "translocational energy", "roaring flames",
-    "a cloud of scalding steam", "thick gloom", "ink",
+    "a cloud of scalding steam",
+#if TAG_MAJOR_VERSION == 34
+    "thick gloom",
+#endif
+    "ink",
     "calcifying dust",
     "blessed fire", "dark miasma", "thin mist", "seething chaos", "the rain",
     "mutagenic fog", "magical condensation", "raging winds",
-    "sparse dust",
+    "sparse dust", "ghostly flame"
 };
 
 string cloud_type_name(cloud_type type, bool terse)
@@ -1359,7 +1406,9 @@ int get_cloud_colour(int cloudno)
 
     case CLOUD_PURPLE_SMOKE:
     case CLOUD_TLOC_ENERGY:
+#if TAG_MAJOR_VERSION == 34
     case CLOUD_GLOOM:
+#endif
         which_colour = MAGENTA;
         break;
 
@@ -1402,6 +1451,10 @@ int get_cloud_colour(int cloudno)
         which_colour = WHITE;
         break;
 
+    case CLOUD_GHOSTLY_FLAME:
+        which_colour = ETC_ELECTRICITY;
+        break;
+
     default:
         which_colour = LIGHTGREY;
         break;
@@ -1433,3 +1486,87 @@ void remove_tornado_clouds(mid_t whose)
         if (env.cloud[i].type == CLOUD_TORNADO && env.cloud[i].source == whose)
             delete_cloud(i);
 }
+
+static void _spread_cloud(coord_def pos, cloud_type type, int radius, int pow,
+                          int &remaining, int ratio = 10,
+                          mid_t agent_mid = NON_ENTITY, kill_category kcat = KC_OTHER)
+{
+    bolt beam;
+    beam.target = pos;
+    beam.use_target_as_pos = true;
+    explosion_map exp_map;
+    exp_map.init(INT_MAX);
+    beam.determine_affected_cells(exp_map, coord_def(), 0,
+                                  radius, true, true);
+
+    coord_def centre(9,9);
+    for (distance_iterator di(pos, true, false); di; ++di)
+    {
+        if (di.radius() > radius)
+            return;
+
+        if ((exp_map(*di - pos + centre) < INT_MAX) && env.cgrid(*di) == EMPTY_CLOUD
+            && (di.radius() < radius || x_chance_in_y(ratio, 100)))
+        {
+            place_cloud(type, *di, pow + random2(pow), NULL);
+            --remaining;
+
+            // Setting this way since the agent of the cloud may be dead before
+            // cloud is placed, so no agent exists to pass to place_cloud (though
+            // proper blame should still be assigned)
+            if (env.cgrid(*di) != EMPTY_CLOUD)
+            {
+                env.cloud[env.cgrid(*di)].source = agent_mid;
+                env.cloud[env.cgrid(*di)].whose = kcat;
+            }
+        }
+
+        // Placed all clouds for this spreader
+        if (remaining == 0)
+            return;
+    }
+}
+
+void run_cloud_spreaders(int dur)
+{
+    if (!dur)
+        return;
+
+    vector<map_marker*> markers = env.markers.get_all(MAT_CLOUD_SPREADER);
+
+    for (int i = 0, size = markers.size(); i < size; ++i)
+    {
+        map_cloud_spreader_marker *mark = dynamic_cast<map_cloud_spreader_marker*>(markers[i]);
+
+        mark->speed_increment += dur;
+        int rad = min(mark->speed_increment / mark->speed, mark->max_rad - 1) + 1;
+        int ratio = (mark->speed_increment - ((rad - 1) * mark->speed))
+                    * 100 / mark->speed;
+
+        if (ratio == 0)
+        {
+            rad--;
+            ratio = 100;
+        }
+
+        _spread_cloud(mark->pos, mark->ctype, rad, mark->duration,
+                        mark->remaining, ratio, mark->agent_mid, mark->kcat);
+        if ((rad >= mark->max_rad && ratio >= 100) || mark->remaining == 0)
+        {
+            env.markers.remove(mark);
+            break;
+        }
+    }
+}
+
+void fume()
+{
+    static cloud_type clouds[] =
+        { CLOUD_PURPLE_SMOKE, CLOUD_BLUE_SMOKE, CLOUD_GREY_SMOKE };
+    if (you.mutation[MUT_FUMES])
+    {
+        int level = you.mutation[MUT_FUMES];
+        if (x_chance_in_y(you.time_taken * level, 35))
+            place_cloud(clouds[bestroll(3, 2)], you.pos(), 3 + random2(4), &you, 4);
+    }
+}
