@@ -146,6 +146,7 @@
 {CK_CTRL_HOME, CMD_OPEN_DOOR_UP_LEFT},
 {CONTROL('A'), CMD_TOGGLE_AUTOPICKUP},
 {CONTROL('C'), CMD_CLEAR_MAP},
+{CONTROL('E'), CMD_TOGGLE_TRAVEL_SPEED},
 {CONTROL('F'), CMD_SEARCH_STASHES},
 {CONTROL('O'), CMD_DISPLAY_OVERMAP},
 {CONTROL('P'), CMD_REPLAY_MESSAGES},
@@ -214,6 +215,7 @@
 {'n', CMD_TARGET_DOWN_RIGHT},
 {'u', CMD_TARGET_UP_RIGHT},
 {'y', CMD_TARGET_UP_LEFT},
+{CK_CLEAR, CMD_TARGET_SELECT},
 {CK_END, CMD_TARGET_DOWN_LEFT},
 {CK_LEFT, CMD_TARGET_LEFT},
 {CK_DOWN, CMD_TARGET_DOWN},
@@ -257,6 +259,7 @@
 {'?', CMD_MAP_HELP},
 {CONTROL('C'), CMD_MAP_CLEAR_MAP},
 {CONTROL('F'), CMD_MAP_FORGET},
+{CONTROL('U'), CMD_MAP_UNFORGET},
 {CONTROL('W'), CMD_MAP_ADD_WAYPOINT},
 {'e', CMD_MAP_EXCLUDE_AREA},
 {CONTROL('E'), CMD_MAP_CLEAR_EXCLUDES},
