@@ -2578,104 +2578,106 @@ int list_wizard_commands(bool do_redraw_screen)
 
     cols.add_formatted(0,
                        "<yellow>Player stats</yellow>\n"
-                       "<w>A</w>      : set all skills to level\n"
-                       "<w>Ctrl-D</w> : change enchantments/durations\n"
-                       "<w>g</w>      : exercise a skill\n"
-                       "<w>Ctrl-L</w> : change experience level\n"
-                       "<w>r</w>      : change character's species\n"
-                       "<w>s</w>      : gain 20000 skill points\n"
-                       "<w>S</w>      : set skill to level\n"
-                       "<w>x</w>      : gain an experience level\n"
-                       "<w>$</w>      : get 1000 gold\n"
-                       "<w>]</w>      : get a mutation\n"
-                       "<w>_</w>      : gain religion\n"
-                       "<w>^</w>      : set piety to a value\n"
-                       "<w>@</w>      : set Str Int Dex\n"
-                       "<w>#</w>      : load character from a dump file\n"
-                       "<w>Z</w>      : gain lots of Zot Points\n"
-                       "<w>&</w>      : list all divine followers\n"
+                       "<w>A</w>      set all skills to level\n"
+                       "<w>Ctrl-D</w> change enchantments/durations\n"
+                       "<w>g</w>      exercise a skill\n"
+                       "<w>Ctrl-L</w> change experience level\n"
+                       "<w>r</w>      change character's species\n"
+                       "<w>s</w>      gain 20000 skill points\n"
+                       "<w>S</w>      set skill to level\n"
+                       "<w>x</w>      gain an experience level\n"
+                       "<w>$</w>      get 1000 gold\n"
+                       "<w>]</w>      get a mutation\n"
+                       "<w>_</w>      gain religion\n"
+                       "<w>^</w>      set piety to a value\n"
+                       "<w>@</w>      set Str Int Dex\n"
+                       "<w>#</w>      load character from a dump file\n"
+                       "<w>Z</w>      gain lots of Zot Points\n"
+                       "<w>&</w>      list all divine followers\n"
                        "\n"
                        "<yellow>Create level features</yellow>\n"
-                       "<w>L</w>      : place a vault by name\n"
-                       "<w>p</w>      : make a portal\n"
-                       "<w>T</w>      : make a trap\n"
-                       "<w><<</w>/<w>></w>    : create up/down staircase\n"
-                       "<w>(</w>      : turn cell into feature\n"
-                       "<w>\\</w>      : make a shop\n"
-                       "<w>Ctrl-K</w> : mark all vaults as unused\n"
+                       "<w>L</w>      place a vault by name\n"
+                       "<w>p</w>      make a portal\n"
+                       "<w>T</w>      make a trap\n"
+                       "<w><<</w>/<w>></w>    create up/down staircase\n"
+                       "<w>(</w>      turn cell into feature\n"
+                       "<w>\\</w>      make a shop\n"
+                       "<w>Ctrl-K</w> mark all vaults as unused\n"
                        "\n"
                        "<yellow>Other level related commands</yellow>\n"
-                       "<w>Ctrl-A</w> : generate new Abyss area\n"
-                       "<w>b</w>      : controlled blink\n"
-                       "<w>Ctrl-B</w> : controlled teleport\n"
-                       "<w>B</w>      : banish yourself to the Abyss\n"
-                       "<w>k</w>      : shift section of a labyrinth\n"
-                       "<w>R</w>      : change monster spawn rate\n"
-                       "<w>Ctrl-S</w> : change Abyss speed\n"
-                       "<w>u</w>/<w>d</w>    : shift up/down one level\n"
-                       "<w>~</w>      : go to a specific level\n"
-                       "<w>:</w>      : find branches and overflow\n"
-                       "         temples in the dungeon\n"
-                       "<w>;</w>      : list known levels and counters\n"
-                       "<w>{</w>      : magic mapping\n"
-                       "<w>}</w>      : detect all traps on level\n"
-                       "<w>)</w>      : change Shoals' tide speed\n"
-                       "<w>Ctrl-E</w> : dump level builder information\n"
-                       "<w>Ctrl-R</w> : regenerate current level\n"
-                       "<w>P</w>      : create a level based on a vault\n",
+                       "<w>Ctrl-A</w> generate new Abyss area\n"
+                       "<w>b</w>      controlled blink\n"
+                       "<w>Ctrl-B</w> controlled teleport\n"
+                       "<w>B</w>      banish yourself to the Abyss\n"
+                       "<w>k</w>      shift section of a labyrinth\n"
+                       "<w>R</w>      change monster spawn rate\n"
+                       "<w>Ctrl-S</w> change Abyss speed\n"
+                       "<w>u</w>/<w>d</w>    shift up/down one level\n"
+                       "<w>~</w>      go to a specific level\n"
+                       "<w>:</w>      find branches and overflow\n"
+                       "       temples in the dungeon\n"
+                       "<w>;</w>      list known levels and counters\n"
+                       "<w>{</w>      magic mapping\n"
+                       "<w>}</w>      detect all traps on level\n"
+                       "<w>)</w>      change Shoals' tide speed\n"
+                       "<w>Ctrl-E</w> dump level builder information\n"
+                       "<w>Ctrl-R</w> regenerate current level\n"
+                       "<w>P</w>      create a level based on a vault\n",
                        true, true);
 
     cols.add_formatted(1,
                        "<yellow>Other player related effects</yellow>\n"
-                       "<w>c</w>      : card effect\n"
+                       "<w>c</w>      card effect\n"
 #ifdef DEBUG_BONES
-                       "<w>Ctrl-G</w> : save/load ghost (bones file)\n"
+                       "<w>Ctrl-G</w> save/load ghost (bones file)\n"
 #endif
-                       "<w>h</w>/<w>H</w>    : heal yourself (super-Heal)\n"
-                       "<w>Ctrl-H</w> : set hunger state\n"
-                       "<w>X</w>      : make Xom do something now\n"
-                       "<w>z</w>      : cast spell by number/name\n"
-                       "<w>Ctrl-M</w> : memorise spell\n"
-                       "<w>W</w>      : god wrath\n"
-                       "<w>w</w>      : god mollification\n"
-                       "<w>Ctrl-P</w> : polymorph into a form\n"
-                       "<w>Ctrl-V</w> : toggle xray vision\n"
+                       "<w>h</w>/<w>H</w>    heal yourself (super-Heal)\n"
+                       "<w>Ctrl-H</w> set hunger state\n"
+                       "<w>X</w>      make Xom do something now\n"
+                       "<w>z</w>      cast spell by number/name\n"
+                       "<w>Ctrl-M</w> memorise spell\n"
+                       "<w>W</w>      god wrath\n"
+                       "<w>w</w>      god mollification\n"
+                       "<w>Ctrl-P</w> polymorph into a form\n"
+                       "<w>Ctrl-V</w> toggle xray vision\n"
                        "\n"
                        "<yellow>Monster related commands</yellow>\n"
-                       "<w>D</w>      : detect all monsters\n"
-                       "<w>G</w>      : dismiss all monsters\n"
-                       "<w>m</w>/<w>M</w>    : create monster by number/name\n"
-                       "<w>\"</w>      : list monsters\n"
+                       "<w>D</w>      detect all monsters\n"
+                       "<w>G</w>      dismiss all monsters\n"
+                       "<w>m</w>/<w>M</w>    create monster by number/name\n"
+                       "<w>\"</w>      list monsters\n"
                        "\n"
                        "<yellow>Item related commands</yellow>\n"
-                       "<w>a</w>      : acquirement\n"
-                       "<w>C</w>      : (un)curse item\n"
-                       "<w>i</w>/<w>I</w>    : identify/unidentify inventory\n"
-                       "<w>o</w>/<w>%</w>    : create an object\n"
-                       "<w>t</w>      : tweak object properties\n"
-                       "<w>v</w>      : show gold value of an item\n"
-                       "<w>-</w>      : get a god gift\n"
-                       "<w>|</w>      : create all predefined artefacts\n"
-                       "<w>+</w>      : make randart from item\n"
-                       "<w>'</w>      : list items\n"
-                       "<w>J</w>      : Jiyva off-level sacrifice\n"
+                       "<w>a</w>      acquirement\n"
+                       "<w>C</w>      (un)curse item\n"
+                       "<w>i</w>/<w>I</w>    identify/unidentify inventory\n"
+                       "<w>o</w>/<w>%</w>    create an object\n"
+                       "<w>t</w>      tweak object properties\n"
+                       "<w>v</w>      show gold value of an item\n"
+                       "<w>-</w>      get a god gift\n"
+                       "<w>|</w>      create all unrand artefacts\n"
+                       "<w>+</w>      make randart from item\n"
+                       "<w>'</w>      list items\n"
+                       "<w>J</w>      Jiyva off-level sacrifice\n"
                        "\n"
                        "<yellow>Debugging commands</yellow>\n"
-                       "<w>f</w>      : quick fight simulation\n"
-                       "<w>F</w>      : single scale fsim\n"
-                       "<w>Ctrl-F</w> : double scale fsim\n"
-                       "<w>Ctrl-I</w> : item generation stats\n"
-                       "<w>O</w>      : measure exploration time\n"
-                       "<w>Ctrl-t</w> : enter in-game Lua interpreter\n"
-                       "<w>Ctrl-X</w> : Xom effect stats\n"
+                       "<w>f</w>      quick fight simulation\n"
+                       "<w>F</w>      single scale fsim\n"
+                       "<w>Ctrl-F</w> double scale fsim\n"
+                       "<w>Ctrl-I</w> item generation stats\n"
+                       "<w>O</w>      measure exploration time\n"
+                       "<w>Ctrl-T</w> dungeon (D)Lua interpreter\n"
+                       "<w>Ctrl-U</w> client (C)Lua interpreter\n"
+                       "<w>Ctrl-X</w> Xom effect stats\n"
 #ifdef DEBUG_DIAGNOSTICS
-                       "<w>Ctrl-Q</w> : make some debug messages quiet\n"
+                       "<w>Ctrl-Q</w> make some debug messages quiet\n"
 #endif
+                       "<w>Ctrl-C</w> force a crash\n"
                        "\n"
                        "<yellow>Other wizard commands</yellow>\n"
                        "(not prefixed with <w>&</w>!)\n"
-                       "<w>x?</w>     : list targeted commands\n"
-                       "<w>X?</w>     : list map-mode commands\n",
+                       "<w>x?</w>     list targeted commands\n"
+                       "<w>X?</w>     list map-mode commands\n",
                        true, true);
 
     int key = _show_keyhelp_menu(cols.formatted_lines(), false,
