@@ -25,7 +25,7 @@ void show_stash_search_help();
 void show_butchering_help();
 void show_skill_menu_help();
 void list_commands(int hotkey = 0, bool do_redraw_screen = false,
-                   std::string highlight_string = "");
+                   string highlight_string = "");
 #ifdef WIZARD
 int list_wizard_commands(bool do_redraw_screen = false);
 #endif
