@@ -8,7 +8,6 @@
 #include "dactions.h"
 
 #include "coordit.h"
-#include "debug.h"
 #include "decks.h"
 #include "dungeon.h"
 #include "env.h"
@@ -57,6 +56,7 @@ static const char *daction_names[] =
     "slimes allow another conversion attempt",
 #endif
     "hogs to humans",
+    "end spirit howl",
 };
 #endif
 
@@ -120,6 +120,10 @@ bool mons_matches_daction(const monster* mon, daction_type act)
                 && (mon->props.exists("kirke_band")
                     || mon->props.exists(ORIG_MONSTER_KEY)));
 
+    case DACT_END_SPIRIT_HOWL:
+        return (mon->type == MONS_SPIRIT_WOLF
+                && mon->props.exists("howl_called"));
+
     default:
         return false;
     }
@@ -226,6 +230,15 @@ void apply_daction_to_mons(monster* mon, daction_type act, bool local,
             _daction_hog_to_human(mon, in_transit);
             break;
 
+        case DACT_END_SPIRIT_HOWL:
+            if (!you.can_see(mon))
+            {
+                // This wolf is available to be called again later
+                you.props["spirit_wolf_total"].get_int()++;
+                monster_die(mon, KILL_RESET, NON_MONSTER);
+            }
+            break;
+
         // The other dactions do not affect monsters directly.
         default:
             break;
@@ -234,7 +247,7 @@ void apply_daction_to_mons(monster* mon, daction_type act, bool local,
 
 static void _apply_daction(daction_type act)
 {
-    ASSERT(act >= 0 && act < NUM_DACTIONS);
+    ASSERT_RANGE(act, 0, NUM_DACTIONS);
     dprf("applying delayed action: %s", daction_names[act]);
 
     switch (act)
@@ -254,6 +267,7 @@ static void _apply_daction(daction_type act)
     case DACT_HOLY_PETS_GO_NEUTRAL:
     case DACT_PIKEL_SLAVES:
     case DACT_KIRKE_HOGS:
+    case DACT_END_SPIRIT_HOWL:
         for (monster_iterator mi; mi; ++mi)
         {
             if (mons_matches_daction(*mi, act))
@@ -310,7 +324,7 @@ static void _daction_hog_to_human(monster *mon, bool in_transit)
     if (mon->props.exists(ORIG_MONSTER_KEY))
     {
         // It was transformed into a pig. Copy it, since the instance in props
-        // will get deleted as soon a **mi is assigned to.
+        // will get deleted as soon as **mi is assigned to.
         orig = mon->props[ORIG_MONSTER_KEY].get_monster();
         orig.mid = mon->mid;
     }
@@ -377,6 +391,5 @@ static void _daction_hog_to_human(monster *mon, bool in_transit)
     if (could_see && !can_see)
         mpr("The hog vanishes!");
     else if (!could_see && can_see)
-        mprf("%s appears from out of thin air!",
-                mon->name(DESC_A).c_str());
+        mprf("%s appears from out of thin air!", mon->name(DESC_A).c_str());
 }
