@@ -16,8 +16,8 @@ function ch_item_wieldable(it)
     -- by Crawl itself.
     local spells = make_hash(you.spells())
 
-    if (spells["Sublimation of Blood"] or spells["Simulacrum"])
-            and food.ischunk(it)
+    if spells["Sublimation of Blood"] and food.ischunk(it)
+            or spells["Simulacrum"] and food.ismeaty(it)
     then
         return true
     end
