@@ -171,6 +171,14 @@ static bool mg_build_dungeon()
         const level_id &lid = places[i];
         you.where_are_you = lid.branch;
         you.depth = lid.depth;
+
+        // An unholy hack, FIXME!
+        if (startdepth[BRANCH_FOREST] == -1
+            && lid.branch == BRANCH_FOREST && lid.depth == 5)
+        {
+            you.unique_creatures.set(MONS_THE_ENCHANTRESS, false);
+        }
+
         if (!mg_do_build_level(1))
             return false;
     }
@@ -199,7 +207,8 @@ static void mg_build_levels(int niters)
         dlua.callfn("dgn_clear_data", "");
         you.uniq_map_tags.clear();
         you.uniq_map_names.clear();
-        you.unique_creatures.init(false);
+        you.unique_creatures.reset();
+        initialise_branch_depths();
         init_level_connectivity();
         if (!mg_build_dungeon())
             break;
