@@ -84,24 +84,6 @@ static void _handle_macro_delay();
 static void _finish_delay(const delay_queue_item &delay);
 static const char *_activity_interrupt_name(activity_interrupt_type ai);
 
-static int _zin_recite_to_monsters(coord_def where, int prayertype, int, actor *)
-{
-    ASSERT(prayertype >= 0 && prayertype < NUM_RECITE_TYPES);
-    return zin_recite_to_single_monster(where, (recite_type)prayertype);
-}
-
-static string _get_zin_recite_speech(int trits[], size_t len, int prayertype, int step)
-{
-    const string str = zin_recite_text(trits, len, prayertype, step);
-
-    if (str.empty())
-    {
-        // In case nothing is found.
-        return "mumble mumble buggy mumble";
-    }
-    return str;
-}
-
 // Returns true if this delay can act as a parent to other delays, i.e. if
 // other delays can be spawned while this delay is running. If is_parent_delay
 // returns true, new delays will be pushed immediately to the front of the
@@ -261,12 +243,6 @@ void stop_delay(bool stop_stair_travel, bool force_unsafe)
         _pop_delay();
         break;
 
-    case DELAY_RECITE:
-        mprf(MSGCH_PLAIN, "Your recitation is interrupted.");
-        mpr("You feel short of breath.");
-        _pop_delay();
-        break;
-
     case DELAY_RUN:
     case DELAY_REST:
     case DELAY_TRAVEL:
@@ -709,21 +685,6 @@ void handle_delay()
             mpr("You begin to meditate on the wall.", MSGCH_MULTITURN_ACTION);
             break;
 
-        case DELAY_RECITE:
-        {
-            // We need to handle training here.
-            practise(EX_USED_ABIL, ABIL_ZIN_RECITE);
-
-            // We don't actually start reciting on this turn, because we haven't "said" anything yet.
-            delay.len = 7;
-            for (size_t n = 0; n < delay.len; n++)
-                delay.trits[n] = random2(3);
-            mprf(MSGCH_PLAIN, "You clear your throat and prepare to recite %s.",
-                 _get_zin_recite_speech(delay.trits, delay.len,
-                                        delay.parm1, -1).c_str());
-            break;
-        }
-
         default:
             break;
         }
@@ -865,14 +826,6 @@ void handle_delay()
             return;
         }
     }
-    else if (delay.type == DELAY_RECITE)
-    {
-        if (you.hp*2 < delay.parm2) // ...or significant health drop.
-        {
-            stop_delay();
-            return;
-        }
-    }
 
     // Handle delay:
     if (delay.duration > 0)
@@ -924,42 +877,6 @@ void handle_delay()
                 MSGCH_MULTITURN_ACTION);
             break;
 
-        case DELAY_RECITE:
-        {
-            mprf(MSGCH_MULTITURN_ACTION, "\"%s\"",
-                 _get_zin_recite_speech(delay.trits, delay.len,
-                                        delay.parm1, delay.duration).c_str());
-            if (apply_area_visible(_zin_recite_to_monsters, delay.parm1))
-                viewwindow();
-
-            // Recite trains more than once per use, because it has a
-            // long timer in between uses and actually takes up multiple
-            // turns.
-            practise(EX_USED_ABIL, ABIL_ZIN_RECITE);
-
-            const string shout_verb = you.shout_verb();
-
-            int noise_level = 12; // "shout"
-
-            // Tweak volume for different kinds of vocalisation.
-            if (shout_verb == "roar")
-                noise_level = 18;
-
-            else if (shout_verb == "hiss")
-                noise_level = 8;
-            else if (shout_verb == "squeak")
-                noise_level = 4;
-            else if (shout_verb == "__NONE")
-                noise_level = 0;
-            else if (shout_verb == "yell")
-                noise_level = 14;
-            else if (shout_verb == "scream")
-                noise_level = 16;
-
-            noisy(noise_level, you.pos());
-            break;
-        }
-
         case DELAY_MULTIDROP:
             if (!drop_item(items_for_multidrop[0].slot,
                            items_for_multidrop[0].quantity))
@@ -1098,25 +1015,6 @@ static void _finish_delay(const delay_queue_item &delay)
         break;
     }
 
-    case DELAY_RECITE:
-    {
-        string speech = _get_zin_recite_speech(const_cast<int*>(delay.trits),
-                                               delay.len, delay.parm1, -1);
-        speech += ".";
-        if (one_chance_in(9))
-        {
-            const string closure = getSpeakString("recite_closure");
-            if (!closure.empty() && one_chance_in(3))
-            {
-                speech += " ";
-                speech += closure;
-            }
-        }
-        mprf(MSGCH_PLAIN, "You finish reciting %s", speech.c_str());
-        mpr("You feel short of breath.");
-        break;
-    }
-
     case DELAY_PASSWALL:
     {
         mpr("You finish merging with the rock.");
@@ -1218,7 +1116,7 @@ static void _finish_delay(const delay_queue_item &delay)
                      mitm[delay.parm1].name(DESC_THE).c_str());
 
                 if (god_hates_cannibalism(you.religion)
-                    && is_player_same_species(item.mon_type))
+                    && is_player_same_genus(item.mon_type))
                 {
                     simple_god_message(" expects more respect for your"
                                        " departed relatives.");
@@ -1229,7 +1127,7 @@ static void _finish_delay(const delay_queue_item &delay)
                     simple_god_message(" expects more respect for holy"
                                        " creatures!");
                 }
-                else if (you.religion == GOD_ZIN
+                else if (you_worship(GOD_ZIN)
                          && mons_class_intel(item.mon_type) >= I_NORMAL)
                 {
                     simple_god_message(" expects more respect for this"
@@ -1396,6 +1294,15 @@ static command_type _get_running_command()
     return direction_to_command(you.running.pos.x, you.running.pos.y);
 }
 
+static bool _auto_eat(delay_type type)
+{
+    return Options.auto_eat_chunks
+           && (!you.gourmand()
+               || you.duration[DUR_GOURMAND] >= GOURMAND_MAX / 4
+               || you.hunger_state < HS_SATIATED)
+           && (type == DELAY_REST || type == DELAY_TRAVEL);
+}
+
 static void _handle_run_delays(const delay_queue_item &delay)
 {
     // Handle inconsistencies between the delay queue and you.running.
@@ -1418,14 +1325,14 @@ static void _handle_run_delays(const delay_queue_item &delay)
         stop_running();
     else
     {
-        if (Options.auto_eat_chunks)
+        if (_auto_eat(delay.type))
         {
             const interrupt_block block_interrupts;
             if (prompt_eat_chunks(true) == 1)
                 return;
         }
 
-        if (Options.auto_sacrifice == OPT_YES
+        if (Options.auto_sacrifice == AS_YES
             && you.running == RMODE_EXPLORE_GREEDY)
         {
             LevelStashes *lev = StashTrack.find_current_level();
@@ -1541,6 +1448,7 @@ void run_macro(const char *macroname)
         }
     }
 #else
+    UNUSED(_decrement_delay);
     stop_delay();
 #endif
 }
@@ -1562,7 +1470,7 @@ static maybe_bool _userdef_interrupt_activity(const delay_queue_item &idelay,
     const int delay = idelay.type;
     lua_State *ls = clua.state();
     if (!ls || ai == AI_FORCE_INTERRUPT)
-        return B_TRUE;
+        return MB_TRUE;
 
     const char *interrupt_name = _activity_interrupt_name(ai);
     const char *act_name = delay_name(delay);
@@ -1575,23 +1483,24 @@ static maybe_bool _userdef_interrupt_activity(const delay_queue_item &idelay,
         if (lua_isnil(ls, -1))
         {
             lua_pop(ls, 1);
-            return B_FALSE;
+            return MB_FALSE;
         }
 
         bool stopact = lua_toboolean(ls, -1);
         lua_pop(ls, 1);
         if (stopact)
-            return B_TRUE;
+            return MB_TRUE;
     }
 
     if (delay == DELAY_MACRO && clua.callbooleanfn(true, "c_interrupt_macro",
                                                    "sA", interrupt_name, &at))
     {
-        return B_TRUE;
+        return MB_TRUE;
     }
-
+#else
+    UNUSED(_activity_interrupt_name);
 #endif
-    return B_MAYBE;
+    return MB_MAYBE;
 }
 
 // Returns true if the activity should be interrupted, false otherwise.
@@ -1601,11 +1510,11 @@ static bool _should_stop_activity(const delay_queue_item &item,
 {
     switch (_userdef_interrupt_activity(item, ai, at))
     {
-    case B_TRUE:
+    case MB_TRUE:
         return true;
-    case B_FALSE:
+    case MB_FALSE:
         return false;
-    case B_MAYBE:
+    case MB_MAYBE:
         break;
     }
 
@@ -1705,6 +1614,8 @@ static inline bool _monster_warning(activity_interrupt_type ai,
             text += " opens the gate.";
         else if (at.context == SC_TELEPORT_IN)
             text += " appears from thin air!";
+        else if (at.context == SC_LEAP_IN)
+            text += " leaps into view!";
         // The monster surfaced and submerged in the same turn without
         // doing anything else.
         else if (at.context == SC_SURFACES_BRIEFLY)
@@ -1831,11 +1742,8 @@ bool interrupt_activity(activity_interrupt_type ai,
     }
 
     // If we get hungry while traveling, let's try to auto-eat a chunk.
-    if (delay_is_run(delay) && ai == AI_HUNGRY
-        && Options.auto_eat_chunks && prompt_eat_chunks(true) == 1)
-    {
+    if (ai == AI_HUNGRY && _auto_eat(delay) && prompt_eat_chunks(true) == 1)
         return false;
-    }
 
     dprf("Activity interrupt: %s", _activity_interrupt_name(ai));
 
@@ -1843,7 +1751,7 @@ bool interrupt_activity(activity_interrupt_type ai,
     const delay_queue_item &item = you.delay_queue.front();
 
     if (ai == AI_FULL_HP)
-        mpr("HP restored.");
+        mprf("%s restored.", you.species == SP_DJINNI ? "EP" : "HP");
     else if (ai == AI_FULL_MP)
         mpr("Magic restored.");
 
@@ -1920,7 +1828,11 @@ static const char *delay_names[] =
     "not_delayed", "eat", "vampire_feed", "armour_on", "armour_off",
     "jewellery_on", "memorise", "butcher", "bottle_blood", "weapon_swap",
     "passwall", "drop_item", "multidrop", "ascending_stairs",
-    "descending_stairs", "recite", "run", "rest", "travel", "macro",
+    "descending_stairs",
+#if TAG_MAJOR_VERSION == 34
+    "recite",
+#endif
+    "run", "rest", "travel", "macro",
     "macro_process_key", "interruptible", "uninterruptible"
 };
 
