@@ -98,7 +98,8 @@ void seen_notable_thing(dungeon_feature_type which_thing, const coord_def& pos)
 
 bool move_notable_thing(const coord_def& orig, const coord_def& dest)
 {
-    ASSERT(in_bounds(orig) && in_bounds(dest));
+    ASSERT_IN_BOUNDS(orig);
+    ASSERT_IN_BOUNDS(dest);
     ASSERT(orig != dest);
     ASSERT(!is_notable_terrain(grd(dest)));
 
@@ -127,49 +128,27 @@ static string coloured_branch(branch_type br)
     if (br < 0 || br >= NUM_BRANCHES)
         return "<lightred>Buggy buglands</lightred>";
 
-    colour_t col;
-    switch (br)
-    {
-    // These make little sense: old code used the first colour of elemental
-    // colour used for the entrance portal.
-    case BRANCH_VESTIBULE_OF_HELL: col = RED; break;
-    case BRANCH_ABYSS:             col = MAGENTA; break; // ETC_RANDOM
-    case BRANCH_PANDEMONIUM:       col = BLUE; break;
-    case BRANCH_LABYRINTH:         col = CYAN; break;
-    case BRANCH_BAILEY:            col = LIGHTRED; break;
-    case BRANCH_BAZAAR:
-    case BRANCH_WIZLAB:
-    case BRANCH_ZIGGURAT:          col = BLUE; break; // ETC_SHIMMER_BLUE
-    case BRANCH_ICE_CAVE:          col = WHITE; break;
-    case BRANCH_OSSUARY:           col = BROWN; break;
-    case BRANCH_SEWER:             col = LIGHTGREEN; break;
-    case BRANCH_TROVE:             col = BLUE; break;
-    case BRANCH_VOLCANO:           col = RED; break;
-    default:                       col = YELLOW; // shouldn't happen
-    }
-
-    const string colname = colour_to_str(col);
-    return make_stringf("<%s>%s</%s>", colname.c_str(), branches[br].shortname,
-                        colname.c_str());
+    return make_stringf("<yellow>%s</yellow>", branches[br].shortname);
 }
 
 static string shoptype_to_string(shop_type s)
 {
     switch (s)
     {
-    case SHOP_WEAPON:          return "(";
+    case SHOP_WEAPON:          return "<w>(</w>";
     case SHOP_WEAPON_ANTIQUE:  return "<yellow>(</yellow>";
-    case SHOP_ARMOUR:          return "[";
+    case SHOP_ARMOUR:          return "<w>[</w>";
     case SHOP_ARMOUR_ANTIQUE:  return "<yellow>[</yellow>";
-    case SHOP_GENERAL:         return "*";
+    case SHOP_GENERAL:         return "<w>*</w>";
     case SHOP_GENERAL_ANTIQUE: return "<yellow>*</yellow>";
-    case SHOP_JEWELLERY:       return "=";
-    case SHOP_WAND:            return "/";
-    case SHOP_BOOK:            return "+";
-    case SHOP_FOOD:            return "%";
-    case SHOP_DISTILLERY:      return "!";
-    case SHOP_SCROLL:          return "?";
-    default:                   return "x";
+    case SHOP_JEWELLERY:       return "<w>=</w>";
+    case SHOP_WAND:            return "<w>/</w>";
+    case SHOP_BOOK:            return "<w>+</w>";
+    case SHOP_FOOD:            return "<w>%</w>";
+    case SHOP_DISTILLERY:      return "<w>!</w>";
+    case SHOP_SCROLL:          return "<w>?</w>";
+    case SHOP_MISCELLANY:      return "<w>}</w>";
+    default:                   return "<w>x</w>";
     }
 }
 
@@ -332,22 +311,32 @@ static string _get_unseen_branches()
 
     /* see if we need to hide lair branches that don't exist */
     int seen_lair_branches = 0;
+    int seen_vaults_branches = 0;
     for (int i = BRANCH_FIRST_NON_DUNGEON; i < NUM_BRANCHES; i++)
     {
         const branch_type branch = branches[i].id;
 
-        if (!is_random_lair_subbranch(branch))
+        if (!is_random_subbranch(branch))
             continue;
 
         if (stair_level.find(branch) != stair_level.end())
-            seen_lair_branches++;
+        {
+            if (parent_branch((branch_type)i) == BRANCH_LAIR)
+                seen_lair_branches++;
+            else if (parent_branch((branch_type)i) == BRANCH_VAULTS)
+                seen_vaults_branches++;
+        }
     }
 
     for (int i = BRANCH_FIRST_NON_DUNGEON; i < NUM_BRANCHES; i++)
     {
         const branch_type branch = branches[i].id;
 
-        if (seen_lair_branches >= 2 && is_random_lair_subbranch(branch))
+        if (is_random_subbranch(branch)
+            && ((parent_branch((branch_type)i) == BRANCH_LAIR
+                 && seen_lair_branches >= 2)
+                || (parent_branch((branch_type)i) == BRANCH_VAULTS)
+                    && seen_vaults_branches >= 1))
             continue;
 
         if (i == BRANCH_VESTIBULE_OF_HELL || !is_connected_branch(branch))
@@ -358,8 +347,11 @@ static string _get_unseen_branches()
 
         if (stair_level.find(branch) == stair_level.end())
         {
-            const branch_type parent_branch = branches[i].parent_branch;
-            level_id lid(parent_branch, 0);
+            const branch_type parent = parent_branch((branch_type)i);
+            // Root branches.
+            if (parent == NUM_BRANCHES)
+                continue;
+            level_id lid(parent, 0);
             lid = find_deepest_explored(lid);
             if (lid.depth >= branches[branch].mindepth)
             {
@@ -368,7 +360,7 @@ static string _get_unseen_branches()
                     snprintf(buffer, sizeof buffer,
                         "<darkgrey>%6s: %s:%d-%d</darkgrey>",
                             branches[branch].abbrevname,
-                            branches[parent_branch].abbrevname,
+                            branches[parent].abbrevname,
                             branches[branch].mindepth,
                             branches[branch].maxdepth);
                 }
@@ -377,7 +369,7 @@ static string _get_unseen_branches()
                     snprintf(buffer, sizeof buffer,
                         "<darkgrey>%6s: %s:%d</darkgrey>",
                             branches[branch].abbrevname,
-                            branches[parent_branch].abbrevname,
+                            branches[parent].abbrevname,
                             branches[branch].mindepth);
                 }
 
@@ -461,12 +453,12 @@ static string _print_altars_for_gods(const vector<god_type>& gods,
         if (has_altar_been_seen)
             colour = "white";
         // Good gods don't inflict penance unless they hate your god.
-        if (you.penance[god] && (!is_good_god(god) || god_hates_your_god(god)))
+        if (player_under_penance(god) && (!is_good_god(god) || god_hates_your_god(god)))
             colour = (you.penance[god] > 10) ? "red" : "lightred";
         // Indicate good gods that you've abandoned, though.
-        else if (you.penance[god])
+        else if (player_under_penance(god))
             colour = "magenta";
-        else if (you.religion == god)
+        else if (you_worship(god))
             colour = "yellow";
         else if (god_likes_your_god(god) && has_altar_been_seen)
             colour = "brown";
@@ -492,9 +484,9 @@ static string _print_altars_for_gods(const vector<god_type>& gods,
                     break;
             case 2: disp += string(18 - strwidth(god_name(god, false)), ' ');
                     break;
-            case 3: disp += string(13 - strwidth(god_name(god, false)), ' ');
+            case 3: disp += string(16 - strwidth(god_name(god, false)), ' ');
                     break;
-            case 4: disp += string(16 - strwidth(god_name(god, false)), ' ');
+            case 4: disp += string(13 - strwidth(god_name(god, false)), ' ');
             }
     }
 
@@ -519,9 +511,11 @@ static string _get_shops(bool display)
     last_id.depth = 10000;
     map<level_pos, shop_type>::const_iterator ci_shops;
 
-    // There are at most 5 shops per level, plus 7 chars for the level
-    // name, plus 4 for the spacing; that makes a total of 17
-    // characters per shop.
+    // There are at most 5 shops per level, plus up to 8 chars for the
+    // level name, plus 4 for the spacing (3 as padding + 1 separating
+    // items from level). That makes a total of 17 characters per shop:
+    //       1...5....0....5..
+    // "D:8 *   Vaults:2 **([+   D:24 +";
     const int maxcolumn = get_number_of_cols() - 17;
     int column_count = 0;
 
@@ -537,19 +531,18 @@ static string _get_shops(bool display)
             }
             else if (column_count != 0)
             {
-                disp += "  ";
-                column_count += 2;
+                disp += "   ";
+                column_count += 3;
             }
-            disp += "<brown>";
+            disp += "<lightgrey>";
 
             const string loc = ci_shops->first.id.describe(false, true);
             disp += loc;
             column_count += strwidth(loc);
 
-            disp += ": ";
-            disp += "</brown>";
-
-            column_count += 2;
+            disp += " ";
+            disp += "</lightgrey>";
+            column_count += 1;
 
             last_id = ci_shops->first.id;
         }
@@ -590,7 +583,7 @@ static string _get_notes()
 
     if (disp.empty())
         return disp;
-    return "\n<green>Annotations</green>\n" + disp;
+    return "\n<green>Annotations:</green>\n" + disp;
 }
 
 template <typename Z, typename Key>
@@ -864,11 +857,8 @@ string get_level_annotation(level_id li, bool skip_excl, bool skip_uniq,
 
 static const string _get_coloured_level_annotation(level_id li)
 {
-    string place = "<yellow>" + li.describe();
-    place = replace_all(place, ":", "</yellow>:");
-    if (place.find("</yellow>") == string::npos)
-        place += "</yellow>";
-    int col = level_annotation_has("!", li) ? LIGHTRED : MAGENTA;
+    string place = "<yellow>" + li.describe() + "</yellow>";
+    int col = level_annotation_has("!", li) ? LIGHTRED : WHITE;
     return place + " " + get_level_annotation(li, false, false, true, col);
 }
 
@@ -903,10 +893,11 @@ void annotate_level()
 
 void do_annotate(level_id& li)
 {
-    if (!get_level_annotation(li).empty())
+    string old = get_level_annotation(li, true, true);
+    if (!old.empty())
     {
         mpr("Current level annotation: " +
-            colour_string(get_level_annotation(li, true, true), LIGHTGREY),
+            colour_string(old, LIGHTGREY),
             MSGCH_PROMPT);
     }
 
@@ -914,16 +905,15 @@ void do_annotate(level_id& li)
                           + " (include '!' for warning): ";
 
     char buf[77];
-    if (msgwin_get_line_autohist(prompt, buf, sizeof(buf)))
-        return;
-
-    if (*buf)
-        level_annotations[li] = buf;
-    else if (get_level_annotation(li, true).empty())
+    if (msgwin_get_line_autohist(prompt, buf, sizeof(buf), old))
         canned_msg(MSG_OK);
-    else if (yesno("Really clear the annotation?", true, 'n'))
+    else if (old == buf)
+        canned_msg(MSG_OK);
+    else if (*buf)
+        level_annotations[li] = buf;
+    else
     {
-        mpr("Cleared.");
+        mpr("Cleared annotation.");
         level_annotations.erase(li);
     }
 }
