@@ -36,6 +36,7 @@
 #include "exercise.h"
 #include "fight.h"
 #include "fprop.h"
+#include "godabil.h"
 #include "godpassive.h"
 #include "hints.h"
 #include "hiscores.h"
@@ -49,6 +50,7 @@
 #include "message.h"
 #include "mgen_data.h"
 #include "misc.h"
+#include "mislead.h"
 #include "mon-behv.h"
 #include "mon-cast.h"
 #include "mon-iter.h"
@@ -64,6 +66,7 @@
 #include "player-stats.h"
 #include "player.h"
 #include "religion.h"
+#include "shopping.h"
 #include "shout.h"
 #include "skills.h"
 #include "skills2.h"
@@ -83,7 +86,7 @@
 
 static void _update_corpses(int elapsedTime);
 
-static void _holy_word_player(int pow, int caster, actor *attacker)
+static void _holy_word_player(int pow, holy_word_source_type source, actor *attacker)
 {
     if (!you.undead_or_demonic())
         return;
@@ -103,42 +106,38 @@ static void _holy_word_player(int pow, int caster, actor *attacker)
 
     const char *aux = "holy word";
 
-    kill_method_type type = KILLED_BY_MONSTER;
-    if (invalid_monster_index(caster))
+    kill_method_type type = KILLED_BY_SOMETHING;
+    if (crawl_state.is_god_acting())
+        type = KILLED_BY_DIVINE_WRATH;
+
+    switch (source)
     {
-        type = KILLED_BY_SOMETHING;
-        if (crawl_state.is_god_acting())
-            type = KILLED_BY_DIVINE_WRATH;
+    case HOLY_WORD_SCROLL:
+        aux = "scroll of holy word";
+        break;
 
-        switch (caster)
-        {
-        case HOLY_WORD_SCROLL:
-            aux = "scroll of holy word";
-            break;
+    case HOLY_WORD_ZIN:
+        aux = "Zin's holy word";
+        break;
 
-        case HOLY_WORD_ZIN:
-            aux = "Zin's holy word";
-            break;
-
-        case HOLY_WORD_TSO:
-            aux = "the Shining One's holy word";
-            break;
-        }
+    case HOLY_WORD_TSO:
+        aux = "the Shining One's holy word";
+        break;
     }
 
-    ouch(hploss, caster, type, aux);
+    ouch(hploss, NON_MONSTER, type, aux);
 
     return;
 }
 
-void holy_word_monsters(coord_def where, int pow, int caster,
+void holy_word_monsters(coord_def where, int pow, holy_word_source_type source,
                         actor *attacker)
 {
     pow = min(300, pow);
 
     // Is the player in this cell?
     if (where == you.pos())
-        _holy_word_player(pow, caster, attacker);
+        _holy_word_player(pow, source, attacker);
 
     // Is a monster in this cell?
     monster* mons = monster_at(where);
@@ -153,11 +152,11 @@ void holy_word_monsters(coord_def where, int pow, int caster,
     else
         hploss = roll_dice(3, 15) + (random2(pow) / 10);
 
-    if (hploss && caster != HOLY_WORD_ZIN)
-        simple_monster_message(mons, " convulses!");
-    if (hploss && caster == HOLY_WORD_ZIN)
-        simple_monster_message(mons, " is blasted by Zin's holy word!");
-
+    if (hploss)
+        if (source == HOLY_WORD_ZIN)
+            simple_monster_message(mons, " is blasted by Zin's holy word!");
+        else
+            simple_monster_message(mons, " convulses!");
     mons->hurt(attacker, hploss, BEAM_MISSILE);
 
     if (!hploss || !mons->alive())
@@ -178,8 +177,8 @@ void holy_word_monsters(coord_def where, int pow, int caster,
     }
 }
 
-void holy_word(int pow, int caster, const coord_def& where, bool silent,
-               actor *attacker)
+void holy_word(int pow, holy_word_source_type source, const coord_def& where,
+               bool silent, actor *attacker)
 {
     if (!silent && attacker)
     {
@@ -192,7 +191,7 @@ void holy_word(int pow, int caster, const coord_def& where, bool silent,
     los_def los(where);
     los.update();
     for (radius_iterator ri(&los); ri; ++ri)
-        holy_word_monsters(*ri, pow, caster, attacker);
+        holy_word_monsters(*ri, pow, source, attacker);
 }
 
 int torment_player(actor *attacker, int taux)
@@ -209,7 +208,7 @@ int torment_player(actor *attacker, int taux)
         // Negative energy resistance can alleviate torment.
         hploss = max(0, you.hp * (50 - player_prot_life() * 5) / 100 - 1);
         // Statue form is only partial petrification.
-        if (you.form == TRAN_STATUE)
+        if (you.form == TRAN_STATUE || you.species == SP_GARGOYLE)
             hploss /= 2;
     }
 
@@ -343,8 +342,7 @@ int torment(actor *attacker, int taux, const coord_def& where)
     return r;
 }
 
-void immolation(int pow, int caster, coord_def where, bool known,
-                actor *attacker)
+void immolation(int pow, immolation_source_type source, bool known)
 {
     ASSERT(!crawl_state.game_is_arena());
 
@@ -352,7 +350,7 @@ void immolation(int pow, int caster, coord_def where, bool known,
 
     bolt beam;
 
-    switch (caster)
+    switch (source)
     {
     case IMMOLATION_SCROLL:
         aux = "a scroll of immolation";
@@ -372,35 +370,16 @@ void immolation(int pow, int caster, coord_def where, bool known,
     beam.flavour       = BEAM_FIRE;
     beam.glyph         = dchar_glyph(DCHAR_FIRED_BURST);
     beam.damage        = dice_def(3, pow);
-    beam.target        = where;
+    beam.target        = you.pos();
     beam.name          = "fiery explosion";
     beam.colour        = RED;
     beam.aux_source    = aux;
     beam.ex_size       = 2;
     beam.is_explosion  = true;
     beam.effect_known  = known;
-    beam.affects_items = caster != IMMOLATION_SCROLL
-                         && caster != IMMOLATION_AFFIX;
-
-    if (caster == IMMOLATION_GENERIC)
-    {
-        beam.thrower     = KILL_MISC;
-        beam.beam_source = NON_MONSTER;
-    }
-    else if (attacker && attacker->is_player())
-    {
-        beam.thrower     = KILL_YOU;
-        beam.beam_source = NON_MONSTER;
-    }
-    else
-    {
-        // If there was no attacker, caster should have been IMMOLATION_GENERIC
-        // which we handled above.
-        ASSERT(attacker);
-
-        beam.thrower     = KILL_MON;
-        beam.beam_source = attacker->mindex();
-    }
+    beam.affects_items = source == IMMOLATION_TOME;
+    beam.thrower       = KILL_YOU;
+    beam.beam_source   = NON_MONSTER;
 
     beam.explode();
 }
@@ -551,8 +530,11 @@ void banished(const string &who)
     down_stairs(DNGN_ENTER_ABYSS);  // heh heh
 
     // Xom just might decide to interfere.
-    if (you.religion == GOD_XOM && who != "Xom" && who != "wizard command")
+    if (you_worship(GOD_XOM) && who != "Xom" && who != "wizard command"
+        && who != "a distortion unwield")
+    {
         xom_maybe_reverts_banishment(false, false);
+    }
 }
 
 bool forget_spell(void)
@@ -619,7 +601,7 @@ void direct_effect(monster* source, spell_type spell,
             simple_monster_message(def, " is struck by the twisting air!");
         else
         {
-            if (you.flight_mode())
+            if (you.flight_mode() || djinni_floats())
                 mpr("The air twists around and violently strikes you in flight!");
             else
                 mpr("The air twists around and strikes you!");
@@ -638,6 +620,28 @@ void direct_effect(monster* source, spell_type spell,
         damage_taken = defender->apply_ac(random2avg(damage_taken, 3));
         break;
 
+    case SPELL_WATERSTRIKE:
+        if (feat_is_water(grd(defender->pos())))
+        {
+            if (defender->is_player() || you.can_see(defender))
+            {
+                if (defender->flight_mode())
+                    mprf("The water rises up and strikes %s!", defender->name(DESC_THE).c_str());
+                else
+                    mprf("The water swirls and strikes %s!", defender->name(DESC_THE).c_str());
+            }
+
+            pbolt.name       = "waterstrike";
+            pbolt.flavour    = BEAM_WATER;
+            pbolt.aux_source = "by the raging water";
+
+            damage_taken     = roll_dice(3, 8 + source->hit_dice);
+
+            damage_taken = defender->beam_resists(pbolt, damage_taken, false);
+            damage_taken = defender->apply_ac(damage_taken);
+        }
+        break;
+
     case SPELL_BRAIN_FEED:
         if (!def)
         {
@@ -890,8 +894,10 @@ static bool _follows_orders(monster* mon)
     return (mon->friendly()
             && mon->type != MONS_GIANT_SPORE
             && mon->type != MONS_BATTLESPHERE
-            && !mon->berserk()
-            && !mons_is_projectile(mon->type));
+            && mon->type != MONS_SPECTRAL_WEAPON
+            && !mon->berserk_or_insane()
+            && !mon->is_projectile()
+            && !mon->has_ench(ENCH_HAUNTING));
 }
 
 // Sets foe target of friendly monsters.
@@ -947,6 +953,12 @@ void yell(bool force)
 {
     ASSERT(!crawl_state.game_is_arena());
 
+    if (you.duration[DUR_WATER_HOLD] && !you.res_water_drowning())
+    {
+        mpr("You cannot shout while unable to breathe!");
+        return;
+    }
+
     bool targ_prev = false;
     int mons_targd = MHITNOT;
     dist targ;
@@ -1004,7 +1016,10 @@ void yell(bool force)
 
     if (force)
     {
-        mprf("A %s rips itself from your throat!", shout_verb.c_str());
+        if (you.duration[DUR_RECITE])
+            mpr("You feel yourself shouting your recitation.");
+        else
+            mprf("A %s rips itself from your throat!", shout_verb.c_str());
         noisy(noise_level, you.pos());
         return;
     }
@@ -1043,6 +1058,7 @@ void yell(bool force)
              shout_verb.c_str(),
              you.berserk() ? " wildly" : " for attention");
         noisy(noise_level, you.pos());
+        zin_recite_interrupt();
         you.turn_is_over = true;
         return;
 
@@ -1177,6 +1193,7 @@ void yell(bool force)
         return;
     }
 
+    zin_recite_interrupt();
     you.turn_is_over = true;
     you.pet_target = mons_targd;
     // Allow patrolling for "Stop fighting!" and "Wait here!"
@@ -1226,7 +1243,7 @@ bool vitrify_area(int radius)
 
 static void _hell_effects()
 {
-    if ((you.religion == GOD_ZIN && x_chance_in_y(you.piety, MAX_PIETY))
+    if ((you_worship(GOD_ZIN) && x_chance_in_y(you.piety, MAX_PIETY))
         || is_sanctuary(you.pos()))
     {
         simple_god_message("'s power protects you from the chaos of Hell!");
@@ -1236,15 +1253,14 @@ static void _hell_effects()
     string msg = getMiscString("hell_effect");
     if (msg.empty())
         msg = "Something hellishly buggy happens.";
-    msg_channel_type chan = MSGCH_PLAIN;
-    strip_channel_prefix(msg, chan);
-    mpr(msg.c_str(), chan);
-    if (chan == MSGCH_SOUND)
+    bool loud = starts_with(msg, "SOUND:");
+    if (loud)
+        msg.erase(0, 6);
+    mpr(msg.c_str(), MSGCH_HELL_EFFECT);
+    if (loud)
         noisy(15, you.pos());
 
     spschool_flag_type which_miscast = SPTYP_RANDOM;
-    bool summon_instead = false;
-    monster_type which_beastie = MONS_NO_MONSTER;
 
     int temp_rand = random2(27);
     if (temp_rand > 17)     // 9 in 27 odds {dlb}
@@ -1266,49 +1282,36 @@ static void _hell_effects()
     }
     else if (temp_rand > 7) // 10 in 27 odds {dlb}
     {
-        // 60:40 miscast:summon split {dlb}
-        summon_instead = x_chance_in_y(2, 5);
+        monster_type which_beastie;
 
+        // 60:40 miscast:summon split {dlb}
         switch (you.where_are_you)
         {
         case BRANCH_DIS:
-            if (summon_instead)
-                which_beastie = summon_any_demon(RANDOM_DEMON_GREATER);
-            else
-                which_miscast = SPTYP_EARTH;
+            which_beastie = RANDOM_DEMON_GREATER;
+            which_miscast = SPTYP_EARTH;
             break;
 
         case BRANCH_GEHENNA:
-            if (summon_instead)
-                which_beastie = MONS_BRIMSTONE_FIEND;
-            else
-                which_miscast = SPTYP_FIRE;
+            which_beastie = MONS_BRIMSTONE_FIEND;
+            which_miscast = SPTYP_FIRE;
             break;
 
         case BRANCH_COCYTUS:
-            if (summon_instead)
-                which_beastie = MONS_ICE_FIEND;
-            else
-                which_miscast = SPTYP_ICE;
+            which_beastie = MONS_ICE_FIEND;
+            which_miscast = SPTYP_ICE;
             break;
 
         case BRANCH_TARTARUS:
-            if (summon_instead)
-                which_beastie = MONS_SHADOW_FIEND;
-            else
-                which_miscast = SPTYP_NECROMANCY;
+            which_beastie = MONS_SHADOW_FIEND;
+            which_miscast = SPTYP_NECROMANCY;
             break;
 
         default:
-            // This is to silence gcc compiler warnings. {dlb}
-            if (summon_instead)
-                which_beastie = MONS_BRIMSTONE_FIEND;
-            else
-                which_miscast = SPTYP_NECROMANCY;
-            break;
+            die("unknown hell branch");
         }
 
-        if (summon_instead)
+        if (x_chance_in_y(2, 5))
         {
             create_monster(
                 mgen_data::hostile_at(which_beastie, "the effects of Hell",
@@ -1385,7 +1388,7 @@ static bool _feat_is_flanked_by_walls(const coord_def &p)
 // also have to be floor flanked by walls.
 //
 //   czd
-//   a.b   -> if (a, b == walls) then (c, d == walls) or return (false)
+//   a.b   -> if (a, b == walls) then (c, d == walls) or return false
 //   #X#
 //    .
 //
@@ -1600,7 +1603,7 @@ void change_labyrinth(bool msg)
                                          min((int) targets.size(), 45));
 
     // Shuffle the targets, then pick the max_targets first ones.
-    random_shuffle(targets.begin(), targets.end(), random2);
+    shuffle_array(targets);
 
     // For each of the chosen wall grids, calculate the path connecting the
     // two floor grids to either side, and block off one floor grid on this
@@ -1801,7 +1804,7 @@ void change_labyrinth(bool msg)
                  ri->x, ri->y);
         }
         // Search the eight possible directions in random order.
-        random_shuffle(dirs.begin(), dirs.end(), random2);
+        shuffle_array(dirs);
         for (unsigned int i = 0; i < dirs.size(); i++)
         {
             const coord_def p = *ri + dirs[i];
@@ -2069,6 +2072,106 @@ static void _rot_inventory_food(int time_delta)
     }
 }
 
+static void _handle_magic_contamination()
+{
+    int added_contamination = 0;
+
+    // Scale has been increased by a factor of 1000, but the effect now happens
+    // every turn instead of every 20 turns, so everything has been multiplied
+    // by 50 and scaled to you.time_taken.
+
+    if (you.duration[DUR_INVIS])
+        added_contamination += 30;
+
+    if (you.duration[DUR_HASTE])
+        added_contamination += 30;
+
+    // Is there a point to this? It's not even strong enough to cancel normal
+    // dissipation, so it only slows it down. Shouldn't it cancel dissipation
+    // like haste and invis do?
+    if (you.duration[DUR_FINESSE])
+        added_contamination += 20;
+
+    if (you.duration[DUR_REGENERATION] && you.species == SP_DJINNI)
+        added_contamination += 30;
+
+    // The Orb halves dissipation (well a bit more, I had to round it),
+    // but won't cause glow on its own -- otherwise it'd spam the player
+    // with messages about contamination oscillating near zero.
+    if (you.magic_contamination && orb_haloed(you.pos()))
+        added_contamination += 13;
+
+    // Normal dissipation
+    if (!you.duration[DUR_INVIS] && !you.duration[DUR_HASTE])
+        added_contamination -= 25;
+
+    // Scaling to turn length
+    added_contamination = div_rand_round(added_contamination * you.time_taken,
+                                         BASELINE_DELAY);
+
+    contaminate_player(added_contamination, false);
+}
+
+static void _magic_contamination_effects()
+{
+    // [ds] Move magic contamination effects closer to b26 again.
+    const bool glow_effect = you.species == SP_DJINNI ?
+        get_contamination_level() > 2
+            && x_chance_in_y(you.magic_contamination, 24000):
+        get_contamination_level() > 1
+            && x_chance_in_y(you.magic_contamination, 12000);
+
+    if (glow_effect && is_sanctuary(you.pos()))
+    {
+        mpr("Your body momentarily shudders from a surge of wild "
+            "energies until Zin's power calms it.", MSGCH_GOD);
+    }
+    else if (glow_effect)
+    {
+        mpr("Your body shudders with the violent release "
+            "of wild energies!", MSGCH_WARN);
+
+        // For particularly violent releases, make a little boom.
+        if (you.magic_contamination > 10000 && coinflip())
+        {
+            bolt beam;
+
+            beam.flavour      = BEAM_RANDOM;
+            beam.glyph        = dchar_glyph(DCHAR_FIRED_BURST);
+            beam.damage       = dice_def(3,
+                                 div_rand_round(you.magic_contamination, 2000));
+            beam.target       = you.pos();
+            beam.name         = "magical storm";
+            beam.beam_source  = NON_MONSTER;
+            beam.aux_source   = "a magical explosion";
+            beam.ex_size      = max(1, min(9,
+                               div_rand_round(you.magic_contamination, 15000)));
+            beam.ench_power   = div_rand_round(you.magic_contamination, 200);
+            beam.is_explosion = true;
+
+            // Undead enjoy extra contamination explosion damage because
+            // the magical contamination has a harder time dissipating
+            // through non-living flesh. :-)
+            if (you.is_undead)
+                beam.damage.size *= 2;
+
+            beam.explode();
+        }
+
+        // We want to warp the player, not do good stuff!
+        mutate(one_chance_in(5) ? RANDOM_MUTATION : RANDOM_BAD_MUTATION,
+               "mutagenic glow", true,
+               coinflip(),
+               false, false, false, false,
+               you.species == SP_DJINNI);
+
+        // we're meaner now, what with explosions and whatnot, but
+        // we dial down the contamination a little faster if its actually
+        // mutating you.  -- GDL
+        contaminate_player(-(random2(you.magic_contamination / 4) + 1000));
+    }
+}
+
 // Get around C++ dividing integers towards 0.
 static int _div(int num, int denom)
 {
@@ -2100,6 +2203,10 @@ void handle_time()
     if (player_in_branch(BRANCH_LABYRINTH) || player_in_branch(BRANCH_ABYSS))
         forget_map(true);
 
+    // Magic contamination from spells and Orb.
+    if (!crawl_state.game_is_arena())
+        _handle_magic_contamination();
+
     // Every 20 turns, a variety of other effects.
     if (! (_div(base_time, 200) > _div(old_time, 200)))
         return;
@@ -2154,7 +2261,7 @@ void handle_time()
         // If Cheibriados has slowed your biology, disease might
         // not actually do anything.
         if (one_chance_in(30)
-            && !(you.religion == GOD_CHEIBRIADOS
+            && !(you_worship(GOD_CHEIBRIADOS)
                  && you.piety >= piety_breakpoint(0)
                  && coinflip()))
         {
@@ -2163,6 +2270,10 @@ void handle_time()
         }
     }
 
+    // Bad effects from magic contamination.
+    if (coinflip())
+        _magic_contamination_effects();
+
     // Adjust the player's stats if s/he has the deterioration mutation.
     if (player_mutation_level(MUT_DETERIORATION)
         && x_chance_in_y(player_mutation_level(MUT_DETERIORATION) * 5 - 1, 200))
@@ -2170,95 +2281,12 @@ void handle_time()
         lose_stat(STAT_RANDOM, 1, false, "deterioration mutation");
     }
 
-    int added_contamination = 0;
-
-    // Account for mutagenic radiation.  Invis and haste will give the
-    // player about .1 points per turn, mutagenic randarts will give
-    // about 1.5 points on average, so they can corrupt the player
-    // quite quickly.  Wielding one for a short battle is OK, which is
-    // as things should be.   -- GDL
-    if (you.duration[DUR_INVIS] && x_chance_in_y(6, 10))
-        added_contamination++;
-
-    if (you.duration[DUR_HASTE] && x_chance_in_y(6, 10))
-        added_contamination++;
-
-    if (you.duration[DUR_FINESSE] && x_chance_in_y(4, 10))
-        added_contamination++;
-
-    // The Orb adds .25 points per turn (effectively halving dissipation),
-    // but won't cause glow on its own -- otherwise it'd spam the player
-    // with messages about contamination oscillating near zero.
-    if (you.magic_contamination && orb_haloed(you.pos()) && one_chance_in(4))
-        added_contamination++;
-
-    // We take off about .5 points per turn.
-    if (!you.duration[DUR_INVIS] && !you.duration[DUR_HASTE] && coinflip())
-        added_contamination--;
-
-    // Don't punish for this contamination.
-    // (Haste and invisibility already penalised earlier).
-    contaminate_player(added_contamination, false);
-
-    // Only check for badness once every other turn.
-    if (coinflip())
-    {
-        // [ds] Move magic contamination effects closer to b26 again.
-        const bool glow_effect =
-            (get_contamination_level() > 1
-             && x_chance_in_y(you.magic_contamination, 12));
-
-        if (glow_effect && is_sanctuary(you.pos()))
-        {
-            mpr("Your body momentarily shudders from a surge of wild "
-                "energies until Zin's power calms it.", MSGCH_GOD);
-        }
-        else if (glow_effect)
-        {
-            mpr("Your body shudders with the violent release "
-                "of wild energies!", MSGCH_WARN);
-
-            // For particularly violent releases, make a little boom.
-            // Undead enjoy extra contamination explosion damage because
-            // the magical contamination has a harder time dissipating
-            // through non-living flesh. :-)
-            if (you.magic_contamination > 10 && coinflip())
-            {
-                bolt beam;
-
-                beam.flavour      = BEAM_RANDOM;
-                beam.glyph        = dchar_glyph(DCHAR_FIRED_BURST);
-                beam.damage       = dice_def(3, you.magic_contamination
-                                             * (you.is_undead ? 4 : 2) / 4);
-                beam.target       = you.pos();
-                beam.name         = "magical storm";
-                beam.beam_source  = NON_MONSTER;
-                beam.aux_source   = "a magical explosion";
-                beam.ex_size      = max(1, min(9, you.magic_contamination / 15));
-                beam.ench_power   = you.magic_contamination * 5;
-                beam.is_explosion = true;
-
-                beam.explode();
-            }
-
-            // We want to warp the player, not do good stuff!
-            if (one_chance_in(5))
-                mutate(RANDOM_MUTATION, "mutagenic glow");
-            else
-                give_bad_mutation("mutagenic glow", true, coinflip());
-
-            // we're meaner now, what with explosions and whatnot, but
-            // we dial down the contamination a little faster if its actually
-            // mutating you.  -- GDL
-            contaminate_player(-(random2(you.magic_contamination / 4) + 1));
-        }
-    }
-
     // Check to see if an upset god wants to do something to the player.
     handle_god_time();
 
     if (player_mutation_level(MUT_SCREAM)
-        && x_chance_in_y(3 + player_mutation_level(MUT_SCREAM) * 3, 100))
+        && x_chance_in_y(3 + player_mutation_level(MUT_SCREAM) * 3, 100)
+        && !(you.duration[DUR_WATER_HOLD] && !you.res_water_drowning()))
     {
         yell(true);
     }
@@ -2276,7 +2304,7 @@ void handle_time()
     {
         // Update the abyss speed. This place is unstable and the speed can
         // fluctuate. It's not a constant increase.
-        if (you.religion == GOD_CHEIBRIADOS && coinflip())
+        if (you_worship(GOD_CHEIBRIADOS) && coinflip())
             ; // Speed change less often for Chei.
         else if (coinflip() && you.abyss_speed < 100)
             ++you.abyss_speed;
@@ -2284,7 +2312,7 @@ void handle_time()
             --you.abyss_speed;
     }
 
-    if (you.religion == GOD_JIYVA && one_chance_in(10))
+    if (you_worship(GOD_JIYVA) && one_chance_in(10))
     {
         int total_jellies = 1 + random2(5);
         bool success = false;
@@ -2327,13 +2355,13 @@ void handle_time()
         }
     }
 
-    if (you.religion == GOD_JIYVA && x_chance_in_y(you.piety / 4, MAX_PIETY)
+    if (you_worship(GOD_JIYVA) && x_chance_in_y(you.piety / 4, MAX_PIETY)
         && !player_under_penance() && one_chance_in(4))
     {
         jiyva_stat_action();
     }
 
-    if (you.religion == GOD_JIYVA && one_chance_in(25))
+    if (you_worship(GOD_JIYVA) && one_chance_in(25))
         jiyva_eat_offlevel_items();
 
     if (int lev = player_mutation_level(MUT_EVOLUTION))
@@ -2371,11 +2399,26 @@ static void _catchup_monster_moves(monster* mon, int turns)
     if (!mon->alive())
         return;
 
+    // Expire friendly summons
+    if (mon->friendly() && mon->is_summoned() && !mon->is_perm_summoned())
+    {
+        // You might still see them disappear if you were quick
+        if (turns > 2)
+            monster_die(mon, KILL_DISMISSED, NON_MONSTER);
+        else
+        {
+            mon_enchant abj  = mon->get_ench(ENCH_ABJ);
+            abj.duration = 0;
+            mon->update_ench(abj);
+        }
+        return;
+    }
+
     // Don't move non-land or stationary monsters around.
     if (mons_primary_habitat(mon) != HT_LAND
         || mons_is_zombified(mon)
            && mons_class_primary_habitat(mon->base_monster) != HT_LAND
-        || mons_is_stationary(mon))
+        || mon->is_stationary())
     {
         return;
     }
@@ -2384,7 +2427,7 @@ static void _catchup_monster_moves(monster* mon, int turns)
     if (mon->type == MONS_GIANT_SPORE)
         return;
 
-    if (mon->type == MONS_ORB_OF_DESTRUCTION)
+    if (mon->is_projectile())
     {
         iood_catchup(mon, turns);
         return;
@@ -2420,6 +2463,7 @@ static void _catchup_monster_moves(monster* mon, int turns)
         x = 500;
         break;
     case I_ANIMAL:
+    case I_REPTILE:
     case I_INSECT:
         x = 250;
         break;
@@ -2683,7 +2727,7 @@ int place_ring(vector<coord_def> &ring_points,
                int arc_occupancy,
                int &seen_count)
 {
-    random_shuffle(ring_points.begin(), ring_points.end());
+    shuffle_array(ring_points);
 
     int target_amount = ring_points.size();
     int spawned_count = 0;
@@ -2916,7 +2960,7 @@ int spawn_corpse_mushrooms(item_def& corpse,
 
         // Is this square occupied by a non mushroom?
         if (mons && mons->mons_species() != MONS_TOADSTOOL
-            || player_occupant && you.religion != GOD_FEDHAS
+            || player_occupant && !you_worship(GOD_FEDHAS)
             || !can_spawn_mushrooms(current))
         {
             continue;
@@ -2964,7 +3008,8 @@ int spawn_corpse_mushrooms(item_def& corpse,
                 placed_targets++;
                 if (current == you.pos())
                 {
-                    mprf("A toadstool grows at your feet.");
+                    mprf("A toadstool grows %s.",
+                         player_has_feet() ? "at your feet" : "before you");
                     current = mushroom->pos();
                 }
                 else if (you.see_cell(current))
@@ -2979,7 +3024,7 @@ int spawn_corpse_mushrooms(item_def& corpse,
             break;
 
         // Wish adjacent_iterator had a random traversal.
-        random_shuffle(permutation, permutation+c_size);
+        shuffle_array(permutation, c_size);
 
         for (int count = 0; count < c_size; ++count)
         {
@@ -3069,6 +3114,8 @@ static void _update_corpses(int elapsedTime)
 
         if (it.base_type == OBJ_POTIONS)
         {
+            if (is_shop_item(it))
+                continue;
             maybe_coagulate_blood_potions_floor(c);
             continue;
         }
@@ -3164,9 +3211,9 @@ void slime_wall_damage(actor* act, int delay)
 
     if (act->is_player())
     {
-        if (you.religion != GOD_JIYVA || you.penance[GOD_JIYVA])
+        if (!you_worship(GOD_JIYVA) || you.penance[GOD_JIYVA])
         {
-            splash_with_acid(strength, false,
+            splash_with_acid(strength, NON_MONSTER, false,
                              (walls > 1) ? "The walls burn you!"
                                          : "The wall burns you!");
         }
@@ -3189,3 +3236,29 @@ void slime_wall_damage(actor* act, int delay)
         mon->hurt(NULL, dam, BEAM_ACID);
     }
 }
+
+void recharge_elemental_evokers(int exp)
+{
+    vector<item_def*> evokers;
+    for (int item = 0; item < ENDOFPACK; ++item)
+    {
+        if (is_elemental_evoker(you.inv[item]) && you.inv[item].plus2 > 0)
+            evokers.push_back(&you.inv[item]);
+    }
+
+    int xp_factor = max(min((int)exp_needed(you.experience_level+1, 0) * 2 / 7,
+                             you.experience_level * 425),
+                        you.experience_level*4 + 30)
+                    / (3 + you.skill_rdiv(SK_EVOCATIONS, 2, 13));
+
+    for (unsigned int i = 0; i < evokers.size(); ++i)
+    {
+        item_def* evoker = evokers[i];
+        evoker->plus2 -= div_rand_round(exp, xp_factor);
+        if (evoker->plus2 <= 0)
+        {
+            evoker->plus2 = 0;
+            mprf("Your %s has recharged.", evoker->name(DESC_QUALNAME).c_str());
+        }
+    }
+}
