@@ -49,18 +49,17 @@ void direct_effect(monster* src, spell_type spl, bolt &pbolt, actor *defender);
 
 void yell(bool force = false);
 
-void holy_word(int pow, int caster, const coord_def& where, bool silent = false,
-               actor *attacker = NULL);
+void holy_word(int pow, holy_word_source_type source, const coord_def& where,
+               bool silent = false, actor *attacker = NULL);
 
-void holy_word_monsters(coord_def where, int pow, int caster,
+void holy_word_monsters(coord_def where, int pow, holy_word_source_type source,
                         actor *attacker = NULL);
 
 int torment(actor *attacker, int taux, const coord_def& where);
 int torment_player(actor *attacker, int taux);
 int torment_monsters(coord_def where, actor *attacker, int taux);
 
-void immolation(int pow, int caster, coord_def where, bool known = false,
-                actor *attacker = NULL);
+void immolation(int pow, immolation_source_type source, bool known = false);
 
 void conduct_electricity(coord_def where, actor *attacker);
 
@@ -73,6 +72,7 @@ bool vitrify_area(int radius);
 void update_level(int elapsedTime);
 void handle_time();
 void recharge_rods(int aut, bool floor_only);
+void recharge_elemental_evokers(int exp);
 
 void slime_wall_damage(actor* act, int delay);
 
