@@ -15,7 +15,7 @@ NORETURN void fail(const char *msg, ...)
 {
     va_list args;
     va_start(args, msg);
-    std::string buf = vmake_stringf(msg, args);
+    string buf = vmake_stringf(msg, args);
     va_end(args);
 
     // Do we want to call end() right on when there's no one trying catching,
@@ -27,7 +27,7 @@ NORETURN void sysfail(const char *msg, ...)
 {
     va_list args;
     va_start(args, msg);
-    std::string buf = vmake_stringf(msg, args);
+    string buf = vmake_stringf(msg, args);
     va_end(args);
 
     buf += ": ";
@@ -40,7 +40,7 @@ NORETURN void corrupted(const char *msg, ...)
 {
     va_list args;
     va_start(args, msg);
-    std::string buf = vmake_stringf(msg, args);
+    string buf = vmake_stringf(msg, args);
     va_end(args);
 
     throw corrupted_save(buf);
