@@ -26,6 +26,7 @@ skill_type abil_skill(ability_type abil)
     case ABIL_EVOKE_TURN_INVISIBLE:
     case ABIL_EVOKE_FLIGHT:
     case ABIL_EVOKE_FOG:
+    case ABIL_EVOKE_TELEPORT_CONTROL:
         return SK_EVOCATIONS;
 
     case ABIL_NEMELEX_DRAW_ONE:
@@ -100,6 +101,7 @@ static int _abil_degree(ability_type abil)
     case ABIL_EVOKE_TURN_INVISIBLE:
     case ABIL_EVOKE_FLIGHT:
     case ABIL_EVOKE_FOG:
+    case ABIL_EVOKE_TELEPORT_CONTROL:
         return 1;
 
     case ABIL_NEMELEX_DRAW_ONE:
@@ -222,7 +224,7 @@ static void _exercise_spell(spell_type spell, bool success)
     if (conj && !x_chance_in_y(skillcount, 4))
         return;
 
-    random_shuffle(disc.begin(), disc.end());
+    shuffle_array(disc);
 
     for (unsigned int k = 0; k < disc.size(); ++k)
     {
@@ -323,7 +325,7 @@ void practise(exer_type ex, int param1)
     switch (ex)
     {
     case EX_WILL_STAB:
-        sk = SK_STABBING;
+        sk = SK_STEALTH;
         deg = 1 + random2avg(5, 4);
         exercise(sk, deg);
         break;
@@ -401,37 +403,6 @@ void practise(exer_type ex, int param1)
                         ex == EX_DID_CAST);
         break;
 
-    case EX_TRAP_FOUND:
-        exercise(SK_TRAPS, 1 + random2(2));
-        break;
-
-    case EX_TRAP_PASSIVE:
-        exercise(SK_TRAPS, 3);
-        break;
-
-    case EX_TRAP_TRIGGER:
-        exercise(SK_TRAPS, 1 + random2(2));
-        break;
-
-    case EX_TRAP_DISARM:
-        // param1 == you.absdepth0
-        exercise(SK_TRAPS, 1 + random2(5) + param1 / 5);
-        break;
-
-    case EX_TRAP_DISARM_FAIL:
-        // param1 == you.absdepth0
-        exercise(SK_TRAPS, 1 + random2(param1 / 5));
-        break;
-
-    case EX_TRAP_DISARM_TRIGGER:
-        if (coinflip())
-            exercise(SK_TRAPS, 1);
-        break;
-
-    case EX_REMOVE_NET:
-        exercise(SK_TRAPS, 1);
-        break;
-
     case EX_SHIELD_BLOCK:
         if (coinflip())
             exercise(SK_SHIELDS, 1);
