@@ -7,18 +7,26 @@
 #ifndef FOOD_H
 #define FOOD_H
 
-#define BERSERK_NUTRITION    700
-#define HUNGER_STARVING     1000
-#define HUNGER_DEFAULT      6000
-#define HUNGER_MAXIMUM     12000
+#define BERSERK_NUTRITION     700
+
+#define HUNGER_STARVING      1000
+#define HUNGER_NEAR_STARVING 1533
+#define HUNGER_VERY_HUNGRY   2066
+#define HUNGER_HUNGRY        2600
+#define HUNGER_SATIATED      7000
+#define HUNGER_FULL          9000
+#define HUNGER_VERY_FULL    11000
+#define HUNGER_ENGORGED     40000
+
+#define HUNGER_DEFAULT       6000
+#define HUNGER_MAXIMUM      12000
 
 int count_corpses_in_pack(bool blood_only = false);
 bool butchery(int which_corpse = -1, bool bottle_blood = false);
 
 bool eat_food(int slot = -1);
 
-void make_hungry(int hunger_amount, bool suppress_msg,
-                 bool allow_reducing = false);
+void make_hungry(int hunger_amount, bool suppress_msg, bool magic = false);
 
 void lessen_hunger(int statiated_amount, bool suppress_msg);
 
@@ -60,11 +68,12 @@ void finished_eating_message(int food_type);
 
 int you_max_hunger();
 int you_min_hunger();
-bool you_foodless();
+bool you_foodless(bool can_eat = false);
+// Is the player always foodless or just because of a temporary change?
+bool you_foodless_normally();
 
 void handle_starvation();
 string hunger_cost_string(const int hunger);
-void end_nausea();
 
 maybe_bool drop_spoiled_chunks(int weight_needed, bool whole_slot = false);
 #endif
