@@ -40,7 +40,7 @@ bool is_tide_immune(const coord_def &p);
 bool is_moldy(const coord_def & p);
 bool glowing_mold(const coord_def & p);
 void remove_mold(const coord_def & p);
-feature_property_type str_to_fprop(const std::string &str);
+feature_property_type str_to_fprop(const string &str);
 char blood_rotation(const coord_def & p);
 
 #endif
