@@ -10,12 +10,6 @@
 #include "itemprop-enum.h"
 #include "mon-enum.h"
 
-#ifdef USE_TILE
-int tile_offset_for_labrat_colour(colour_t l_colour);
-#endif
-string adjective_for_labrat_colour(colour_t l_colour);
-colour_t colour_for_labrat_adjective(string adjective);
-
 class ghost_demon
 {
 public:
@@ -41,6 +35,9 @@ public:
 
     monster_spells spells;
 
+    // For some chimera actions, lets us choose as specific part
+    monster_type acting_part;
+
 public:
     ghost_demon();
     bool has_spells() const;
@@ -50,7 +47,11 @@ public:
     void init_ugly_thing(bool very_ugly, bool only_mutate = false,
                          colour_t force_colour = BLACK);
     void init_dancing_weapon(const item_def& weapon, int power);
-    void init_labrat (colour_t force_colour = BLACK);
+    void init_spectral_weapon(const item_def& weapon, int power, int wpn_skill);
+    void init_chimera(monster* mon, monster_type parts[]);
+    bool init_chimera_for_place(monster* mon, level_id place,
+                                monster_type chimera_type, coord_def pos);
+
     void ugly_thing_to_very_ugly_thing();
 
 public:
@@ -67,6 +68,8 @@ private:
     spell_type translate_spell(spell_type playerspell) const;
     void ugly_thing_add_resistance(bool very_ugly,
                                    attack_flavour u_att_flav);
+
+    void _apply_chimera_part(monster* mon, monster_type part, int partnum);
 };
 
 bool debug_check_ghosts();
