@@ -8,6 +8,7 @@
 #include "godmenu.h"
 
 #include "colour.h"
+#include "libutil.h"
 #include "religion.h"
 
 GodMenuEntry::GodMenuEntry(god_type god_, bool long_name) :
@@ -19,21 +20,21 @@ GodMenuEntry::GodMenuEntry(god_type god_, bool long_name) :
     else
     {
         hotkeys.push_back(text.at(0));
-        hotkeys.push_back(tolower(text.at(0)));
+        hotkeys.push_back(toalower(text.at(0)));
     }
     int c = god_message_altar_colour(god);
     colour_text = colour_to_str(c);
     data = &text;
 }
 
-std::string GodMenuEntry::get_text(const bool unused) const
+string GodMenuEntry::get_text(const bool unused) const
 {
     if (level == MEL_ITEM && hotkeys.size())
     {
         char buf[300];
         snprintf(buf, sizeof buf, " <%s>%c</%s> %c %s",  colour_text.c_str(),
                  hotkeys[0], colour_text.c_str(), preselected ? '+' : '-', text.c_str());
-        return std::string(buf);
+        return string(buf);
     }
     return text;
 }
