@@ -50,7 +50,10 @@ static bool _confirm_pray_sacrifice(god_type god)
             prompt += " in it?";
 
             if (!yesno(prompt.c_str(), false, 'n'))
+            {
+                canned_msg(MSG_OK);
                 return false;
+            }
         }
     }
 
@@ -65,13 +68,13 @@ string god_prayer_reaction()
     else
         result += " is ";
     result +=
-        (you.piety > 130) ? "exalted by your worship" :
-        (you.piety > 100) ? "extremely pleased with you" :
-        (you.piety >  70) ? "greatly pleased with you" :
-        (you.piety >  40) ? "most pleased with you" :
-        (you.piety >  20) ? "pleased with you" :
-        (you.piety >   5) ? "noncommittal"
-                          : "displeased";
+        (you.piety >= piety_breakpoint(5)) ? "exalted by your worship" :
+        (you.piety >= piety_breakpoint(4)) ? "extremely pleased with you" :
+        (you.piety >= piety_breakpoint(3)) ? "greatly pleased with you" :
+        (you.piety >= piety_breakpoint(2)) ? "most pleased with you" :
+        (you.piety >= piety_breakpoint(1)) ? "pleased with you" :
+        (you.piety >= piety_breakpoint(0)) ? "aware of your devotion"
+                                           : "noncommittal";
     result += ".";
 
     return result;
@@ -81,13 +84,9 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
 {
     item_def& wpn = *you.weapon();
 
-    if (wpn.base_type != OBJ_WEAPONS
-        || (is_range_weapon(wpn)
-            && (brand != SPWPN_HOLY_WRATH || wpn.sub_type == WPN_BLOWGUN))
-        || is_artefact(wpn))
-    {
+    // Only TSO allows blessing ranged weapons.
+    if (!is_brandable_weapon(wpn, brand == SPWPN_HOLY_WRATH))
         return false;
-    }
 
     string prompt = "Do you wish to have " + wpn.name(DESC_YOUR)
                        + " ";
@@ -100,7 +99,10 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
     prompt += "?";
 
     if (!yesno(prompt.c_str(), true, 'n'))
+    {
+        canned_msg(MSG_OK);
         return false;
+    }
 
     you.duration[DUR_WEAPON_BRAND] = 0;     // just in case
 
@@ -138,7 +140,7 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
     }
 
     you.wield_change = true;
-    you.one_time_ability_used[god] = true;
+    you.one_time_ability_used.set(god);
     calc_mp(); // in case the old brand was antimagic
     string desc  = old_name + " ";
             desc += (god == GOD_SHINING_ONE   ? "blessed by the Shining One" :
@@ -199,15 +201,14 @@ static bool _altar_prayer()
     bool did_something = false;
 
     // donate gold to gain piety distributed over time
-    if (you.religion == GOD_ZIN)
+    if (you_worship(GOD_ZIN))
         did_something = _zin_donate_gold();
 
     // TSO blesses weapons with holy wrath, and long blades and demon
     // whips specially.
-    if (you.religion == GOD_SHINING_ONE
-        && !you.one_time_ability_used[GOD_SHINING_ONE]
-        && !player_under_penance()
-        && you.piety > 160)
+    if (you_worship(GOD_SHINING_ONE) && !player_under_penance()
+        && you.piety >= piety_breakpoint(5)
+        && !you.one_time_ability_used[GOD_SHINING_ONE])
     {
         item_def *wpn = you.weapon();
 
@@ -221,10 +222,9 @@ static bool _altar_prayer()
     }
 
     // Lugonu blesses weapons with distortion.
-    if (you.religion == GOD_LUGONU
-        && !you.one_time_ability_used[GOD_LUGONU]
-        && !player_under_penance()
-        && you.piety > 160)
+    if (you_worship(GOD_LUGONU) && !player_under_penance()
+        && you.piety >= piety_breakpoint(5)
+        && !you.one_time_ability_used[GOD_LUGONU])
     {
         item_def *wpn = you.weapon();
 
@@ -233,10 +233,9 @@ static bool _altar_prayer()
     }
 
     // Kikubaaqudgha blesses weapons with pain, or gives you a Necronomicon.
-    if (you.religion == GOD_KIKUBAAQUDGHA
-        && !you.one_time_ability_used[GOD_KIKUBAAQUDGHA]
-        && !player_under_penance()
-        && you.piety > 160)
+    if (you_worship(GOD_KIKUBAAQUDGHA) && !player_under_penance()
+        && you.piety >= piety_breakpoint(5)
+        && !you.one_time_ability_used[GOD_KIKUBAAQUDGHA])
     {
         if (you.species != SP_FELID)
         {
@@ -256,7 +255,10 @@ static bool _altar_prayer()
 
             // If not, ask if the player wants a Necronomicon.
             if (!yesno("Do you wish to receive the Necronomicon?", true, 'n'))
+            {
+                canned_msg(MSG_OK);
                 return false;
+            }
         }
 
         int thing_created = items(1, OBJ_BOOKS, BOOK_NECRONOMICON, true, 1,
@@ -273,7 +275,7 @@ static bool _altar_prayer()
             simple_god_message(" grants you a gift!");
             more();
 
-            you.one_time_ability_used[you.religion] = true;
+            you.one_time_ability_used.set(you.religion);
             did_something = true;
             take_note(Note(NOTE_GOD_GIFT, you.religion));
         }
@@ -300,7 +302,7 @@ void pray()
     const god_type altar_god = feat_altar_god(grd(you.pos()));
     if (altar_god != GOD_NO_GOD)
     {
-        if (you.religion != GOD_NO_GOD && altar_god == you.religion)
+        if (!you_worship(GOD_NO_GOD) && altar_god == you.religion)
             something_happened = _altar_prayer();
         else if (altar_god != GOD_NO_GOD)
         {
@@ -318,13 +320,13 @@ void pray()
         }
     }
 
-    if (you.religion == GOD_NO_GOD)
+    if (you_worship(GOD_NO_GOD))
     {
         const mon_holy_type holi = you.holiness();
 
         mprf(MSGCH_PRAY,
              "You spend a moment contemplating the meaning of %s.",
-             holi == MH_NONLIVING || holi == MH_UNDEAD ? "existence" : "life");
+             holi == MH_NONLIVING ? "existence" : holi == MH_UNDEAD ? "unlife" : "life");
 
         // Zen meditation is timeless.
         return;
@@ -333,13 +335,13 @@ void pray()
     mprf(MSGCH_PRAY, "You offer a prayer to %s.",
          god_name(you.religion).c_str());
 
-    if (you.religion == GOD_FEDHAS && fedhas_fungal_bloom())
+    if (you_worship(GOD_FEDHAS) && fedhas_fungal_bloom())
         something_happened = true;
 
     // All sacrifices affect items you're standing on.
     something_happened |= _offer_items();
 
-    if (you.religion == GOD_XOM)
+    if (you_worship(GOD_XOM))
         mpr(getSpeakString("Xom prayer"), MSGCH_GOD);
     else if (player_under_penance())
         simple_god_message(" demands penance!");
@@ -426,7 +428,10 @@ static bool _zin_donate_gold()
     }
 
     if (!yesno("Do you wish to donate half of your money?", true, 'n'))
+    {
+        canned_msg(MSG_OK);
         return false;
+    }
 
     const int donation_cost = (you.gold / 2) + 1;
     const int donation = _gold_to_donation(donation_cost);
@@ -466,18 +471,19 @@ static bool _zin_donate_gold()
     {
         string result = "You feel that " + god_name(GOD_ZIN) + " will soon be ";
         result +=
-            (estimated_piety > 130) ? "exalted by your worship" :
-            (estimated_piety > 100) ? "extremely pleased with you" :
-            (estimated_piety >  70) ? "greatly pleased with you" :
-            (estimated_piety >  40) ? "most pleased with you" :
-            (estimated_piety >  20) ? "pleased with you" :
-            (estimated_piety >   5) ? "noncommittal"
-                                    : "displeased";
-        result += (donation >= 30 && you.piety <= 170) ? "!" : ".";
+            (estimated_piety >= piety_breakpoint(5)) ? "exalted by your worship" :
+            (estimated_piety >= piety_breakpoint(4)) ? "extremely pleased with you" :
+            (estimated_piety >= piety_breakpoint(3)) ? "greatly pleased with you" :
+            (estimated_piety >= piety_breakpoint(2)) ? "most pleased with you" :
+            (estimated_piety >= piety_breakpoint(1)) ? "pleased with you" :
+            (estimated_piety >= piety_breakpoint(0)) ? "aware of your devotion"
+                                                     : "noncommittal";
+        result += (donation >= 30 && you.piety < piety_breakpoint(5)) ? "!" : ".";
 
         mpr(result.c_str());
     }
 
+    zin_recite_interrupt();
     return true;
 }
 
@@ -499,7 +505,7 @@ static int _leading_sacrifice_group()
 
 static void _give_sac_group_feedback(int which)
 {
-    ASSERT(which >= 0 && which < 5);
+    ASSERT_RANGE(which, 0, 5);
     const char* names[] = {
         "Escape", "Destruction", "Dungeons", "Summoning", "Wonder"
     };
@@ -549,10 +555,10 @@ static bool _destroyed_valuable_weapon(int value, int type)
 
 static piety_gain_t _sac_corpse(const item_def& item)
 {
-    if (you.religion == GOD_OKAWARU)
+    if (you_worship(GOD_OKAWARU))
     {
         monster dummy;
-        dummy.type = (monster_type)(item.orig_monnum ? item.orig_monnum - 1
+        dummy.type = (monster_type)(item.orig_monnum ? item.orig_monnum
                                                      : item.plus);
         if (item.props.exists(MONSTER_NUMBER))
             dummy.number   = item.props[MONSTER_NUMBER].get_short();
@@ -647,7 +653,7 @@ static piety_gain_t _sacrifice_one_item_noncount(const item_def& item,
 
     case GOD_BEOGH:
     {
-        const int item_orig = item.orig_monnum - 1;
+        const int item_orig = item.orig_monnum;
 
         int chance = 4;
 
@@ -823,7 +829,7 @@ static bool _offer_items()
         }
 
         // Skip items you don't want to sacrifice right now.
-        if (you.religion == GOD_NEMELEX_XOBEH
+        if (you_worship(GOD_NEMELEX_XOBEH)
             && !check_nemelex_sacrificing_item_type(item))
         {
             i = next;
@@ -859,7 +865,7 @@ static bool _offer_items()
         num_sacced++;
     }
 
-    if (num_sacced > 0 && you.religion == GOD_NEMELEX_XOBEH)
+    if (num_sacced > 0 && you_worship(GOD_NEMELEX_XOBEH))
     {
         const int new_leading = _leading_sacrifice_group();
         if (old_leading != new_leading || one_chance_in(50))
@@ -884,17 +890,17 @@ static bool _offer_items()
         // sacrifices.
         else if (god_likes_fresh_corpses(you.religion))
             simple_god_message(" only cares about fresh corpses!");
-        else if (you.religion == GOD_BEOGH)
+        else if (you_worship(GOD_BEOGH))
             simple_god_message(" only cares about orcish remains!");
-        else if (you.religion == GOD_NEMELEX_XOBEH)
+        else if (you_worship(GOD_NEMELEX_XOBEH))
             if (disliked_item->base_type == OBJ_GOLD)
                 simple_god_message(" does not care about gold!");
             else
                 simple_god_message(" expects you to use your decks, not offer them!");
-        else if (you.religion == GOD_ASHENZARI)
+        else if (you_worship(GOD_ASHENZARI))
             simple_god_message(" can corrupt only scrolls of remove curse.");
     }
-    if (num_sacced == 0 && you.religion == GOD_ELYVILON)
+    if (num_sacced == 0 && you_worship(GOD_ELYVILON))
     {
         mprf("There are no %sweapons here to destroy!",
              you.piety_max[GOD_ELYVILON] < piety_breakpoint(2) ? "" : "unholy or evil ");
