@@ -8,10 +8,11 @@
 
 #include "religion-enum.h"
 
-std::string god_prayer_reaction();
+string god_prayer_reaction();
 void pray();
 
-piety_gain_t sacrifice_item_stack(const item_def& item, int *js = 0);
+piety_gain_t sacrifice_item_stack(const item_def& item, int *js = 0,
+                                  int quantity = 0);
 bool check_nemelex_sacrificing_item_type(const item_def& item);
 int zin_tithe(item_def& item, int quant, bool quiet, bool converting = false);
 
