@@ -135,7 +135,7 @@ typedef uint32_t uchar_t;
  * Validate a single UTF-8 character starting at @s.
  * The string must be null-terminated.
  *
- * If it's valid, return its length (1 thru 4).
+ * If it's valid, return its length (1 through 4).
  * If it's invalid or clipped, return 0.
  *
  * This function implements the syntax given in RFC3629, which is
@@ -345,7 +345,7 @@ static void to_surrogate_pair(uchar_t unicode, uint16_t *uc, uint16_t *lc)
 {
     uchar_t n;
 
-    ASSERT(unicode >= 0x10000 && unicode <= 0x10FFFF);
+    ASSERT_RANGE(unicode, 0x10000, 0x10FFFF + 1);
 
     n = unicode - 0x10000;
     *uc = ((n >> 10) & 0x3FF) | 0xD800;
