@@ -336,12 +336,14 @@ static int l_item_do_subtype(lua_State *ls)
                    s = "porridge";
                 else if (item->sub_type == POT_BERSERK_RAGE)
                    s = "berserk";
+#if TAG_MAJOR_VERSION == 34
                 else if (item->sub_type == POT_GAIN_STRENGTH
                          || item->sub_type == POT_GAIN_DEXTERITY
                          || item->sub_type == POT_GAIN_INTELLIGENCE)
                 {
                    s = "gain ability";
                 }
+#endif
                 else if (item->sub_type == POT_CURE_MUTATION)
                    s = "cure mutation";
             }
@@ -479,7 +481,7 @@ IDEF(equip_type)
     else if (item->base_type == OBJ_ARMOUR)
         eq = get_armour_slot(*item);
     else if (item->base_type == OBJ_JEWELLERY)
-        eq = item->sub_type >= AMU_RAGE? EQ_AMULET : EQ_RINGS;
+        eq = item->sub_type >= AMU_RAGE ? EQ_AMULET : EQ_RINGS;
 
     if (eq != EQ_NONE)
     {
@@ -621,6 +623,16 @@ IDEF(snakable)
     return 1;
 }
 
+IDEF(god_gift)
+{
+    if (!item || !item->defined())
+        return 0;
+
+    lua_pushboolean(ls, origin_is_god_gift(*item));
+
+    return 1;
+}
+
 // DLUA-only functions
 static int l_item_do_pluses(lua_State *ls)
 {
@@ -1038,6 +1050,7 @@ static ItemAccessor item_attrs[] =
     { "artefact",          l_item_artefact },
     { "branded",           l_item_branded },
     { "snakable",          l_item_snakable },
+    { "god_gift",          l_item_god_gift },
     { "class",             l_item_class },
     { "subtype",           l_item_subtype },
     { "cursed",            l_item_cursed },
