@@ -10,6 +10,7 @@
 #include "mon-behv.h"
 #include "mon-util.h"
 #include "mon-stuff.h"
+#include "monster.h"
 
 #define WRAPPED_MONSTER(ls, name)                                       \
     MonsterWrap *___mw = clua_get_userdata< MonsterWrap >(ls, MONS_METATABLE); \
@@ -250,8 +251,8 @@ static int l_mons_set_hp(lua_State *ls)
         luaL_argerror(ls, 1, "hp must be positive");
         return 0;
     }
-    hp = std::min(hp, mons->max_hit_points);
-    mons->hit_points = std::min(hp, MAX_MONSTER_HP);
+    hp = min(hp, mons->max_hit_points);
+    mons->hit_points = min(hp, MAX_MONSTER_HP);
     return 0;
 }
 MDEFN(set_hp, set_hp)
@@ -269,7 +270,7 @@ static int l_mons_set_max_hp(lua_State *ls)
         luaL_argerror(ls, 1, "maxhp must be positive");
         return 0;
     }
-    mons->max_hit_points = std::min(maxhp, MAX_MONSTER_HP);
+    mons->max_hit_points = min(maxhp, MAX_MONSTER_HP);
     mons->hit_points = mons->max_hit_points;
     return 0;
 }
@@ -344,7 +345,7 @@ static int l_mons_do_set_prop(lua_State *ls)
     }
     else
     {
-        std::string err
+        string err
             = make_stringf("Don't know how to set monster property of the "
                            "given value type for property '%s'", prop_name);
         luaL_argerror(ls, 2, err.c_str());
@@ -369,7 +370,7 @@ static int l_mons_do_get_prop(lua_State *ls)
     {
         if (lua_isboolean(ls, 2))
         {
-            std::string err = make_stringf("Don't have a property called '%s'.", prop_name);
+            string err = make_stringf("Don't have a property called '%s'.", prop_name);
             luaL_argerror(ls, 2, err.c_str());
         }
 
@@ -431,8 +432,7 @@ static int l_mons_do_add_ench(lua_State *ls)
     enchant_type met = name_to_ench(ench_name);
     if (!met)
     {
-        std::string err
-            = make_stringf("No such enchantment: %s", ench_name);
+        string err = make_stringf("No such enchantment: %s", ench_name);
         luaL_argerror(ls, 1, err.c_str());
         return 0;
     }
@@ -455,8 +455,7 @@ static int l_mons_do_del_ench(lua_State *ls)
     enchant_type met = name_to_ench(ench_name);
     if (!met)
     {
-        std::string err
-            = make_stringf("No such enchantment: %s", ench_name);
+        string err = make_stringf("No such enchantment: %s", ench_name);
         luaL_argerror(ls, 1, err.c_str());
         return 0;
     }
@@ -546,7 +545,8 @@ static const char *_monster_behaviour_names[] = {
     "cornered",
     "panic",
     "lurk",
-    "retreat"
+    "retreat",
+    "withdraw"
 };
 
 static const char* _behaviour_name(beh_type beh)
@@ -557,7 +557,7 @@ static const char* _behaviour_name(beh_type beh)
         return "invalid";
 }
 
-static beh_type behaviour_by_name(const std::string &name)
+static beh_type behaviour_by_name(const string &name)
 {
     COMPILE_CHECK(ARRAYSZ(_monster_behaviour_names) == NUM_BEHAVIOURS);
 
