@@ -139,7 +139,6 @@ LUARET1(you_teleporting, boolean, you.duration[DUR_TELEPORT])
 LUARET1(you_poisoned, boolean, you.duration[DUR_POISONING])
 LUARET1(you_invisible, boolean, you.duration[DUR_INVIS])
 LUARET1(you_mesmerised, boolean, you.duration[DUR_MESMERISED])
-LUARET1(you_nauseous, boolean, you.duration[DUR_NAUSEA])
 LUARET1(you_on_fire, boolean, you.duration[DUR_LIQUID_FLAMES])
 LUARET1(you_petrifying, boolean, you.duration[DUR_PETRIFYING])
 LUARET1(you_silencing, boolean, you.duration[DUR_SILENCE])
@@ -157,10 +156,13 @@ LUARET1(you_contaminated, number, get_contamination_level())
 LUARET1(you_feel_safe, boolean, i_feel_safe())
 LUARET1(you_deaths, number, you.deaths)
 LUARET1(you_lives, number, you.lives)
+LUARET1(you_antimagic, boolean, you.duration[DUR_ANTIMAGIC])
 
 LUARET1(you_where, string, level_id::current().describe().c_str())
 LUARET1(you_branch, string, level_id::current().describe(false, false).c_str())
 LUARET1(you_depth, number, you.depth)
+LUARET1(you_depth_fraction, number,
+        (float)you.depth / brdepth[you.where_are_you])
 // [ds] Absolute depth is 1-based for Lua to match things like DEPTH:
 // which are also 1-based. Yes, this is confusing. FIXME: eventually
 // change you.absdepth0 to be 1-based as well.
@@ -239,6 +241,27 @@ static int l_you_spell_letters(lua_State *ls)
     return 1;
 }
 
+static int l_you_spell_table(lua_State *ls)
+{
+    lua_newtable(ls);
+
+    char buf[2];
+    buf[1] = 0;
+
+    for (int i = 0; i < 52; ++i)
+    {
+        buf[0] = index_to_letter(i);
+        const spell_type spell = get_spell_by_letter(buf[0]);
+        if (spell == SPELL_NO_SPELL)
+            continue;
+
+        lua_pushstring(ls, buf);
+        lua_pushstring(ls, spell_title(spell));
+        lua_rawset(ls, -3);
+    }
+    return 1;
+}
+
 static int l_you_abils(lua_State *ls)
 {
     lua_newtable(ls);
@@ -269,6 +292,24 @@ static int l_you_abil_letters(lua_State *ls)
     return 1;
 }
 
+static int l_you_abil_table(lua_State *ls)
+{
+    lua_newtable(ls);
+
+    char buf[2];
+    buf[1] = 0;
+
+    vector<talent> talents = your_talents(false);
+    for (int i = 0, size = talents.size(); i < size; ++i)
+    {
+        buf[0] = talents[i].hotkey;
+        lua_pushstring(ls, buf);
+        lua_pushstring(ls, ability_name(talents[i].which));
+        lua_rawset(ls, -3);
+    }
+    return 1;
+}
+
 static int you_can_consume_corpses(lua_State *ls)
 {
     lua_pushboolean(ls,
@@ -316,13 +357,11 @@ LUAFN(you_mutation)
     string mutname = luaL_checkstring(ls, 1);
     for (int i = 0; i < NUM_MUTATIONS; ++i)
     {
-        mutation_type mut = static_cast<mutation_type>(i);
-        if (!is_valid_mutation(mut))
+        const char *wizname = mutation_name(static_cast<mutation_type>(i));
+        if (!wizname)
             continue;
-
-        const mutation_def& mdef = get_mutation_def(mut);
-        if (!strcmp(mutname.c_str(), mdef.wizname))
-            PLUARET(integer, you.mutation[mut]);
+        if (!strcmp(mutname.c_str(), wizname))
+            PLUARET(integer, you.mutation[i]);
     }
 
     string err = make_stringf("No such mutation: '%s'.", mutname.c_str());
@@ -372,8 +411,10 @@ static const struct luaL_reg you_clib[] =
     { "time"        , you_time },
     { "spells"      , l_you_spells },
     { "spell_letters", l_you_spell_letters },
+    { "spell_table" , l_you_spell_table },
     { "abilities"   , l_you_abils },
     { "ability_letters", l_you_abil_letters },
+    { "ability_table", l_you_abil_table },
     { "name"        , you_name },
     { "race"        , you_race },
     { "class"       , you_class },
@@ -426,7 +467,6 @@ static const struct luaL_reg you_clib[] =
     { "poisoned",     you_poisoned },
     { "invisible",    you_invisible },
     { "mesmerised",   you_mesmerised },
-    { "nauseous",     you_nauseous },
     { "on_fire",      you_on_fire },
     { "petrifying",   you_petrifying },
     { "silencing",    you_silencing },
@@ -448,6 +488,7 @@ static const struct luaL_reg you_clib[] =
     { "burden",       you_burden },
     { "constricted",  you_constricted },
     { "constricting", you_constricting },
+    { "antimagic",    you_antimagic },
 
     { "god_likes_fresh_corpses",  you_god_likes_fresh_corpses },
     { "can_consume_corpses",      you_can_consume_corpses },
@@ -460,6 +501,7 @@ static const struct luaL_reg you_clib[] =
     { "where",        you_where },
     { "branch",       you_branch },
     { "depth",        you_depth },
+    { "depth_fraction", you_depth_fraction },
     { "absdepth",     you_absdepth },
     { "is_level_on_stack", you_is_level_on_stack },
 
@@ -538,7 +580,10 @@ static int _you_uniques(lua_State *ls)
     bool unique_found = false;
 
     if (lua_gettop(ls) >= 1 && lua_isstring(ls, 1))
-        unique_found = you.unique_creatures[get_monster_by_name(lua_tostring(ls, 1))];
+    {
+        unique_found =
+            you.unique_creatures[get_monster_by_name(lua_tostring(ls, 1))];
+    }
 
     lua_pushboolean(ls, unique_found);
     return 1;
