@@ -10,6 +10,7 @@ class crawl_view_buffer;
 
 int get_number_of_lines();
 int get_number_of_cols();
+int num_to_lines(int num);
 
 void clrscr(void);
 void clear_to_end_of_line();
@@ -34,7 +35,7 @@ void enable_smart_cursor(bool cursor);
 bool is_smart_cursor_enabled();
 void set_mouse_enabled(bool enabled);
 
-inline void put_colour_ch(int colour, unsigned ch)
+static inline void put_colour_ch(int colour, unsigned ch)
 {
     textcolor(colour);
     putwch(ch);
