@@ -6,7 +6,6 @@
 #ifndef MAKEITEM_H
 #define MAKEITEM_H
 
-#include "decks.h"
 #include "itemprop-enum.h"
 
 enum item_make_species_type
@@ -19,8 +18,7 @@ enum item_make_species_type
     MAKE_ITEM_RANDOM_RACE = 250,
 };
 
-int create_item_named(std::string name, coord_def pos,
-                      std::string *error);
+int create_item_named(string name, coord_def pos, string *error);
 
 int items(bool allow_uniques, object_class_type force_class, int force_type,
            bool dont_place, int item_level, int item_race,
