@@ -164,6 +164,7 @@ public:
     coord_def corpse_pos;
 };
 
+#if TAG_MAJOR_VERSION == 34
 // A marker for sealed doors
 class map_door_seal_marker : public map_marker
 {
@@ -184,6 +185,59 @@ public:
     int mon_num;
     dungeon_feature_type old_feature;
 };
+#endif
+
+// A marker for temporary terrain changes
+class map_terrain_change_marker : public map_marker
+{
+public:
+    map_terrain_change_marker (const coord_def& pos = coord_def(0, 0),
+                    dungeon_feature_type oldfeat = DNGN_FLOOR,
+                    dungeon_feature_type newfeat = DNGN_FLOOR,
+                    int dur = 0, terrain_change_type type = TERRAIN_CHANGE_GENERIC,
+                    int mnum = 0);
+
+    void write (writer &) const;
+    void read (reader &);
+    map_marker *clone() const;
+    string debug_describe() const;
+
+    static map_marker *read(reader &, map_marker_type);
+
+public:
+    int duration;
+    int mon_num;
+    dungeon_feature_type old_feature;
+    dungeon_feature_type new_feature;
+    terrain_change_type  change_type;
+};
+
+class map_cloud_spreader_marker : public map_marker
+{
+public:
+    map_cloud_spreader_marker(const coord_def &pos = coord_def(0, 0),
+                              cloud_type type = CLOUD_NONE,
+                              int speed = 10, int amount = 35,
+                              int max_radius = LOS_RADIUS, int dur = 10,
+                              actor* agent = NULL);
+
+    void write(writer &) const;
+    void read(reader &);
+    map_marker *clone() const;
+    string debug_describe() const;
+
+    static map_marker *read(reader &, map_marker_type);
+
+public:
+    cloud_type ctype;
+    int speed;
+    int remaining;
+    int max_rad;
+    int duration;
+    int speed_increment;
+    mid_t agent_mid;
+    kill_category kcat;
+};
 
 // A marker powered by Lua.
 class map_lua_marker : public map_marker, public dgn_event_listener
