@@ -21,6 +21,7 @@
 #include "coordit.h"
 #include "dbg-maps.h"
 #include "dungeon.h"
+#include "endianness.h"
 #include "env.h"
 #include "enum.h"
 #include "files.h"
@@ -38,9 +39,6 @@
 #include "tags.h"
 #include "terrain.h"
 
-#ifdef __ANDROID__
-  #include <sys/endian.h>
-#endif
 #ifndef BYTE_ORDER
 # error BYTE_ORDER is not defined
 #endif
@@ -380,6 +378,9 @@ static bool _may_overwrite_feature(const coord_def p,
     if (grid == DNGN_DEEP_WATER)
         return water_ok;
 
+    if (grid == DNGN_TREE && player_in_branch(BRANCH_FOREST))
+        return true;
+
     // Handle all other non-LOS blocking grids here.
     if (!feat_is_opaque(grid)
         && grid != DNGN_FLOOR
@@ -583,13 +584,13 @@ static bool _apply_vault_grid(map_def &def,
     // Handle maps aligned along cardinals that are smaller than
     // the corresponding map dimension.
     if ((orient == MAP_NORTH || orient == MAP_SOUTH
-         || orient == MAP_ENCOMPASS)
+         || orient == MAP_ENCOMPASS || orient == MAP_CENTRE)
         && size.x < GXM)
     {
         start.x = (GXM - size.x) / 2;
     }
     if ((orient == MAP_EAST || orient == MAP_WEST
-         || orient == MAP_ENCOMPASS)
+         || orient == MAP_ENCOMPASS || orient == MAP_CENTRE)
         && size.y < GYM)
     {
         start.y = (GYM - size.y) / 2;
@@ -640,7 +641,7 @@ static map_section_type _apply_vault_definition(
         return MAP_NONE;
 
     const map_section_type orient = def.orient;
-    return (orient == MAP_NONE? MAP_NORTH : orient);
+    return (orient == MAP_NONE ? MAP_NORTH : orient);
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -673,7 +674,7 @@ const map_def *find_map_by_name(const string &name)
 {
     for (unsigned i = 0, size = vdefs.size(); i < size; ++i)
         if (vdefs[i].name == name)
-            return (&vdefs[i]);
+            return &vdefs[i];
 
     return NULL;
 }
@@ -794,8 +795,7 @@ public:
 
 bool map_selector::depth_selectable(const map_def &mapdef) const
 {
-    return (mapdef.place.empty()
-            && mapdef.is_usable_in(place)
+    return (mapdef.is_usable_in(place)
             // Some tagged levels cannot be selected as random
             // maps in a specific depth:
             && !mapdef.has_tag_suffix("entry")
@@ -872,13 +872,13 @@ void map_selector::announce(const map_def *vault) const
         else
         {
             const char *format =
-                sel == PLACE? "[PLACE] Found map %s for %s" :
-                sel == DEPTH? "[DEPTH] Found random map %s for %s" :
+                sel == PLACE ? "[PLACE] Found map %s for %s" :
+                sel == DEPTH ? "[DEPTH] Found random map %s for %s" :
                 "[TAG] Found map %s tagged '%s'";
 
             mprf(MSGCH_DIAGNOSTICS, format,
                  vault->name.c_str(),
-                 sel == TAG? tag.c_str() : place.describe().c_str());
+                 sel == TAG ? tag.c_str() : place.describe().c_str());
         }
     }
 #endif
@@ -1262,6 +1262,12 @@ static bool _load_map_index(const string& cache, const string &base,
         return false;
     }
 
+#if TAG_MAJOR_VERSION == 34
+    // Throw out pre-ORDER: indices entirely.
+    if (minor < TAG_MINOR_MAP_ORDER)
+        return false;
+#endif
+
     const int nmaps = unmarshallShort(inf);
     const int nexist = vdefs.size();
     vdefs.resize(nexist + nmaps, map_def());
@@ -1270,6 +1276,7 @@ static bool _load_map_index(const string& cache, const string &base,
         map_def &vdef(vdefs[nexist + i]);
         vdef.read_index(inf);
         vdef.description = unmarshallString(inf);
+        vdef.order = unmarshallInt(inf);
 
         vdef.set_file(cache);
         lc_loaded_maps[vdef.name] = vdef.place_loaded_from;
@@ -1356,6 +1363,7 @@ static void _write_map_index(const string &filebase, size_t vs, size_t ve,
     {
         vdefs[i].write_index(outf);
         marshallString(outf, vdefs[i].description);
+        marshallInt(outf, vdefs[i].order);
         vdefs[i].place_loaded_from.clear();
         vdefs[i].strip();
     }
@@ -1495,7 +1503,7 @@ void run_map_local_preludes()
 
 const map_def *map_by_index(int index)
 {
-    return (&vdefs[index]);
+    return &vdefs[index];
 }
 
 ///////////////////////////////////////////////////////////////////////////
