@@ -8,6 +8,9 @@
 // a dancing weapon.
 #define TUKIMA_WEAPON "tukima-weapon"
 #define TUKIMA_POWER "tukima-power"
+// Technically only used for spectral weapon, not dancing weapons
+// Equal to weapon skill with a scale of 10
+#define TUKIMA_SKILL "tukima-skill"
 
 // A structure with all the data needed to whip up a new monster.
 struct mgen_data
@@ -109,6 +112,9 @@ struct mgen_data
     // This simply stores the initial shape-shifter type.
     monster_type    initial_shifter;
 
+    // This simply stores chimera base monsters.
+    vector<monster_type> chimera_mons;
+
     // This can eventually be used to store relevant information.
     CrawlHashTable  props;
 
@@ -145,7 +151,8 @@ struct mgen_data
                || mt == MONS_BATTLESPHERE
                || summon_type == SPELL_STICKS_TO_SNAKES
                || summon_type == SPELL_DEATH_CHANNEL
-               || summon_type == SPELL_SIMULACRUM);
+               || summon_type == SPELL_SIMULACRUM
+               || summon_type == SPELL_AWAKEN_VINES);
     }
 
     bool permit_bands() const { return (flags & MG_PERMIT_BANDS); }
@@ -158,6 +165,9 @@ struct mgen_data
 
     bool summoned() const { return (abjuration_duration > 0); }
 
+    void define_chimera(monster_type part1, monster_type part2,
+                        monster_type part3);
+
     static mgen_data sleeper_at(monster_type what,
                                 const coord_def &where,
                                 unsigned genflags = 0)
