@@ -29,7 +29,7 @@ int get_max_corpse_chunks(monster_type mons_class);
 void turn_corpse_into_skeleton(item_def &item);
 void turn_corpse_into_chunks(item_def &item, bool bloodspatter = true,
                              bool make_hide = true);
-void butcher_corpse(item_def &item, maybe_bool skeleton = B_MAYBE,
+void butcher_corpse(item_def &item, maybe_bool skeleton = MB_MAYBE,
                     bool chunks = true);
 
 void init_stack_blood_potions(item_def &stack, int age = -1);
@@ -90,7 +90,7 @@ void timeout_tombs(int duration);
 int count_malign_gateways();
 void timeout_malign_gateways(int duration);
 
-void timeout_door_seals(int duration, bool force = false);
+void timeout_terrain_changes(int duration, bool force = false);
 
 void setup_environment_effects();
 
@@ -120,13 +120,11 @@ bool stop_attack_prompt(const monster* mon, bool beam_attack,
 bool stop_attack_prompt(targetter &hitfunc, string verb,
                         bool (*affects)(const actor *victim) = 0);
 
-bool is_orckind(const actor *act);
 bool is_dragonkind(const actor *act);
 
 void swap_with_monster(monster *mon_to_swap);
 
 void wear_id_type(item_def &item);
-void maybe_id_ring_TC();
 void maybe_id_ring_hunger();
 void maybe_id_ring_see_invis();
 void maybe_id_clarity();
@@ -230,7 +228,7 @@ struct simple_connect
     void operator()(const position_node & node,
                     vector<position_node> & expansion)
     {
-        random_shuffle(compass_idx, compass_idx + connect);
+        shuffle_array(compass_idx, connect);
 
         for (int i=0; i < connect; i++)
         {
