@@ -23,7 +23,7 @@ void activate_ballistomycetes(monster* mons, const coord_def& origin,
 
 bool valid_kraken_connection(const monster* mons);
 void move_child_tentacles(monster * kraken);
-void move_demon_tentacle(monster * tentacle);
+void move_solo_tentacle(monster * tentacle);
 
 void ancient_zyme_sicken(monster* mons);
 void starcursed_merge(monster* mon, bool forced);
@@ -34,4 +34,16 @@ bool get_push_space(const coord_def& pos, coord_def& newpos,
                     actor* act, bool ignore_tension = false,
                     const vector<coord_def>* excluded = NULL);
 
+void heal_flayed_effect(actor* act, bool quiet = false, bool blood_only = false);
+void end_flayed_effect(monster* ghost);
+
+bool lost_soul_revive(monster* mons);
+bool lost_soul_spectralize(monster* mons);
+
+int spawn_spirit_pack(const actor* target);
+void waterport_touch(monster* nymph, actor* target);
+void treant_release_wasps(monster* mons);
+bool apply_grasping_roots(monster* mons);
+void check_grasping_roots(actor* act, bool quiet = false);
+
 #endif
