@@ -8,6 +8,7 @@
 
 #include "externs.h"
 
+#include "abl-show.h"
 #include "areas.h"
 #include "coord.h"
 #include "coordit.h"
@@ -16,7 +17,9 @@
 #include "env.h"
 #include "fprop.h"
 #include "exclude.h"
+#include "itemprop.h"
 #include "losglobal.h"
+#include "macro.h"
 #include "mon-act.h"
 #include "mon-death.h"
 #include "mon-iter.h"
@@ -26,6 +29,8 @@
 #include "mon-stuff.h"
 #include "ouch.h"
 #include "random.h"
+#include "religion.h"
+#include "spl-summoning.h"
 #include "state.h"
 #include "terrain.h"
 #include "traps.h"
@@ -60,6 +65,11 @@ static void _guess_invis_foe_pos(monster* mon)
 
 static void _mon_check_foe_invalid(monster* mon)
 {
+    // Assume a spectral weapon has a valid target
+    // Ideally this is not outside special cased like this
+    if (mon->type == MONS_SPECTRAL_WEAPON)
+        return;
+
     if (mon->foe != MHITNOT && mon->foe != MHITYOU)
     {
         if (actor *foe = mon->get_foe())
@@ -144,6 +154,124 @@ static void _set_firing_pos(monster* mon, coord_def target)
     mon->firing_pos = best_pos;
 }
 
+struct dist2_sorter
+{
+    coord_def pos;
+    bool operator()(const coord_def a, const coord_def b)
+    {
+        return distance2(a, pos) < distance2(b, pos);
+    }
+};
+
+static bool _can_traverse_unseen(const monster* mon, const coord_def& target)
+{
+    if (mon->pos() == target)
+        return true;
+
+    ray_def ray;
+    if (!find_ray(mon->pos(), target, ray, opc_immob))
+        return false;
+
+    while (ray.pos() != target && ray.advance())
+        if (!mon_can_move_to_pos(mon, ray.pos() - mon->pos()))
+            return false;
+
+    return true;
+}
+
+// Attempt to find the furthest position from a given target which still has
+// line of sight to it, and which the monster can move to (without pathfinding)
+static coord_def _furthest_aim_spot(monster* mon, coord_def target)
+{
+    int best_distance = 0;
+    coord_def best_pos(0, 0);
+
+    const los_base *los = mon->get_los();
+    for (distance_iterator di(mon->pos(), false, false, LOS_RADIUS);
+         di; ++di)
+    {
+        const coord_def p(*di);
+        const int range = p.distance_from(target);
+
+        if (!los->see_cell(*di))
+            continue;
+
+        if (!in_bounds(p) || range > LOS_RADIUS - 1
+            || !cell_see_cell(p, target, LOS_NO_TRANS)
+            || !mon_can_move_to_pos(mon, p - mon->pos(), true))
+        {
+            continue;
+        }
+
+        const int distance = p.distance_from(target);
+        if (distance > best_distance)
+        {
+            if (_can_traverse_unseen(mon, p))
+            {
+                best_pos = p;
+                best_distance = distance;
+            }
+        }
+    }
+
+    return best_pos;
+}
+
+// Tries to find and set an optimal spot for the curse skull to lurk, just
+// outside player's line of sight. We consider this to be the spot the furthest
+// from the player which still has line of sight to where the player will move
+// if they are approaching us. (This keeps it from lurking immediately around
+// corners, where the player can enter melee range of it the first turn it comes
+// into sight)
+//
+// The answer given is not always strictly optimal, since no actual pathfinding
+// is done, and sometimes the best lurking position crosses spots visible to
+// the player unless a more circuitous route is taken, but generally it is
+// pretty good, and eliminates the most obvious cases of players luring them
+// into easy kill.
+static void _set_curse_skull_lurk_pos(monster* mon)
+{
+    // If we're already moving somewhere that we can actually reach, don't
+    // search for a new spot.
+    if (!mon->firing_pos.origin() && _can_traverse_unseen(mon, mon->firing_pos))
+        return;
+
+    // Examine spots adjacent to our target, starting with those closest to us
+    vector<coord_def> spots;
+    for (adjacent_iterator ai(you.pos()); ai; ++ai)
+    {
+        if (!feat_is_solid(grd(*ai)) || feat_is_door(grd(*ai)))
+            spots.push_back(*ai);
+    }
+
+    dist2_sorter sorter = {mon->pos()};
+    sort(spots.begin(), spots.end(), sorter);
+
+    coord_def lurk_pos(0, 0);
+    for (unsigned int i = 0; i < spots.size(); ++i)
+    {
+        lurk_pos = _furthest_aim_spot(mon, spots[i]);
+
+        // Consider the first position found to be good enough
+        if (!lurk_pos.origin())
+        {
+            mon->firing_pos = lurk_pos;
+            return;
+        }
+    }
+}
+
+static bool _stabber_keep_distance(const monster* mon, const actor* foe)
+{
+    return (mons_class_flag(mon->type, M_STABBER)
+            && !mon->berserk_or_insane()
+            && (mons_has_incapacitating_ranged_attack(mon, foe)
+                || mons_has_incapacitating_spell(mon, foe))
+            && !foe->incapacitated()
+            && !adjacent(mon->pos(), foe->pos())
+            && !mons_aligned(mon, foe));
+}
+
 //---------------------------------------------------------------
 //
 // handle_behaviour
@@ -179,17 +307,15 @@ void handle_behaviour(monster* mon)
     bool changed = true;
     bool isFriendly = mon->friendly();
     bool isNeutral  = mon->neutral();
-    bool wontAttack = mon->wont_attack();
+    bool wontAttack = mon->wont_attack() && !mon->has_ench(ENCH_INSANE);
 
     // Whether the player position is in LOS of the monster.
     bool proxPlayer = !crawl_state.game_is_arena() && mon->see_cell(you.pos());
 
-#ifdef WIZARD
-    // If stealth is greater than actually possible (wizmode level)
-    // pretend the player isn't there, but only for hostile monsters.
-    if (proxPlayer && you.skills[SK_STEALTH] > 27 && !mon->wont_attack())
+    // If set, pretend the player isn't there, but only for hostile monsters.
+    if (proxPlayer && crawl_state.disables[DIS_MON_SIGHT] && !mon->wont_attack())
         proxPlayer = false;
-#endif
+
     bool proxFoe;
     bool isHealthy  = (mon->hit_points > mon->max_hit_points / 2);
     bool isSmart    = (mons_intel(mon) > I_ANIMAL);
@@ -255,6 +381,46 @@ void handle_behaviour(monster* mon)
     // Validate current target exists.
     _mon_check_foe_invalid(mon);
 
+    // The target and foe set here for a spectral weapon should never change
+    if (mon->type == MONS_SPECTRAL_WEAPON)
+    {
+        // Do nothing if we're still being placed
+        if (!mon->summoner)
+            return;
+
+        actor *owner = actor_by_mid(mon->summoner);
+
+        if (!owner || !owner->alive())
+        {
+            end_spectral_weapon(mon, false);
+            return;
+        }
+
+        mon->target = owner->pos();
+        mon->foe = MHITNOT;
+        // Try to move towards any monsters the owner is attacking
+        if (mon->props.exists(SW_TARGET_MID))
+        {
+            actor *atarget = actor_by_mid(mon->props[SW_TARGET_MID].get_int());
+
+            // Only go after the target if it's still near the owner,
+            // and so are we.
+            // The weapon is restricted to a leash range of 2,
+            // and things reachable within that leash range [qoala]
+            const int leash = 2;
+            if (atarget && atarget->alive()
+                && (grid_distance(owner->pos(), atarget->pos())
+                    <= ((mon->reach_range() == REACH_TWO) ? leash + 2 : leash + 1))
+                && (grid_distance(owner->pos(), mon->pos()) <= leash))
+            {
+                mon->target = atarget->pos();
+                mon->foe = atarget->mindex();
+            }
+            else
+                reset_spectral_weapon(mon);
+        }
+    }
+
     // Change proxPlayer depending on invisibility and standing
     // in shallow water.
     if (proxPlayer && !you.visible_to(mon))
@@ -279,14 +445,14 @@ void handle_behaviour(monster* mon)
 
         // Ash penance makes monsters very likely to target you through
         // invisibility, depending on their intelligence.
-        if (you.penance[GOD_ASHENZARI] && x_chance_in_y(intel, 6))
+        if (player_under_penance(GOD_ASHENZARI) && x_chance_in_y(intel, 7))
             proxPlayer = true;
     }
 
     // Zotdef: immobile allies forget targets that are out of sight
     if (crawl_state.game_is_zotdef())
     {
-        if (isFriendly && mons_is_stationary(mon)
+        if (isFriendly && mon->is_stationary()
             && (mon->foe != MHITNOT && mon->foe != MHITYOU)
             && !mon->can_see(&menv[mon->foe]))
         {
@@ -300,10 +466,11 @@ void handle_behaviour(monster* mon)
     // Berserking allies ignore your commands!
     if (isFriendly
         && (mon->foe == MHITNOT || mon->foe == MHITYOU)
-        && !mon->berserk()
+        && !mon->berserk_or_insane()
         && mon->behaviour != BEH_WITHDRAW
         && mon->type != MONS_GIANT_SPORE
-        && mon->type != MONS_BATTLESPHERE)
+        && mon->type != MONS_BATTLESPHERE
+        && mon->type != MONS_SPECTRAL_WEAPON)
     {
         if  (!crawl_state.game_is_zotdef())
         {
@@ -330,13 +497,20 @@ void handle_behaviour(monster* mon)
 
     // Instead, berserkers attack nearest monsters.
     if (mon->behaviour != BEH_SLEEP
-        && (mon->berserk() || mon->type == MONS_GIANT_SPORE)
-        && (mon->foe == MHITNOT || isFriendly && mon->foe == MHITYOU))
+        && (mon->has_ench(ENCH_INSANE)
+            || ((mon->berserk() || mon->type == MONS_GIANT_SPORE)
+                && (mon->foe == MHITNOT
+                    || isFriendly && mon->foe == MHITYOU))))
     {
         // Intelligent monsters prefer to attack the player,
         // even when berserking.
-        if (!isFriendly && proxPlayer && mons_intel(mon) >= I_NORMAL)
+        if (!isFriendly
+            && !mon->has_ench(ENCH_INSANE)
+            && proxPlayer
+            && mons_intel(mon) >= I_NORMAL)
+        {
             mon->foe = MHITYOU;
+        }
         else
             _set_nearest_monster_foe(mon);
     }
@@ -355,7 +529,8 @@ void handle_behaviour(monster* mon)
     }
 
     // Friendly summons will come back to the player if they go out of sight.
-    if (!summon_can_attack(mon))
+    // Spectral weapon should keep its target even though it can't attack it
+    if (!summon_can_attack(mon) && mon->type!=MONS_SPECTRAL_WEAPON)
         mon->target = you.pos();
 
     // Monsters do not attack themselves. {dlb}
@@ -371,7 +546,9 @@ void handle_behaviour(monster* mon)
     }
 
     // Neutral monsters prefer not to attack players, or other neutrals.
-    if (isNeutral && mon->foe != MHITNOT
+    if (isNeutral
+        && !mon->has_ench(ENCH_INSANE)
+        && mon->foe != MHITNOT
         && (mon->foe == MHITYOU || menv[mon->foe].neutral()))
     {
         mon->foe = MHITNOT;
@@ -382,7 +559,8 @@ void handle_behaviour(monster* mon)
     // Zotdef: 2/3 chance of retargetting changed to 1/4
     if (!isFriendly && !isNeutral
         && mon->foe != MHITYOU && mon->foe != MHITNOT
-        && proxPlayer && !mon->berserk() && isHealthy
+        && proxPlayer && !mon->berserk_or_insane()
+        && isHealthy
         && (crawl_state.game_is_zotdef() ? one_chance_in(4)
                                          : !one_chance_in(3)))
     {
@@ -392,6 +570,16 @@ void handle_behaviour(monster* mon)
     // Validate current target again.
     _mon_check_foe_invalid(mon);
 
+    if (mon->has_ench(ENCH_HAUNTING))
+    {
+        actor* targ = mon->get_ench(ENCH_HAUNTING).agent();
+        if (targ && targ->alive())
+        {
+            mon->foe = targ->mindex();
+            mon->target = targ->pos();
+        }
+    }
+
     while (changed)
     {
         actor* afoe = mon->get_foe();
@@ -446,7 +634,8 @@ void handle_behaviour(monster* mon)
             {
                 if (crawl_state.game_is_arena()
                     || !proxPlayer && !isFriendly
-                    || isNeutral || patrolling
+                    || isNeutral && !mon->has_ench(ENCH_INSANE)
+                    || patrolling
                     || mon->type == MONS_GIANT_SPORE)
                 {
                     if (mon->behaviour != BEH_LURK)
@@ -469,9 +658,9 @@ void handle_behaviour(monster* mon)
             {
                 // If their foe is marked, the monster always knows exactly
                 // where they are.
-                if (mons_foe_is_marked(mon))
+                if (mons_foe_is_marked(mon) || mon->has_ench(ENCH_HAUNTING))
                 {
-                    mon->target = you.pos();
+                    mon->target = afoe->pos();
                     try_pathfind(mon);
                     break;
                 }
@@ -557,6 +746,12 @@ void handle_behaviour(monster* mon)
                 {
                     new_beh = BEH_WANDER;
                 }
+                else if ((mon->type == MONS_CURSE_SKULL
+                          && mon->foe == MHITYOU
+                          && grid_distance(mon->pos(), you.pos()) <= LOS_RADIUS))
+                {
+                    _set_curse_skull_lurk_pos(mon);
+                }
                 // If the player walk out of the LOS of a monster with a ranged
                 // attack, we assume it sees in which direction the player went
                 // and it tries to find a line of fire instead of following the
@@ -571,7 +766,8 @@ void handle_behaviour(monster* mon)
                     break;
             }
 
-            ASSERT((proxFoe || isFriendly) && mon->foe != MHITNOT);
+            ASSERT(proxFoe || isFriendly);
+            ASSERT(mon->foe != MHITNOT);
 
             // Monster can see foe: set memory in case it loses sight.
             // Hack: smarter monsters will tend to pursue the player longer.
@@ -585,6 +781,7 @@ void handle_behaviour(monster* mon)
                 break;
             case I_ANIMAL:
             case I_INSECT:
+            case I_REPTILE:
                 mon->foe_memory = random_range(250, 550);
                 break;
             case I_PLANT:
@@ -597,14 +794,23 @@ void handle_behaviour(monster* mon)
             if (mon->foe == MHITYOU)
             {
                 // The foe is the player.
-
                 if (mons_class_flag(mon->type, M_MAINTAIN_RANGE)
-                    && !mon->berserk())
+                    && !mon->berserk_or_insane())
                 {
                     if (mon->attitude != ATT_FRIENDLY)
                         // Get to firing range even if we are close.
                         _set_firing_pos(mon, you.pos());
                 }
+                else if (_stabber_keep_distance(mon, &you))
+                {
+                    if (mon->pos().distance_from(you.pos()) < 4
+                        && !one_chance_in(7))
+                    {
+                        mon->firing_pos = mon->pos();
+                    }
+                    else
+                        _set_firing_pos(mon, you.pos());
+                }
                 else if (!mon->firing_pos.zero()
                     && mon->see_cell_no_trans(mon->target))
                 {
@@ -641,13 +847,24 @@ void handle_behaviour(monster* mon)
             else
             {
                 // We have a foe but it's not the player.
-                mon->target = menv[mon->foe].pos();
+                monster* target = &menv[mon->foe];
+                mon->target = target->pos();
 
                 if (mons_class_flag(mon->type, M_MAINTAIN_RANGE)
-                    && !mon->berserk())
+                    && !mon->berserk_or_insane())
                 {
                     _set_firing_pos(mon, mon->target);
                 }
+                else if (target && _stabber_keep_distance(mon, target))
+                {
+                    if (mon->pos().distance_from(target->pos()) < 4
+                        && !one_chance_in(7))
+                    {
+                        mon->firing_pos = mon->pos();
+                    }
+                    else
+                        _set_firing_pos(mon, target->pos());
+                }
 
             }
 
@@ -692,7 +909,7 @@ void handle_behaviour(monster* mon)
             }
 
             if (mon->strict_neutral() && mons_is_slime(mon)
-                && you.religion == GOD_JIYVA)
+                && you_worship(GOD_JIYVA))
             {
                 set_random_slime_target(mon);
             }
@@ -710,7 +927,8 @@ void handle_behaviour(monster* mon)
             // Creatures not currently pursuing another foe are
             // alerted by a sentinel's mark
             if (mon->foe == MHITNOT && you.duration[DUR_SENTINEL_MARK]
-                && !isFriendly && !isNeutral && !isPacified)
+                && (!isFriendly && !isNeutral && !isPacified
+                    || mon->has_ench(ENCH_INSANE)))
             {
                 new_foe = MHITYOU;
                 new_beh = BEH_SEEK;
@@ -800,7 +1018,9 @@ void handle_behaviour(monster* mon)
             // Foe gone out of LOS?
             if (!proxFoe)
             {
-                if ((isFriendly || proxPlayer) && !isNeutral && !patrolling
+                if ((isFriendly || proxPlayer)
+                    && (!isNeutral || mon->has_ench(ENCH_INSANE))
+                    && !patrolling
                     && !crawl_state.game_is_arena())
                 {
                     new_foe = MHITYOU;
@@ -933,10 +1153,11 @@ static bool _mons_check_foe(monster* mon, const coord_def& p,
 
     monster* foe = monster_at(p);
     if (foe && foe != mon
-        && (foe->friendly() != friendly
+        && (mon->has_ench(ENCH_INSANE)
+            || foe->friendly() != friendly
             || neutral && !foe->neutral())
         && mon->can_see(foe)
-        && !mons_is_projectile(foe->type)
+        && !foe->is_projectile()
         && summon_can_attack(mon, p)
         && (friendly || !is_sanctuary(p))
         && (crawl_state.game_is_zotdef() || !mons_is_firewood(foe)))
@@ -944,6 +1165,10 @@ static bool _mons_check_foe(monster* mon, const coord_def& p,
     {
         return true;
     }
+
+    if (mon->has_ench(ENCH_INSANE) && p == you.pos())
+        return true;
+
     return false;
 }
 
@@ -953,8 +1178,12 @@ static void _set_nearest_monster_foe(monster* mon)
     // These don't look for foes.
     if (mon->good_neutral() || mon->strict_neutral()
             || mon->behaviour == BEH_WITHDRAW
-            || mon->type == MONS_BATTLESPHERE)
+            || mon->type == MONS_BATTLESPHERE
+            || mon->type == MONS_SPECTRAL_WEAPON
+            || mon->has_ench(ENCH_HAUNTING))
+    {
         return;
+    }
 
     const bool friendly = mon->friendly();
     const bool neutral  = mon->neutral();
@@ -996,7 +1225,7 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
         return;
 
     ASSERT(!crawl_state.game_is_arena() || src != &you);
-    ASSERT(in_bounds(src_pos) || src_pos.origin());
+    ASSERT_IN_BOUNDS_OR_ORIGIN(src_pos);
     if (mons_is_projectile(mon->type))
         return; // projectiles have no AI
 
@@ -1063,7 +1292,8 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
         // or else fleeing anyway.  Hitting someone over
         // the head, of course, always triggers this code.
         if (event == ME_WHACK
-            || ((wontAttack != sourceWontAttack || isSmart)
+            || mon->has_ench(ENCH_INSANE)
+            || ((wontAttack != sourceWontAttack || (mons_intel(mon) > I_PLANT))
                 && (!mons_is_fleeing(mon) && !mons_class_flag(mon->type, M_FLEEING))
                 && !mons_is_panicking(mon)))
         {
@@ -1091,7 +1321,7 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
             // If the monster can't reach its target and can't attack it
             // either, retreat.
             try_pathfind(mon);
-            if (mons_intel(mon) > I_INSECT && !mons_can_attack(mon)
+            if (mons_intel(mon) > I_REPTILE && !mons_can_attack(mon)
                 && target_is_unreachable(mon))
             {
                 mon->behaviour = BEH_RETREAT;
@@ -1101,7 +1331,10 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
             else if (mon->asleep())
                 mon->behaviour = BEH_SEEK;
 
-            if (src == &you && mon->type != MONS_BATTLESPHERE)
+            if (src == &you
+                && !mon->has_ench(ENCH_INSANE)
+                && mon->type != MONS_BATTLESPHERE
+                && mon->type != MONS_SPECTRAL_WEAPON)
             {
                 mon->attitude = ATT_HOSTILE;
                 breakCharm    = true;
@@ -1140,7 +1373,7 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
         // XXX: Neutral monsters are a tangled mess of arbitrary logic.
         // It's not even clear any more what behaviours are intended for
         // neutral monsters and what are merely accidents of the code.
-        if (mon->neutral())
+        if (mon->neutral() && !mon->has_ench(ENCH_INSANE))
         {
             if (mon->asleep())
                 mon->behaviour = BEH_WANDER;
@@ -1185,7 +1418,7 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
     case ME_SCARE:
         // Stationary monsters can't flee, and berserking monsters
         // are too enraged.
-        if (mons_is_stationary(mon) || mon->berserk())
+        if (mon->is_stationary() || mon->berserk_or_insane())
         {
             mon->del_ench(ENCH_FEAR, true, true);
             break;
@@ -1271,7 +1504,7 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
         //   (chance increases by 5% for every hp lost.)
         if (mons_class_flag(mon->type, M_FLEES)
             && !mons_is_cornered(mon)
-            && !mon->berserk()
+            && !mon->berserk_or_insane()
             && x_chance_in_y(fleeThreshold - mon->hit_points, fleeThreshold))
         {
             mon->behaviour = BEH_FLEE;
@@ -1285,7 +1518,10 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
     if (setTarget && src)
     {
         mon->target = src_pos;
-        if (src->is_player() && mon->type != MONS_BATTLESPHERE)
+        if (src->is_player()
+            && !mon->has_ench(ENCH_INSANE)
+            && mon->type != MONS_BATTLESPHERE
+            && mon->type != MONS_SPECTRAL_WEAPON)
         {
             // Why only attacks by the player change attitude? -- 1KB
             mon->attitude = ATT_HOSTILE;
@@ -1302,7 +1538,12 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
 
     // Do any resultant foe or state changes.
     handle_behaviour(mon);
-    ASSERT(in_bounds(mon->target) || mon->target.origin());
+
+    // That might have made the monster leave the level.
+    if (!mon->alive())
+        return;
+
+    ASSERT_IN_BOUNDS_OR_ORIGIN(mon->target);
 
     // If it woke up and you're its new foe, it might shout.
     if (was_sleeping && !mon->asleep() && allow_shout
@@ -1329,9 +1570,29 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
         mon->behaviour = BEH_LURK;
     }
 
+    // mons_speaks_msg already handles the LOS check.
     if (!msg.empty() && mon->visible_to(&you))
         mons_speaks_msg(mon, msg, MSGCH_TALK, silenced(mon->pos()));
 
+    if (mons_allows_beogh_now(mon))
+    {
+        const bool first = !you.attribute[ATTR_SEEN_BEOGH];
+        if (first || one_chance_in(10))
+        {
+            mons_speaks_msg(mon, getSpeakString("orc_priest_preaching"),
+                            MSGCH_TALK);
+            if (first)
+            {
+                ASSERT_RANGE(get_talent(ABIL_CONVERT_TO_BEOGH, false).hotkey,
+                             'A', 'z' + 1);
+                mprf("(press <white>%s %c</white> to convert to Beogh)",
+                     command_to_string(CMD_USE_ABILITY).c_str(),
+                     get_talent(ABIL_CONVERT_TO_BEOGH, false).hotkey);
+                you.attribute[ATTR_SEEN_BEOGH] = 1;
+            }
+        }
+    }
+
     ASSERT(!crawl_state.game_is_arena()
            || mon->foe != MHITYOU && mon->target != you.pos());
 }
