@@ -1038,8 +1038,13 @@ string monster::describe_enchantments() const
     return oss.str();
 }
 
-bool monster::decay_enchantment(const mon_enchant &me, bool decay_degree)
+bool monster::decay_enchantment(enchant_type en, bool decay_degree)
 {
+    if (!has_ench(en))
+        return false;
+
+    const mon_enchant& me(get_ench(en));
+
     if (me.duration >= INFINITE_DURATION)
         return false;
 
@@ -1080,11 +1085,12 @@ bool monster::decay_enchantment(const mon_enchant &me, bool decay_degree)
 
 void monster::apply_enchantment(const mon_enchant &me)
 {
+    enchant_type en = me.ench;
     const int spd = 10;
     switch (me.ench)
     {
     case ENCH_INSANE:
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             simple_monster_message(this, " is no longer in an insane frenzy.");
             const int duration = random_range(70, 130);
@@ -1094,7 +1100,7 @@ void monster::apply_enchantment(const mon_enchant &me)
         break;
 
     case ENCH_BERSERK:
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             simple_monster_message(this, " is no longer berserk.");
             const int duration = random_range(70, 130);
@@ -1104,7 +1110,7 @@ void monster::apply_enchantment(const mon_enchant &me)
         break;
 
     case ENCH_FATIGUE:
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             simple_monster_message(this, " looks more energetic.");
             del_ench(ENCH_SLOW, true);
@@ -1162,23 +1168,23 @@ void monster::apply_enchantment(const mon_enchant &me)
     case ENCH_WIND_AIDED:
     case ENCH_FIRE_VULN:
     // case ENCH_ROLLING:
-        decay_enchantment(me);
+        decay_enchantment(en);
         break;
 
     case ENCH_MIRROR_DAMAGE:
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
             simple_monster_message(this, "'s dark mirror aura disappears.");
         break;
 
     case ENCH_SILENCE:
     case ENCH_LIQUEFYING:
-        decay_enchantment(me);
+        decay_enchantment(en);
         invalidate_agrid();
         break;
 
     case ENCH_BATTLE_FRENZY:
     case ENCH_ROUSED:
-        decay_enchantment(me, false);
+        decay_enchantment(en, false);
         break;
 
     case ENCH_AQUATIC_LAND:
@@ -1249,11 +1255,11 @@ void monster::apply_enchantment(const mon_enchant &me)
             if (has_ench(ENCH_CONFUSION) && !one_chance_in(5))
                 break;
 
-            decay_enchantment(me, 2*(NUM_SIZE_LEVELS - mon_size) - hold);
+            decay_enchantment(en, 2*(NUM_SIZE_LEVELS - mon_size) - hold);
 
             // Frayed nets are easier to escape.
             if (mon_size <= -(hold-1)/2)
-                decay_enchantment(me, (NUM_SIZE_LEVELS - mon_size));
+                decay_enchantment(en, (NUM_SIZE_LEVELS - mon_size));
         }
         else // Large (and above) monsters always thrash the net and destroy it
         {    // e.g. ogre, large zombie (large); centaur, naga, hydra (big).
@@ -1333,12 +1339,12 @@ void monster::apply_enchantment(const mon_enchant &me)
     }
     case ENCH_CONFUSION:
         if (!mons_class_flag(type, M_CONFUSED))
-            decay_enchantment(me);
+            decay_enchantment(en);
         break;
 
     case ENCH_INVIS:
         if (!mons_class_flag(type, M_INVIS))
-            decay_enchantment(me);
+            decay_enchantment(en);
         break;
 
     case ENCH_SUBMERGED:
@@ -1394,7 +1400,7 @@ void monster::apply_enchantment(const mon_enchant &me)
             hurt(me.agent(), dam, BEAM_POISON);
         }
 
-        decay_enchantment(me, true);
+        decay_enchantment(en, true);
         break;
     }
     case ENCH_ROT:
@@ -1406,7 +1412,7 @@ void monster::apply_enchantment(const mon_enchant &me)
                 --max_hit_points;
         }
 
-        decay_enchantment(me, true);
+        decay_enchantment(en, true);
         break;
     }
 
@@ -1458,19 +1464,19 @@ void monster::apply_enchantment(const mon_enchant &me)
             hurt(me.agent(), dam, BEAM_NAPALM);
         }
 
-        decay_enchantment(me, true);
+        decay_enchantment(en, true);
         break;
     }
 
     case ENCH_SHORT_LIVED:
         // This should only be used for ball lightning -- bwr
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
             suicide();
         break;
 
     case ENCH_SLOWLY_DYING:
         // If you are no longer dying, you must be dead.
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             if (you.can_see(this))
             {
@@ -1488,14 +1494,14 @@ void monster::apply_enchantment(const mon_enchant &me)
         break;
 
     case ENCH_PREPARING_RESURRECT:
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
             shedu_do_actual_resurrection(this);
         break;
 
     case ENCH_SPORE_PRODUCTION:
         // Reduce the timer, if that means we lose the enchantment then
         // spawn a spore and re-add the enchantment.
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             // Search for an open adjacent square to place a spore on
             int idx[] = {0, 1, 2, 3, 4, 5, 6, 7};
@@ -1568,7 +1574,7 @@ void monster::apply_enchantment(const mon_enchant &me)
     {
         // Reduce the timer, if that means we lose the enchantment then
         // spawn a spore and re-add the enchantment
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             monster_type mtype = type;
             bolt beam;
@@ -1589,7 +1595,7 @@ void monster::apply_enchantment(const mon_enchant &me)
 
     case ENCH_PORTAL_TIMER:
     {
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             coord_def base_position = props["base_position"].get_coord();
             // Do a thing.
@@ -1611,7 +1617,7 @@ void monster::apply_enchantment(const mon_enchant &me)
 
     case ENCH_PORTAL_PACIFIED:
     {
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
         {
             if (has_ench(ENCH_SEVERED))
                 break;
@@ -1668,7 +1674,7 @@ void monster::apply_enchantment(const mon_enchant &me)
         break;
 
     case ENCH_TP:
-        if (decay_enchantment(me, true) && !no_tele(true, false))
+        if (decay_enchantment(en, true) && !no_tele(true, false))
             monster_teleport(this, true);
         break;
 
@@ -1682,12 +1688,12 @@ void monster::apply_enchantment(const mon_enchant &me)
 
     case ENCH_AWAKEN_FOREST:
         forest_damage(this);
-        decay_enchantment(me);
+        decay_enchantment(en);
         break;
 
     case ENCH_TORNADO:
         tornado_damage(this, speed_to_duration(speed));
-        decay_enchantment(me);
+        decay_enchantment(en);
         break;
 
     case ENCH_BLEED:
@@ -1706,7 +1712,7 @@ void monster::apply_enchantment(const mon_enchant &me)
                  hit_points, dam, me.degree);
         }
 
-        decay_enchantment(me, true);
+        decay_enchantment(en, true);
         break;
     }
 
@@ -1733,7 +1739,7 @@ void monster::apply_enchantment(const mon_enchant &me)
             hurt(me.agent(), dam, BEAM_LIGHT);
         }
 
-        decay_enchantment(me, true);
+        decay_enchantment(en, true);
         break;
 
     case ENCH_WORD_OF_RECALL:
@@ -1752,7 +1758,7 @@ void monster::apply_enchantment(const mon_enchant &me)
             break;
         }
 
-        if (decay_enchantment(me))
+        if (decay_enchantment(en))
             mons_word_of_recall(this, 3 + random2(5));
         break;
 
@@ -1761,7 +1767,7 @@ void monster::apply_enchantment(const mon_enchant &me)
         if (!me.agent() || !me.agent()->alive())
             del_ench(ENCH_INJURY_BOND, true, false);
         else
-            decay_enchantment(me);
+            decay_enchantment(en);
         break;
 
     case ENCH_WATER_HOLD:
@@ -1796,7 +1802,7 @@ void monster::apply_enchantment(const mon_enchant &me)
             }
         }
         if (!near_ghost)
-            decay_enchantment(me);
+            decay_enchantment(en);
 
         break;
     }
@@ -1808,17 +1814,17 @@ void monster::apply_enchantment(const mon_enchant &me)
 
     case ENCH_CONTROL_WINDS:
         apply_control_winds(this);
-        decay_enchantment(me);
+        decay_enchantment(en);
         break;
 
     case ENCH_TOXIC_RADIANCE:
         toxic_radiance_effect(this, 1);
-        decay_enchantment(me);
+        decay_enchantment(en);
         break;
 
     case ENCH_GRASPING_ROOTS_SOURCE:
         if (!apply_grasping_roots(this))
-            decay_enchantment(me);
+            decay_enchantment(en);
         break;
 
     case ENCH_GRASPING_ROOTS:
