@@ -183,9 +183,7 @@ static void _give_potion(monster* mon, int level)
         mitm[thing_created].flags = 0;
         _give_monster_item(mon, thing_created);
     }
-    else if ((mons_species(mon->type) == MONS_DEEP_DWARF
-              || mon->type == MONS_GNOLL_SERGEANT)
-                  && one_chance_in(3))
+    else if (mon->type == MONS_GNOLL_SERGEANT && one_chance_in(3))
     {
         const int thing_created =
             items(0, OBJ_POTIONS, coinflip() ? POT_HEAL_WOUNDS
@@ -352,6 +350,21 @@ static item_make_species_type _give_weapon(monster* mon, int level,
 
         break;
 
+    case MONS_DEEP_DWARF_DEATH_KNIGHT:
+        item_race = MAKE_ITEM_DWARVEN;
+        item.base_type = OBJ_WEAPONS;
+        item.sub_type = random_choose_weighted(5, WPN_MORNINGSTAR, 5, WPN_GREAT_MACE,
+                                               5, WPN_HALBERD,     8, WPN_GLAIVE,
+                                               5, WPN_GREAT_SWORD, 10, WPN_BROAD_AXE,
+                                               15, WPN_BATTLEAXE, 0);
+        if (coinflip())
+        {
+            force_item  = true;
+            item.plus  += 1 + random2(4);
+            item.plus2 += 1 + random2(4);
+        }
+        break;
+
     case MONS_DWARF:
     case MONS_DEEP_DWARF:
         item_race = MAKE_ITEM_DWARVEN;
@@ -362,8 +375,6 @@ static item_make_species_type _give_weapon(monster* mon, int level,
             break;
         }
         // deliberate fall through
-    case MONS_DEEP_DWARF_SCION:
-    case MONS_DEEP_DWARF_DEATH_KNIGHT:
     case MONS_DEEP_DWARF_BERSERKER:
         item_race = MAKE_ITEM_DWARVEN;
         item.base_type = OBJ_WEAPONS;
@@ -382,18 +393,14 @@ static item_make_species_type _give_weapon(monster* mon, int level,
                                                    15, WPN_HAND_AXE, 0);
         }
 
-        if (coinflip() || mon->type == MONS_DEEP_DWARF_BERSERKER
-                       || mon->type == MONS_DEEP_DWARF_SCION)
+        if (coinflip() || mon->type == MONS_DEEP_DWARF_BERSERKER)
         {
             force_item  = true;
             item.plus  += 1 + random2(4);
             item.plus2 += 1 + random2(4);
 
-            if (one_chance_in(30) && (mon->type == MONS_DEEP_DWARF_BERSERKER
-                                      || mon->type == MONS_DEEP_DWARF_SCION))
-            {
+            if (one_chance_in(30) && mon->type == MONS_DEEP_DWARF_BERSERKER)
                 level = MAKE_GOOD_ITEM;
-            }
         }
         break;
 
@@ -490,10 +497,10 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         {
             item.base_type = OBJ_WEAPONS;
             item.sub_type  = random_choose_weighted(
-                30, WPN_DAGGER,      30, WPN_CLUB,
-                27, WPN_FLAIL,       24, WPN_HAND_AXE,
-                20, WPN_HAMMER,      20, WPN_SHORT_SWORD,
-                20, WPN_MACE,        10, WPN_WHIP,
+                35, WPN_CLUB,        30, WPN_DAGGER,
+                30, WPN_FLAIL,       30, WPN_HAND_AXE,
+                20, WPN_SHORT_SWORD,
+                20, WPN_MACE,        15, WPN_WHIP,
                 10, WPN_TRIDENT,     10, WPN_FALCHION,
                 6, WPN_WAR_AXE,      3, WPN_MORNINGSTAR,
                 0);
@@ -534,7 +541,6 @@ static item_make_species_type _give_weapon(monster* mon, int level,
     case MONS_DEEP_ELF_HIGH_PRIEST:
     case MONS_DEEP_ELF_KNIGHT:
     case MONS_DEEP_ELF_PRIEST:
-    case MONS_DEEP_ELF_SOLDIER:
         item_race = MAKE_ITEM_ELVEN;
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = random_choose_weighted(
@@ -609,6 +615,7 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         // deliberate fall-through {dlb}
 
     case MONS_DANCING_WEAPON:   // give_level may have been adjusted above
+    case MONS_SPECTRAL_WEAPON:  // Necessary for placement by mons spec
     case MONS_FRANCES:
     case MONS_HAROLD:
     case MONS_LOUISE:
@@ -682,27 +689,37 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         item.flags |= ISFLAG_KNOW_TYPE;
         break;
 
+    case MONS_TENGU_REAVER:
+    case MONS_VAULT_WARDEN:
+        item_race = MAKE_ITEM_NO_RACE;
     case MONS_ORC_WARLORD:
     case MONS_SAINT_ROKA:
-    case MONS_VAULT_WARDEN:
         // being at the top has its privileges
         if (one_chance_in(3))
             level = MAKE_GOOD_ITEM;
         // deliberate fall-through
 
     case MONS_ORC_KNIGHT:
-        item_race = MAKE_ITEM_ORCISH;
-        // Occasionally get crossbows.
-        if (!melee_only && one_chance_in(9))
+        if (item_race == MAKE_ITEM_RANDOM_RACE)
+            item_race = MAKE_ITEM_ORCISH;
+        // deliberate fall-through
+
+    case MONS_TENGU_WARRIOR:
+        if (item_race == MAKE_ITEM_RANDOM_RACE)
+            item_race = MAKE_ITEM_NO_RACE;
+        // Occasionally get crossbows, or a longbow for tengu.
+        if (!melee_only && mon->type != MONS_TENGU_REAVER && one_chance_in(9))
         {
             item.base_type = OBJ_WEAPONS;
-            item.sub_type  = WPN_CROSSBOW;
+            item.sub_type  = (mon->type == MONS_TENGU_WARRIOR && coinflip())
+                             ? WPN_LONGBOW : WPN_CROSSBOW;
             break;
         }
         // deliberate fall-through
 
     case MONS_URUG:
-        item_race = MAKE_ITEM_ORCISH;
+        if (item_race == MAKE_ITEM_RANDOM_RACE)
+            item_race = MAKE_ITEM_ORCISH;
         // deliberate fall-through
 
     case MONS_VAULT_GUARD:
@@ -793,13 +810,10 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         break;
 
     case MONS_RED_DEVIL:
-        if (!one_chance_in(3))
-        {
-            item_race = MAKE_ITEM_NO_RACE;
-            item.base_type = OBJ_WEAPONS;
-            item.sub_type  = (one_chance_in(3) ? WPN_DEMON_TRIDENT
-                                               : WPN_TRIDENT);
-        }
+        item_race = MAKE_ITEM_NO_RACE;
+        item.base_type = OBJ_WEAPONS;
+        item.sub_type  = (one_chance_in(5) ? WPN_DEMON_TRIDENT
+                                           : WPN_TRIDENT);
         break;
 
     case MONS_OGRE:
@@ -909,6 +923,35 @@ static item_make_species_type _give_weapon(monster* mon, int level,
             item.sub_type = WPN_LONGBOW;
         break;
 
+    case MONS_FAUN:
+    case MONS_SATYR:
+        item_race      = MAKE_ITEM_NO_RACE;
+        item.base_type = OBJ_WEAPONS;
+        if (!melee_only)
+        {
+            switch (mon->type)
+            {
+                case MONS_FAUN:
+                default:
+                    item.sub_type = WPN_SLING;
+                    break;
+                case MONS_SATYR:
+                    item.sub_type = random_choose_weighted(3, WPN_LONGBOW,
+                                                           1, WPN_BOW,
+                                                           1, WPN_SLING,
+                                                           0);
+                    break;
+            }
+        }
+        else
+        {
+            item.sub_type = random_choose(WPN_SPEAR,
+                                          WPN_CLUB,
+                                          WPN_QUARTERSTAFF,
+                                          -1);
+        }
+        break;
+
     case MONS_NESSOS:
         force_item     = true;
         item_race      = MAKE_ITEM_NO_RACE;
@@ -992,7 +1035,6 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         item.flags |= ISFLAG_KNOW_TYPE;
         break;
 
-    case MONS_PALADIN:
     case MONS_DAEVA:
     case MONS_MENNAS:
         force_item     = true;
@@ -1119,37 +1161,13 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         item.sub_type  = WPN_DAGGER;
         break;
 
-    case MONS_UNBORN_DEEP_DWARF:
+    case MONS_UNBORN:
         if (one_chance_in(6))
             level = MAKE_GOOD_ITEM;
-        // deliberate fallthrough
-
-    case MONS_DEEP_DWARF_NECROMANCER:
-        item_race = MAKE_ITEM_DWARVEN;
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = WPN_HAND_AXE;
         break;
 
-    case MONS_DEEP_DWARF_ARTIFICER:
-        if (one_chance_in(25))
-        {
-            dprf(DIAG_MONPLACE, "generating a rare rod");
-            item.base_type = OBJ_RODS;
-            item.sub_type  = random2(NUM_RODS);
-        }
-        else
-        {
-            item.base_type = OBJ_WANDS;
-            item.sub_type  = random_choose_weighted(10, WAND_FROST,
-                                                    10, WAND_FLAME,
-                                                    8, WAND_MAGIC_DARTS,
-                                                    4, WAND_LIGHTNING,
-                                                    4, WAND_FIRE,
-                                                    4, WAND_COLD,
-                                                    0);
-        }
-        break;
-
     case MONS_DOWAN:
         item_race = MAKE_ITEM_ELVEN;
         item.base_type = OBJ_WEAPONS;
@@ -1303,6 +1321,23 @@ static item_make_species_type _give_weapon(monster* mon, int level,
                                        WPN_SABRE, -1);
         break;
 
+    case MONS_SPRIGGAN_ASSASSIN:
+        if (!melee_only)
+        {
+            item.base_type = OBJ_WEAPONS;
+            item.sub_type  = WPN_BLOWGUN;
+            item_race = MAKE_ITEM_NO_RACE;
+            break;
+        }
+        // deliberate fall-through
+    case MONS_SPRIGGAN_ENCHANTER:
+        item_race = MAKE_ITEM_NO_RACE;
+        if (one_chance_in(3))
+            level = MAKE_GOOD_ITEM;
+        item.base_type = OBJ_WEAPONS;
+        item.sub_type  = one_chance_in(12) ? WPN_QUICK_BLADE : WPN_DAGGER;
+        break;
+
     case MONS_SPRIGGAN_RIDER:
         if (!melee_only && one_chance_in(4))
         {
@@ -1323,6 +1358,12 @@ static item_make_species_type _give_weapon(monster* mon, int level,
                                        WPN_MACE,
                                        WPN_SHORT_SWORD,
                                        -1);
+        if (one_chance_in(4))
+        {
+            force_item = true;
+            set_item_ego_type(item, OBJ_WEAPONS, SPWPN_ANTIMAGIC);
+        }
+
         break;
 
     case MONS_SPRIGGAN_DRUID:
@@ -1333,7 +1374,6 @@ static item_make_species_type _give_weapon(monster* mon, int level,
 
     case MONS_SPRIGGAN_DEFENDER:
     case MONS_THE_ENCHANTRESS:
-        // High end gear, but alas, with an extra chance for distortion.
         item_race = MAKE_ITEM_NO_RACE;
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = random_choose(WPN_LAJATANG,    // best spriggan weapon
@@ -1343,7 +1383,7 @@ static item_make_species_type _give_weapon(monster* mon, int level,
                                        WPN_FLAIL,       // best ordinary 1-handed
                                        -1);
         level = MAKE_GOOD_ITEM;
-        if (one_chance_in(mon->type == MONS_THE_ENCHANTRESS ? 4 : 10))
+        if (mon->type == MONS_THE_ENCHANTRESS && one_chance_in(6))
         {
             force_item = true;
             set_item_ego_type(item, OBJ_WEAPONS, SPWPN_DISTORTION);
@@ -1369,6 +1409,42 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         item.sub_type  = WPN_DEMON_BLADE;
         break;
 
+    case MONS_ANCIENT_CHAMPION:
+        force_item = true;
+        item.base_type = OBJ_WEAPONS;
+        item.sub_type = random_choose(WPN_GREAT_MACE,
+                                      WPN_BATTLEAXE,
+                                      WPN_GREAT_SWORD,
+                                      -1);
+
+        if (x_chance_in_y(2, 3))
+        {
+            set_item_ego_type(item, OBJ_WEAPONS,
+                              random_choose_weighted(12, SPWPN_DRAINING,
+                                                      7, SPWPN_VORPAL,
+                                                      4, SPWPN_FREEZING,
+                                                      4, SPWPN_FLAMING,
+                                                      2, SPWPN_PAIN,
+                                                      0));
+        }
+
+        item.plus  += random2(4);
+        item.plus2 += random2(4);
+        break;
+
+    case MONS_SOJOBO:
+        item_race = MAKE_ITEM_NO_RACE;
+        item.base_type = OBJ_WEAPONS;
+        item.sub_type = one_chance_in(6) ? WPN_TRIPLE_SWORD
+                                         : WPN_GREAT_SWORD;
+        if (x_chance_in_y(2, 3))
+        {
+            force_item = true;
+            set_item_ego_type(item, OBJ_WEAPONS, SPWPN_ELECTROCUTION);
+        }
+        level = MAKE_GOOD_ITEM;
+        break;
+
     default:
         break;
     }
@@ -1437,8 +1513,14 @@ static void _give_ammo(monster* mon, int level,
         const object_class_type xitc = OBJ_MISSILES;
         int xitt = fires_ammo_type(*launcher);
 
-        if (xitt == MI_STONE && (one_chance_in(15) || mon->type == MONS_JOSEPH))
-            xitt = MI_SLING_BULLET;
+        if (xitt == MI_STONE
+            && (mon->type == MONS_JOSEPH
+                || mon->type == MONS_SATYR
+                || (mon->type == MONS_FAUN && one_chance_in(3))
+                || one_chance_in(15)))
+        {
+                xitt = MI_SLING_BULLET;
+        }
 
         const int thing_created = items(0, xitc, xitt, true, level, item_race);
 
@@ -1454,6 +1536,33 @@ static void _give_ammo(monster* mon, int level,
 
                 mitm[thing_created].quantity = random_range(4, 10);
             }
+            else if (mon->type == MONS_SPRIGGAN_ASSASSIN)
+            {
+
+                special_missile_type brand = random_choose_weighted(5, SPMSL_SLEEP,
+                                                              3, SPMSL_CONFUSION,
+                                                              2, SPMSL_PARALYSIS,
+                                                              2, SPMSL_CURARE,
+                                                              1, SPMSL_FRENZY,
+                                                              0);
+                switch (brand)
+                {
+                    case SPMSL_CONFUSION:
+                    case SPMSL_PARALYSIS:
+                    case SPMSL_FRENZY:
+                        mitm[thing_created].quantity = random_range(3, 7);
+                        break;
+                    case SPMSL_CURARE:
+                        mitm[thing_created].quantity = random_range(2, 5);
+                        break;
+                    case SPMSL_SLEEP: default:
+                        mitm[thing_created].quantity = random_range(4, 9);
+                        break;
+                }
+                set_item_ego_type(mitm[thing_created], OBJ_MISSILES,
+                                    brand);
+
+            }
             else
             {
                 set_item_ego_type(mitm[thing_created], OBJ_MISSILES,
@@ -1624,7 +1733,7 @@ static void _give_ammo(monster* mon, int level,
 
             w.quantity = qty;
             _give_monster_item(mon, thing_created, false,
-                               (weap_class == OBJ_WEAPONS?
+                               (weap_class == OBJ_WEAPONS ?
                                 &monster::pickup_melee_weapon
                                 : &monster::pickup_throwable_weapon));
         }
@@ -1673,7 +1782,6 @@ static void _give_shield(monster* mon, int level)
 
     switch (mon->type)
     {
-    case MONS_PALADIN:
     case MONS_DAEVA:
     case MONS_MENNAS:
         make_item_for_monster(mon, OBJ_ARMOUR, ARM_LARGE_SHIELD,
@@ -1690,7 +1798,6 @@ static void _give_shield(monster* mon, int level)
         }
         break;
 
-    case MONS_DEEP_ELF_SOLDIER:
     case MONS_DEEP_ELF_FIGHTER:
         if (one_chance_in(6))
         {
@@ -1725,12 +1832,26 @@ static void _give_shield(monster* mon, int level)
                                   level, MAKE_ITEM_NO_RACE);
         }
         break;
+    case MONS_TENGU_WARRIOR:
+        if (one_chance_in(3))
+            level = MAKE_GOOD_ITEM;
+        // deliberate fall-through
     case MONS_TENGU:
     case MONS_GNOLL_SERGEANT:
+        if (mon->type != MONS_TENGU_WARRIOR && !one_chance_in(3))
+            break;
+        make_item_for_monster(mon, OBJ_ARMOUR,
+                              coinflip() ? ARM_BUCKLER : ARM_SHIELD,
+                              level, MAKE_ITEM_NO_RACE);
+        break;
+    case MONS_TENGU_REAVER:
         if (one_chance_in(3))
+            level = MAKE_GOOD_ITEM;
+        // deliberate fall-through
+    case MONS_TENGU_CONJURER:
+        if (mon->type == MONS_TENGU_REAVER || one_chance_in(3))
         {
-            make_item_for_monster(mon, OBJ_ARMOUR,
-                                  coinflip() ? ARM_BUCKLER : ARM_SHIELD,
+            make_item_for_monster(mon, OBJ_ARMOUR, ARM_BUCKLER,
                                   level, MAKE_ITEM_NO_RACE);
         }
         break;
@@ -1743,6 +1864,8 @@ static void _give_shield(monster* mon, int level)
         break;
     case MONS_SPRIGGAN:
     case MONS_SPRIGGAN_RIDER:
+    case MONS_SPRIGGAN_ASSASSIN:
+    case MONS_SPRIGGAN_ENCHANTER:
         if (!one_chance_in(4))
             break;
     case MONS_SPRIGGAN_DEFENDER:
@@ -1846,7 +1969,6 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
     case MONS_DEEP_ELF_KNIGHT:
     case MONS_DEEP_ELF_MAGE:
     case MONS_DEEP_ELF_PRIEST:
-    case MONS_DEEP_ELF_SOLDIER:
     case MONS_DEEP_ELF_SORCERER:
     case MONS_DEEP_ELF_SUMMONER:
         if (item_race == MAKE_ITEM_RANDOM_RACE)
@@ -1894,10 +2016,16 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
         item.sub_type  = coinflip() ? ARM_ROBE : ARM_LEATHER_ARMOUR;
         break;
 
+    case MONS_SOJOBO:
+        level = MAKE_GOOD_ITEM;
+        // deliberate fall-through
     case MONS_GNOLL_SERGEANT:
+    case MONS_TENGU_REAVER:
         item_race      = MAKE_ITEM_NO_RACE;
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = coinflip() ? ARM_RING_MAIL : ARM_SCALE_MAIL;
+        if (type == MONS_TENGU_REAVER && one_chance_in(3))
+            level = MAKE_GOOD_ITEM;
         break;
 
     case MONS_JOSEPH:
@@ -1940,10 +2068,10 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
             level = MAKE_GOOD_ITEM;
         item_race      = MAKE_ITEM_DWARVEN;
         item.base_type = OBJ_ARMOUR;
-        item.sub_type = random_choose_weighted(3, ARM_CHAIN_MAIL,
-                            5, ARM_SPLINT_MAIL, 10, ARM_PLATE_ARMOUR,
-                            1, ARM_CRYSTAL_PLATE_ARMOUR,
-                            0);
+        item.sub_type = random_choose_weighted(8, ARM_CHAIN_MAIL,
+                                               10, ARM_PLATE_ARMOUR,
+                                               1, ARM_CRYSTAL_PLATE_ARMOUR,
+                                               0);
         break;
 
     case MONS_JORGRUN:
@@ -1966,7 +2094,6 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
         item_race = MAKE_ITEM_ORCISH;
         // deliberate fall through {dlb}
 
-    case MONS_PALADIN:
     case MONS_HELL_KNIGHT:
     case MONS_LOUISE:
     case MONS_DONALD:
@@ -1976,9 +2103,9 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
     case MONS_VAULT_GUARD:
     case MONS_VAULT_WARDEN:
     case MONS_IRONHEART_PRESERVER:
+    case MONS_ANCIENT_CHAMPION:
         item.base_type = OBJ_ARMOUR;
-        item.sub_type  = random_choose(ARM_CHAIN_MAIL,   ARM_SPLINT_MAIL,
-                                       ARM_PLATE_ARMOUR, -1);
+        item.sub_type  = random_choose(ARM_CHAIN_MAIL, ARM_PLATE_ARMOUR, -1);
         break;
 
     case MONS_VAULT_SENTINEL:
@@ -1989,8 +2116,7 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
 
     case MONS_FREDERICK:
         item.base_type = OBJ_ARMOUR;
-        item.sub_type  = random_choose(ARM_SCALE_MAIL,   ARM_CHAIN_MAIL,
-                                       ARM_SPLINT_MAIL, -1);
+        item.sub_type  = random_choose(ARM_SCALE_MAIL,   ARM_CHAIN_MAIL, -1);
         break;
 
     case MONS_MARGERY:
@@ -2001,12 +2127,10 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
                                                0);
         break;
 
-    case MONS_UNBORN_DEEP_DWARF:
+    case MONS_UNBORN:
         if (one_chance_in(6))
             level = MAKE_GOOD_ITEM;
-
-    case MONS_DEEP_DWARF_NECROMANCER:
-    case MONS_DEEP_DWARF_ARTIFICER:
+    // deliberate fall through
     case MONS_HELLBINDER:
         item_race      = MAKE_ITEM_NO_RACE;
         item.base_type = OBJ_ARMOUR;
@@ -2015,13 +2139,11 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
 
     case MONS_DWARF:
     case MONS_DEEP_DWARF:
-    case MONS_DEEP_DWARF_SCION:
     case MONS_DEEP_DWARF_DEATH_KNIGHT:
     case MONS_DEEP_DWARF_BERSERKER:
         item_race      = MAKE_ITEM_DWARVEN;
         item.base_type = OBJ_ARMOUR;
-        item.sub_type  = random_choose_weighted(5, ARM_CHAIN_MAIL,
-                                                2, ARM_SPLINT_MAIL,
+        item.sub_type  = random_choose_weighted(7, ARM_CHAIN_MAIL,
                                                 1, ARM_PLATE_ARMOUR,
                                                 0);
         break;
@@ -2106,6 +2228,12 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
             return;
         break;
 
+    case MONS_TENGU_WARRIOR:
+        item_race      = MAKE_ITEM_NO_RACE;
+        item.base_type = OBJ_ARMOUR;
+        item.sub_type  = coinflip() ? ARM_LEATHER_ARMOUR : ARM_RING_MAIL;
+        break;
+
     case MONS_LAMIA:
         item_race      = MAKE_ITEM_NO_RACE;
         item.base_type = OBJ_ARMOUR;
@@ -2162,6 +2290,8 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs)
     case MONS_MERFOLK_AQUAMANCER:
     case MONS_SPRIGGAN:
     case MONS_SPRIGGAN_AIR_MAGE:
+    case MONS_SPRIGGAN_ASSASSIN:
+    case MONS_SPRIGGAN_ENCHANTER:
     case MONS_SPRIGGAN_DEFENDER:
         if (item_race == MAKE_ITEM_RANDOM_RACE)
             item_race = MAKE_ITEM_NO_RACE;
