@@ -1088,7 +1088,7 @@ string monster_info::mimic_name() const
         else if (item->base_type == OBJ_ORBS)
             s += "orb";
         else
-            s += item->name(DESC_BASENAME);
+            s += item->name(DESC_DBNAME);
     }
 
     if (!s.empty())
