@@ -4,9 +4,13 @@
 
 /* *********************************************************************
 
+    This file determines which spells are contained in monster spellbooks.
+    It is used by /util/gen-mst.pl to generate spellbook enums, which are
+    listed in mon-mst.h.
 
     Template Format:
 
+    {    mon_spellbook_type,
         {
              bolt spell,
              enchantment,
@@ -15,6 +19,7 @@
              misc(2) spell,             // SPELL_DIG must be here to work!
              emergency spell            // only when fleeing
         }
+    }
 
 ********************************************************************* */
 
@@ -52,6 +57,7 @@
       }
     },
 
+#if TAG_MAJOR_VERSION == 34
     {  MST_DEEP_DWARF_NECROMANCER,
       {
        SPELL_PAIN,
@@ -62,15 +68,16 @@
        SPELL_VAMPIRIC_DRAINING
       }
     },
+#endif
 
-    {  MST_UNBORN_DEEP_DWARF,
+    {  MST_UNBORN,
       {
        SPELL_AGONY,
        SPELL_DISPEL_UNDEAD,
-       SPELL_MIRROR_DAMAGE,
+       SPELL_INJURY_MIRROR,
        SPELL_ANIMATE_DEAD,
        SPELL_HAUNT,
-       SPELL_MIRROR_DAMAGE
+       SPELL_INJURY_MIRROR
       }
     },
 
@@ -90,7 +97,7 @@
       {
        SPELL_NO_SPELL,
        SPELL_ANIMATE_DEAD,
-       SPELL_MIRROR_DAMAGE,
+       SPELL_INJURY_MIRROR,
        SPELL_NO_SPELL,
        SPELL_DRAIN_LIFE,
        SPELL_DRAIN_LIFE
@@ -190,7 +197,7 @@
        SPELL_BOLT_OF_DRAINING,
        SPELL_SUMMON_UNDEAD,
        SPELL_INVISIBILITY,
-       SPELL_ANIMATE_DEAD,
+       SPELL_VAMPIRIC_DRAINING,
        SPELL_ANIMATE_DEAD,
        SPELL_INVISIBILITY
       }
@@ -309,7 +316,7 @@
     {  MST_NECROMANCER_I,
       {
        SPELL_BOLT_OF_COLD,
-       SPELL_BOLT_OF_DRAINING,
+       SPELL_AGONY,
        SPELL_NO_SPELL,
        SPELL_ANIMATE_DEAD,
        SPELL_SIMULACRUM,
@@ -320,7 +327,7 @@
     {  MST_NECROMANCER_II,
       {
        SPELL_BOLT_OF_FIRE,
-       SPELL_PAIN,
+       SPELL_AGONY,
        SPELL_INVISIBILITY,
        SPELL_ANIMATE_DEAD,
        SPELL_ANIMATE_DEAD,
@@ -606,44 +613,33 @@
     {  MST_DEEP_ELF_SUMMONER,
       {
        SPELL_BLINK,
-       SPELL_SUMMON_MINOR_DEMON,
-       SPELL_SUMMON_UFETUBUS,
-       SPELL_SUMMON_DEMON,
-       SPELL_SUMMON_DEMON,
+       SPELL_SUMMON_VERMIN,
+       SPELL_NO_SPELL,
+       SPELL_SUMMON_VERMIN,
+       SPELL_NO_SPELL,
        SPELL_NO_SPELL
       }
     },
 
-    {  MST_DEEP_ELF_CONJURER_I,
+    {  MST_DEEP_ELF_CONJURER,
       {
        SPELL_BOLT_OF_FIRE,
        SPELL_BOLT_OF_COLD,
-       SPELL_CANTRIP,
+       SPELL_NO_SPELL,
        SPELL_LIGHTNING_BOLT,
        SPELL_BOLT_OF_DRAINING,
        SPELL_NO_SPELL
       }
     },
 
-    {  MST_DEEP_ELF_CONJURER_II,
-      {
-       SPELL_STICKY_FLAME_RANGE,
-       SPELL_ISKENDERUNS_MYSTIC_BLAST,
-       SPELL_INVISIBILITY,
-       SPELL_STONE_ARROW,
-       SPELL_BOLT_OF_DRAINING,
-       SPELL_INVISIBILITY
-      }
-    },
-
     {  MST_DEEP_ELF_PRIEST,
       {
        SPELL_PAIN,
-       SPELL_CANTRIP,
-       SPELL_MINOR_HEALING,
+       SPELL_MALIGN_OFFERING,
+       SPELL_NO_SPELL,
        SPELL_SMITING,
        SPELL_TWISTED_RESURRECTION,
-       SPELL_MINOR_HEALING
+       SPELL_NO_SPELL
       }
     },
 
@@ -651,10 +647,10 @@
       {
        SPELL_SUMMON_DEMON,
        SPELL_HELLFIRE_BURST,
-       SPELL_MINOR_HEALING,
+       SPELL_MALIGN_OFFERING,
        SPELL_SMITING,
        SPELL_TWISTED_RESURRECTION,
-       SPELL_MINOR_HEALING
+       SPELL_NO_SPELL
       }
     },
 
@@ -696,7 +692,7 @@
        SPELL_BOLT_OF_DRAINING,
        SPELL_BOLT_OF_DRAINING,
        SPELL_VAMPIRIC_DRAINING,
-       SPELL_TWISTED_RESURRECTION,
+       SPELL_CALL_LOST_SOUL,
        SPELL_TWISTED_RESURRECTION,
        SPELL_VAMPIRIC_DRAINING
       }
@@ -715,8 +711,8 @@
 
     {  MST_NAGA,
       {
-       SPELL_POISON_SPLASH,
-       SPELL_POISON_SPLASH,
+       SPELL_SPIT_POISON,
+       SPELL_SPIT_POISON,
        SPELL_NO_SPELL,
        SPELL_NO_SPELL,
        SPELL_NO_SPELL,
@@ -925,10 +921,10 @@
     {  MST_SERPENT_OF_HELL_TARTARUS,
       {
        SPELL_BOLT_OF_DRAINING,
-       SPELL_MIASMA,
+       SPELL_MIASMA_BREATH,
        SPELL_NO_SPELL,
        SPELL_BOLT_OF_DRAINING,
-       SPELL_MIASMA,
+       SPELL_MIASMA_BREATH,
        SPELL_NO_SPELL
       }
     },
@@ -977,17 +973,6 @@
       }
     },
 
-    {  MST_SKELETAL_WARRIOR,
-      {
-       SPELL_ANIMATE_DEAD,
-       SPELL_NO_SPELL,
-       SPELL_ANIMATE_DEAD,
-       SPELL_NO_SPELL,
-       SPELL_NO_SPELL,
-       SPELL_NO_SPELL
-      }
-    },
-
     {  MST_NORRIS,
       {
        SPELL_BRAIN_FEED,
@@ -1001,11 +986,11 @@
 
     {  MST_DEATH_DRAKE,
       {
-       SPELL_MIASMA,
-       SPELL_MIASMA,
+       SPELL_MIASMA_BREATH,
+       SPELL_MIASMA_BREATH,
        SPELL_NO_SPELL,
-       SPELL_MIASMA,
-       SPELL_MIASMA,
+       SPELL_MIASMA_BREATH,
+       SPELL_MIASMA_BREATH,
        SPELL_NO_SPELL
       }
     },
@@ -1034,12 +1019,12 @@
 
     {  MST_DRAC_SHIFTER,
       {
-       SPELL_BANISHMENT,
+       SPELL_DIMENSION_ANCHOR,
        SPELL_BLINK_OTHER,
-       SPELL_BLINK,
+       SPELL_BLINK_RANGE,
+       SPELL_BLINK_ALLIES_ENCIRCLE,
        SPELL_NO_SPELL,
-       SPELL_BLINK_OTHER,
-       SPELL_CONTROLLED_BLINK
+       SPELL_BLINK_AWAY
       }
     },
 
@@ -1047,12 +1032,12 @@
     // too much time crawling around.
     {  MST_CURSE_TOE,
       {
-       SPELL_SUMMON_UNDEAD,
+       SPELL_SYMBOL_OF_TORMENT,
        SPELL_SUMMON_MUSHROOMS, // fungal theme
        SPELL_SUMMON_MUSHROOMS,
        SPELL_SYMBOL_OF_TORMENT,
-       SPELL_SUMMON_UNDEAD,
-       SPELL_SYMBOL_OF_TORMENT
+       SPELL_SUMMON_MUSHROOMS,
+       SPELL_NO_SPELL
       }
     },
 
@@ -1165,7 +1150,7 @@
 
     { MST_EUSTACHIO,
       {
-       SPELL_SUMMON_SMALL_MAMMALS,
+       SPELL_SUMMON_SMALL_MAMMAL,
        SPELL_SUMMON_MINOR_DEMON,
        SPELL_BLINK,
        SPELL_NO_SPELL,
@@ -1233,7 +1218,7 @@
       {
        SPELL_BOLT_OF_COLD,
        SPELL_OZOCUBUS_REFRIGERATION,
-       SPELL_OZOCUBUS_ARMOUR,
+       SPELL_SUMMON_ICE_BEAST,
        SPELL_SUMMON_ICE_BEAST,
        SPELL_OZOCUBUS_REFRIGERATION,
        SPELL_BLINK,
@@ -1245,7 +1230,7 @@
        SPELL_AIRSTRIKE,
        SPELL_SLOW,
        SPELL_SWIFTNESS,
-       SPELL_SUMMON_SMALL_MAMMALS,
+       SPELL_SUMMON_SMALL_MAMMAL,
        SPELL_CANTRIP,
        SPELL_AIRSTRIKE,
       }
@@ -1265,12 +1250,12 @@
     // demon lords
     {  MST_GERYON,
       {
-       SPELL_SUMMON_BEAST,
-       SPELL_SUMMON_BEAST,
+       SPELL_SUMMON_HELL_BEAST,
+       SPELL_SUMMON_HELL_BEAST,
        SPELL_NO_SPELL,
-       SPELL_SUMMON_BEAST,
+       SPELL_SUMMON_HELL_BEAST,
        SPELL_NO_SPELL,
-       SPELL_SUMMON_BEAST
+       SPELL_SUMMON_HELL_BEAST
       }
     },
 
@@ -1354,11 +1339,11 @@
     {  MST_GLOORX_VLOQ,
       {
        SPELL_POISON_ARROW,
-       SPELL_MIASMA,
+       SPELL_MIASMA_BREATH,
        SPELL_SYMBOL_OF_TORMENT,
        SPELL_BOLT_OF_DRAINING,
        SPELL_DISPEL_UNDEAD,
-       SPELL_INVISIBILITY
+       SPELL_NO_SPELL
       }
     },
 
@@ -1498,9 +1483,9 @@
       {
        SPELL_SUNRAY,
        SPELL_AWAKEN_FOREST,
-       SPELL_NO_SPELL,
-       SPELL_SUMMON_CANIFORMS,
-       SPELL_NO_SPELL,
+       SPELL_HASTE_PLANTS,
+       SPELL_DRUIDS_CALL,
+       SPELL_HASTE_PLANTS,
        SPELL_MINOR_HEALING
       }
     },
@@ -1509,21 +1494,21 @@
       {
        SPELL_AIRSTRIKE,
        SPELL_LIGHTNING_BOLT,
-       SPELL_SWIFTNESS,
+       SPELL_CONTROL_WINDS,
        SPELL_SHOCK,
        SPELL_NO_SPELL,
-       SPELL_HASTE
+       SPELL_NO_SPELL
       }
     },
 
     { MST_THE_ENCHANTRESS,
       {
-       SPELL_CORONA,
-       SPELL_SLEEP,
+       SPELL_DIMENSION_ANCHOR,
+       SPELL_SLOW,
        SPELL_HASTE,
-       SPELL_BANISHMENT,
-       SPELL_INVISIBILITY,
-       SPELL_TELEPORT_SELF
+       SPELL_MASS_CONFUSION,
+       SPELL_STRIP_RESISTANCE,
+       SPELL_INVISIBILITY
       }
     },
 
@@ -1586,7 +1571,7 @@
       {
        SPELL_BOLT_OF_DRAINING,
        SPELL_SUMMON_SPECTRAL_ORCS,
-       SPELL_REGENERATION,
+       SPELL_SUMMON_SPECTRAL_ORCS,
        SPELL_DISPEL_UNDEAD,
        SPELL_HASTE_OTHER,
        SPELL_DEATHS_DOOR
@@ -1608,7 +1593,7 @@
       {
        SPELL_IOOD,
        SPELL_NO_SPELL,
-       SPELL_CANTRIP,
+       SPELL_IOOD,
        SPELL_IOOD,
        SPELL_NO_SPELL,
        SPELL_IOOD
@@ -1626,17 +1611,6 @@
       }
     },
 
-    {  MST_SPIRIT,
-      {
-       SPELL_BLINK_AWAY,
-       SPELL_BLINK_AWAY,
-       SPELL_BLINK_AWAY,
-       SPELL_BLINK_AWAY,
-       SPELL_BLINK_AWAY,
-       SPELL_BLINK_AWAY
-      }
-    },
-
     {  MST_OPHAN,
       {
        SPELL_BOLT_OF_FIRE,
@@ -1683,8 +1657,8 @@
 
     {  MST_EIDOLON,
       {
-       SPELL_PAIN,
-       SPELL_CAUSE_FEAR,
+       SPELL_MELEE,
+       SPELL_BOLT_OF_DRAINING,
        SPELL_NO_SPELL,
        SPELL_CAUSE_FEAR,
        SPELL_NO_SPELL,
@@ -1921,6 +1895,336 @@
        SPELL_SHADOW_CREATURES,
        SPELL_SHADOW_CREATURES
       }
-    }
+    },
+
+    {  MST_ANCIENT_CHAMPION_I,
+      {
+       SPELL_IRON_SHOT,
+       SPELL_NO_SPELL,
+       SPELL_HASTE,
+       SPELL_PAIN,
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_ANCIENT_CHAMPION_II,
+      {
+       SPELL_BOLT_OF_DRAINING,
+       SPELL_NO_SPELL,
+       SPELL_HASTE,
+       SPELL_STONE_ARROW,
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_ANCIENT_CHAMPION_III,
+      {
+       SPELL_VENOM_BOLT,
+       SPELL_NO_SPELL,
+       SPELL_ANIMATE_DEAD,
+       SPELL_HAUNT,
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_ANCIENT_CHAMPION_IV,
+      {
+       SPELL_ISKENDERUNS_MYSTIC_BLAST,
+       SPELL_SLOW,
+       SPELL_HASTE,
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_REVENANT,
+      {
+       SPELL_GHOSTLY_FIREBALL,
+       SPELL_GHOSTLY_FLAMES,
+       SPELL_NO_SPELL,
+       SPELL_DISPEL_UNDEAD,
+       SPELL_NO_SPELL,
+       SPELL_BLINK_AWAY
+      }
+    },
+
+    {  MST_DRYAD,
+      {
+       SPELL_AWAKEN_VINES,
+       SPELL_AWAKEN_VINES,
+       SPELL_NO_SPELL,
+       SPELL_AWAKEN_FOREST,
+       SPELL_AWAKEN_FOREST,
+       SPELL_MINOR_HEALING
+      }
+    },
+
+    {  MST_FAUN,
+      {
+       SPELL_CORONA,
+       SPELL_NO_SPELL,
+       SPELL_CORONA,
+       SPELL_SLOW,
+       SPELL_CONFUSE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_SATYR,
+      {
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL,
+       SPELL_CAUSE_FEAR,
+       SPELL_CAUSE_FEAR,
+       SPELL_SLEEP,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_PAN,
+      {
+       SPELL_NO_SPELL,
+       SPELL_MASS_CONFUSION,
+       SPELL_NO_SPELL,
+       SPELL_ENGLACIATION,
+       SPELL_SLEEP,
+       SPELL_BLINK
+      }
+    },
+
+    {  MST_TENGU_CONJURER_I,
+      {
+       SPELL_FORCE_LANCE,
+       SPELL_ISKENDERUNS_MYSTIC_BLAST,
+       SPELL_BATTLESPHERE,
+       SPELL_ISKENDERUNS_MYSTIC_BLAST,
+       SPELL_BATTLESPHERE,
+       SPELL_BLINK
+      }
+    },
+
+    {  MST_TENGU_CONJURER_II,
+      {
+       SPELL_THROW_FLAME,
+       SPELL_BOLT_OF_MAGMA,
+       SPELL_BATTLESPHERE,
+       SPELL_BOLT_OF_MAGMA,
+       SPELL_BATTLESPHERE,
+       SPELL_BLINK
+      }
+    },
+
+    {  MST_TENGU_CONJURER_III,
+      {
+       SPELL_SHOCK,
+       SPELL_LIGHTNING_BOLT,
+       SPELL_BATTLESPHERE,
+       SPELL_LIGHTNING_BOLT,
+       SPELL_BATTLESPHERE,
+       SPELL_BLINK
+      }
+    },
+
+    {  MST_TENGU_CONJURER_IV,
+      {
+       SPELL_MEPHITIC_CLOUD,
+       SPELL_VENOM_BOLT,
+       SPELL_BATTLESPHERE,
+       SPELL_VENOM_BOLT,
+       SPELL_BATTLESPHERE,
+       SPELL_BLINK
+      }
+    },
+
+    {  MST_TENGU_REAVER_I,
+      {
+       SPELL_LIGHTNING_BOLT,
+       SPELL_LIGHTNING_BOLT,
+       SPELL_BATTLESPHERE,
+       SPELL_FREEZING_CLOUD,
+       SPELL_BATTLESPHERE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_TENGU_REAVER_II,
+      {
+       SPELL_BOLT_OF_MAGMA,
+       SPELL_NO_SPELL,
+       SPELL_BATTLESPHERE,
+       SPELL_FIREBALL,
+       SPELL_BATTLESPHERE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_TENGU_REAVER_III,
+      {
+       SPELL_VENOM_BOLT,
+       SPELL_VENOM_BOLT,
+       SPELL_BATTLESPHERE,
+       SPELL_POISONOUS_CLOUD,
+       SPELL_BATTLESPHERE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_SPRIGGAN_ENCHANTER,
+      {
+       SPELL_SLEEP,
+       SPELL_SLEEP,
+       SPELL_INVISIBILITY,
+       SPELL_NO_SPELL,
+       SPELL_STRIP_RESISTANCE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_SOJOBO,
+      {
+       SPELL_LIGHTNING_BOLT,
+       SPELL_NO_SPELL,
+       SPELL_WIND_BLAST,
+       SPELL_AIRSTRIKE,
+       SPELL_AIR_ELEMENTALS,
+       SPELL_WIND_BLAST
+      }
+    },
+
+    {  MST_WIND_DRAKE,
+      {
+       SPELL_AIRSTRIKE,
+       SPELL_MELEE,
+       SPELL_NO_SPELL,
+       SPELL_AIRSTRIKE,
+       SPELL_MELEE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_THORN_HUNTER,
+      {
+       SPELL_THORN_VOLLEY,
+       SPELL_THORN_VOLLEY,
+       SPELL_NO_SPELL,
+       SPELL_WALL_OF_BRAMBLES,
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_WATER_NYMPH,
+      {
+       SPELL_WATERSTRIKE,
+       SPELL_WATERSTRIKE,
+       SPELL_NO_SPELL,
+       SPELL_WATERSTRIKE,
+       SPELL_WATERSTRIKE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_THORN_LOTUS,
+      {
+       SPELL_THORN_VOLLEY,
+       SPELL_THORN_VOLLEY,
+       SPELL_NO_SPELL,
+       SPELL_THORN_VOLLEY,
+       SPELL_THORN_VOLLEY,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_VAPOUR,
+      {
+       SPELL_LIGHTNING_BOLT,
+       SPELL_LIGHTNING_BOLT,
+       SPELL_MELEE,
+       SPELL_LIGHTNING_BOLT,
+       SPELL_NO_SPELL,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_ELEMENTAL_WELLSPRING,
+      {
+       SPELL_PRIMAL_WAVE,
+       SPELL_PRIMAL_WAVE,
+       SPELL_NO_SPELL,
+       SPELL_PRIMAL_WAVE,
+       SPELL_PRIMAL_WAVE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_DRACONIAN_ZEALOT,
+      {
+       SPELL_SUMMON_DEMON,
+       SPELL_HELLFIRE_BURST,
+       SPELL_MINOR_HEALING,
+       SPELL_SMITING,
+       SPELL_ANIMATE_DEAD,
+       SPELL_MINOR_HEALING
+      }
+    },
+
+    {  MST_DEEP_ELF_MAGE_I,
+      {
+       SPELL_FREEZE,
+       SPELL_THROW_ICICLE,
+       SPELL_FREEZE,
+       SPELL_SUMMON_ICE_BEAST,
+       SPELL_THROW_ICICLE,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_DEEP_ELF_MAGE_II,
+      {
+       SPELL_BOLT_OF_MAGMA,
+       SPELL_STONE_ARROW,
+       SPELL_NO_SPELL,
+       SPELL_PETRIFY,
+       SPELL_STONE_ARROW,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_DEEP_ELF_MAGE_III,
+      {
+       SPELL_ISKENDERUNS_MYSTIC_BLAST,
+       SPELL_SLOW,
+       SPELL_NO_SPELL,
+       SPELL_VENOM_BOLT,
+       SPELL_BLINK,
+       SPELL_BLINK
+      }
+    },
+
+    {  MST_DEEP_ELF_MAGE_IV,
+      {
+       SPELL_FLAME_TONGUE,
+       SPELL_STICKY_FLAME_RANGE,
+       SPELL_FIREBALL,
+       SPELL_FIREBALL,
+       SPELL_THROW_FLAME,
+       SPELL_NO_SPELL
+      }
+    },
+
+    {  MST_DEEP_ELF_MAGE_V,
+      {
+       SPELL_MAGIC_DART,
+       SPELL_FORCE_LANCE,
+       SPELL_BATTLESPHERE,
+       SPELL_ISKENDERUNS_MYSTIC_BLAST,
+       SPELL_BATTLESPHERE,
+       SPELL_NO_SPELL
+      }
+    },
 
 #endif
