@@ -22,11 +22,11 @@ struct follower
     void restore_mons_items(monster& m);
 };
 
-typedef std::list<follower> m_transit_list;
-typedef std::map<level_id, m_transit_list> monsters_in_transit;
+typedef list<follower> m_transit_list;
+typedef map<level_id, m_transit_list> monsters_in_transit;
 
-typedef std::list<item_def> i_transit_list;
-typedef std::map<level_id, i_transit_list> items_in_transit;
+typedef list<item_def> i_transit_list;
+typedef map<level_id, i_transit_list> items_in_transit;
 
 extern monsters_in_transit the_lost_ones;
 extern items_in_transit    transiting_items;
@@ -37,6 +37,8 @@ m_transit_list *get_transit_list(const level_id &where);
 void add_monster_to_transit(const level_id &dest, const monster& m);
 void add_item_to_transit(const level_id &dest, const item_def &i);
 
+void remove_monster_from_transit(const level_id &lid, mid_t mid);
+
 // Places (some of the) monsters eligible to be placed on this level.
 void place_transiting_monsters();
 void place_followers();
@@ -46,4 +48,7 @@ void place_transiting_items();
 void tag_followers();
 void untag_followers();
 
+void apply_daction_to_transit(daction_type act);
+int count_daction_in_transit(daction_type act);
+
 #endif
