@@ -3,6 +3,7 @@
 #include "ng-setup.h"
 
 #include "abl-show.h"
+#include "decks.h"
 #include "dungeon.h"
 #include "files.h"
 #include "food.h"
@@ -21,12 +22,14 @@
 #include "ng-wanderer.h"
 #include "options.h"
 #include "player.h"
+#include "religion.h"
 #include "skills.h"
 #include "skills2.h"
 #include "spl-book.h"
 #include "spl-util.h"
 #include "state.h"
 #include "stuff.h"
+#include "tilepick.h"
 #include "tutorial.h"
 
 #define MIN_START_STAT       3
@@ -68,7 +71,9 @@ static void _species_stat_init(species_type which_species)
     case SP_OGRE:               sb = 10; ib =  5; db =  3;      break;  // 18
 
     case SP_MINOTAUR:           sb = 10; ib =  3; db =  3;      break;  // 16
+    case SP_GARGOYLE:           sb =  9; ib =  6; db =  3;      break;  // 18
     case SP_HILL_ORC:           sb =  8; ib =  6; db =  4;      break;  // 18
+    case SP_LAVA_ORC:           sb =  8; ib =  6; db =  4;      break;  // 18
     case SP_CENTAUR:            sb =  8; ib =  5; db =  2;      break;  // 15
     case SP_NAGA:               sb =  8; ib =  6; db =  4;      break;  // 18
 
@@ -158,13 +163,12 @@ static void _jobs_stat_init(job_type which_job)
     case JOB_BERSERKER:         s =  9; i = -1; d =  4; hp = 15; mp = 0; break;
     case JOB_GLADIATOR:         s =  7; i =  0; d =  5; hp = 14; mp = 0; break;
 
-    case JOB_SKALD:             s =  4; i =  4; d =  4; hp = 13; mp = 1; break;
+    case JOB_SKALD:             s =  4; i =  4; d =  4; hp = 12; mp = 3; break;
     case JOB_CHAOS_KNIGHT:      s =  4; i =  4; d =  4; hp = 13; mp = 1; break;
     case JOB_DEATH_KNIGHT:      s =  5; i =  3; d =  4; hp = 13; mp = 2; break;
     case JOB_ABYSSAL_KNIGHT:    s =  4; i =  4; d =  4; hp = 13; mp = 1; break;
 
     case JOB_HEALER:            s =  4; i =  4; d =  4; hp = 13; mp = 2; break;
-    case JOB_PRIEST:            s =  4; i =  4; d =  4; hp = 13; mp = 2; break;
 
     case JOB_ASSASSIN:          s =  3; i =  3; d =  6; hp = 12; mp = 0; break;
 
@@ -237,12 +241,19 @@ static void _give_bonus_items()
     _newgame_give_item(OBJ_SCROLLS, SCR_BLINKING);
 }
 
+void autopickup_starting_ammo(missile_type missile)
+{
+    if (Options.autopickup_starting_ammo)
+        you.force_autopickup[OBJ_MISSILES][missile] = 1;
+}
+
 void give_basic_mutations(species_type speci)
 {
-    // We should switch over to a size-based system
-    // for the fast/slow metabolism when we get around to it.
     switch (speci)
     {
+    case SP_LAVA_ORC:
+        you.mutation[MUT_CONSERVE_SCROLLS] = 1;
+    // Intentional fallthrough.
     case SP_HILL_ORC:
         you.mutation[MUT_SAPROVOROUS] = 1;
         break;
@@ -299,6 +310,15 @@ void give_basic_mutations(species_type speci)
         you.mutation[MUT_SLOW_HEALING]               = 1;
         you.mutation[MUT_UNBREATHING]                = 1;
         break;
+    case SP_GARGOYLE:
+        you.mutation[MUT_PETRIFICATION_RESISTANCE]   = 1;
+        you.mutation[MUT_NEGATIVE_ENERGY_RESISTANCE] = 1;
+        you.mutation[MUT_SHOCK_RESISTANCE]           = 1;
+        you.mutation[MUT_FANGS]                      = 1;
+        you.mutation[MUT_TALONS]                     = 2;
+        you.mutation[MUT_SLOW_METABOLISM]            = 1;
+        you.mutation[MUT_UNBREATHING]                = 1;
+        break;
     case SP_TENGU:
         you.mutation[MUT_BEAK]   = 1;
         you.mutation[MUT_TALONS] = 3;
@@ -332,14 +352,13 @@ void give_basic_mutations(species_type speci)
         you.mutation[MUT_CAMOUFLAGE]      = 1;
         you.mutation[MUT_GELATINOUS_BODY] = 1;
         break;
+    case SP_DJINNI:
+        you.mutation[MUT_NEGATIVE_ENERGY_RESISTANCE] = 3;
+        break;
     default:
         break;
     }
 
-    // Zot def games come with teleport control
-    if (crawl_state.game_is_zotdef())
-        you.mutation[MUT_TELEPORT_CONTROL] = 1;
-
     // Some mutations out-sourced because they're
     // relevant during character choice.
     you.mutation[MUT_CLAWS] = species_has_claws(speci, true);
@@ -404,13 +423,31 @@ void newgame_make_item(int slot, equipment_type eqslot,
     item.plus2     = plus2;
     item.special   = 0;
 
+    if (is_deck(item))
+    {
+        item.plus = 6 + random2(6); // # of cards
+        item.special = DECK_RARITY_COMMON;
+        init_deck(item);
+    }
+
     // If the character is restricted in wearing armour of equipment
     // slot eqslot, hand out replacement instead.
     if (item.base_type == OBJ_ARMOUR && replacement != -1
-        && !can_wear_armour(item, false, true))
+        && !can_wear_armour(item, false, false))
     {
         item.sub_type = replacement;
     }
+    if (eqslot == EQ_WEAPON && replacement != -1
+        && !can_wield(&item, false, false))
+    {
+        item.sub_type = replacement;
+    }
+
+    if (item.base_type == OBJ_ARMOUR && !can_wear_armour(item, false, false))
+        return;
+
+    if (eqslot == EQ_WEAPON && !can_wield(&item, false, false))
+        return;
 
     if (eqslot != EQ_NONE && you.equip[eqslot] == -1)
         you.equip[eqslot] = slot;
@@ -442,18 +479,22 @@ static void _update_weapon(const newgame_def& ng)
     case WPN_ROCKS:
         newgame_make_item(1, EQ_NONE, OBJ_MISSILES, MI_LARGE_ROCK, -1, 4 + plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_THROWING_NET, -1, 2);
+        autopickup_starting_ammo(MI_LARGE_ROCK);
         break;
     case WPN_JAVELINS:
         newgame_make_item(1, EQ_NONE, OBJ_MISSILES, MI_JAVELIN, -1, 5 + plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_THROWING_NET, -1, 2);
+        autopickup_starting_ammo(MI_JAVELIN);
         break;
     case WPN_DARTS:
         newgame_make_item(1, EQ_NONE, OBJ_MISSILES, MI_DART, -1, 20 + 10 * plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_THROWING_NET, -1, 2);
+        autopickup_starting_ammo(MI_DART);
         break;
     case WPN_BOW:
         newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_BOW, -1, 1, plus, plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_ARROW, -1, 20);
+        autopickup_starting_ammo(MI_ARROW);
 
         // Wield the bow instead.
         you.equip[EQ_WEAPON] = 1;
@@ -461,6 +502,7 @@ static void _update_weapon(const newgame_def& ng)
     case WPN_CROSSBOW:
         newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_CROSSBOW, -1, 1, plus, plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_BOLT, -1, 20);
+        autopickup_starting_ammo(MI_BOLT);
 
         // Wield the crossbow instead.
         you.equip[EQ_WEAPON] = 1;
@@ -468,6 +510,7 @@ static void _update_weapon(const newgame_def& ng)
     case WPN_SLING:
         newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_SLING, -1, 1, plus, plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_SLING_BULLET, -1, 20);
+        autopickup_starting_ammo(MI_SLING_BULLET);
 
         // Wield the sling instead.
         you.equip[EQ_WEAPON] = 1;
@@ -582,34 +625,13 @@ static void _give_items_skills(const newgame_def& ng)
         }
         break;
 
-    case JOB_PRIEST:
-        if (you.species == SP_HILL_ORC)
-            you.religion = GOD_BEOGH;
-        else
-            you.religion = GOD_ZIN;
-
-        you.piety = 45;
-
-        if (you.religion == GOD_BEOGH)
-            newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_HAND_AXE);
-        else
-            newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_QUARTERSTAFF);
-
-        newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE);
-
-        you.skills[SK_FIGHTING]    = 2;
-        you.skills[SK_INVOCATIONS] = 5;
-        you.skills[SK_DODGING]     = 1;
-        weap_skill = 3;
-        break;
-
     case JOB_CHAOS_KNIGHT:
         you.religion = GOD_XOM;
         you.piety = 100;
         you.gift_timeout = max(5, random2(40) + random2(40));
 
-        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1,
-                           2, 2);
+        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD);
+        set_item_ego_type(you.inv[0], OBJ_WEAPONS, SPWPN_CHAOS);
         _update_weapon(ng);
 
         newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_LEATHER_ARMOUR,
@@ -684,12 +706,12 @@ static void _give_items_skills(const newgame_def& ng)
         break;
 
     case JOB_SKALD:
-        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD);
+        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1, 0, 0);
         _update_weapon(ng);
 
         newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_LEATHER_ARMOUR,
                            ARM_ROBE);
-        newgame_make_item(2, EQ_NONE, OBJ_BOOKS, BOOK_WAR_CHANTS);
+        newgame_make_item(2, EQ_NONE, OBJ_BOOKS, BOOK_BATTLE);
 
         you.skills[SK_FIGHTING]     = 2;
         you.skills[SK_ARMOUR]       = 1;
@@ -780,7 +802,6 @@ static void _give_items_skills(const newgame_def& ng)
         you.skills[SK_SPELLCASTING] = 1;
         you.skills[SK_DODGING]      = 2;
         you.skills[SK_STEALTH]      = 2;
-        you.skills[SK_STABBING]     = 1;
         break;
 
     case JOB_SUMMONER:
@@ -857,6 +878,9 @@ static void _give_items_skills(const newgame_def& ng)
         newgame_make_item(2, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE);
         newgame_make_item(3, EQ_NONE, OBJ_BOOKS, BOOK_GEOMANCY);
 
+        // sandblast goes through a lot of stones
+        autopickup_starting_ammo(MI_STONE);
+
         you.skills[SK_TRANSMUTATIONS] = 1;
         you.skills[SK_EARTH_MAGIC]    = 3;
         you.skills[SK_SPELLCASTING]   = 1;
@@ -887,6 +911,7 @@ static void _give_items_skills(const newgame_def& ng)
         set_item_ego_type(you.inv[4], OBJ_MISSILES, SPMSL_POISONED);
         newgame_make_item(5, EQ_NONE, OBJ_MISSILES, MI_NEEDLE, -1, 2);
         set_item_ego_type(you.inv[5], OBJ_MISSILES, SPMSL_CURARE);
+        autopickup_starting_ammo(MI_NEEDLE);
 
         if (you.species == SP_OGRE || you.species == SP_TROLL)
             you.inv[0].sub_type = WPN_CLUB;
@@ -894,8 +919,7 @@ static void _give_items_skills(const newgame_def& ng)
         weap_skill = 2;
         you.skills[SK_FIGHTING]     = 2;
         you.skills[SK_DODGING]      = 1;
-        you.skills[SK_STEALTH]      = 3;
-        you.skills[SK_STABBING]     = 2;
+        you.skills[SK_STEALTH]      = 4;
         you.skills[SK_THROWING]     = 2;
         break;
 
@@ -910,6 +934,16 @@ static void _give_items_skills(const newgame_def& ng)
         newgame_make_item(3, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_LEATHER_ARMOUR,
                            ARM_ANIMAL_SKIN);
 
+        // This is meant to match the En/As start change-up, but Trolls have
+        // claws, so they don't get a starting melee weapon (see above).
+        // The +1 is meant to make this less sucky; it could be a better
+        // base type, but whips don't seem very hunter-ish.
+        if (you.species == SP_OGRE)
+        {
+            you.inv[0].sub_type = WPN_CLUB;
+            you.inv[0].plus = you.inv[0].plus2 = 1;
+        }
+
         // Skills.
         you.skills[SK_FIGHTING] = 2;
         you.skills[SK_DODGING]  = 2;
@@ -940,9 +974,15 @@ static void _give_items_skills(const newgame_def& ng)
         newgame_make_item(4, EQ_BODY_ARMOUR, OBJ_ARMOUR,
                            ARM_LEATHER_ARMOUR, ARM_ROBE);
 
+        // See Hunter notes above.
+        if (you.species == SP_OGRE)
+        {
+            you.inv[0].sub_type = WPN_CLUB;
+            you.inv[0].plus = you.inv[0].plus2 = 1;
+        }
+
         // Skills
         you.skills[SK_EVOCATIONS]  = 3;
-        you.skills[SK_TRAPS]       = 2;
         you.skills[SK_DODGING]     = 2;
         you.skills[SK_FIGHTING]    = 1;
         weap_skill                 = 1;
@@ -957,14 +997,9 @@ static void _give_items_skills(const newgame_def& ng)
     if (you.species == SP_DEEP_DWARF)
         newgame_make_item(-1, EQ_NONE, OBJ_WANDS, WAND_HEAL_WOUNDS, -1, 1, 5);
 
-    // Zotdef: everyone gets a bonus two potions of curing, plus two
-    // free levels in Traps & Doors so they can replace old traps with
-    // better ones.
+    // Zotdef: everyone gets bonus two potions of curing.
     if (crawl_state.game_is_zotdef())
-    {
         newgame_make_item(-1, EQ_NONE, OBJ_POTIONS, POT_CURING, -1, 2);
-        you.skills[SK_TRAPS] += 2;
-    }
 
     if (weap_skill)
     {
@@ -985,11 +1020,11 @@ static void _give_items_skills(const newgame_def& ng)
         you.skills[SK_SHIELDS] = 0;
     }
 
-    if (you.religion != GOD_NO_GOD)
+    if (!you_worship(GOD_NO_GOD))
     {
         you.worshipped[you.religion] = 1;
         set_god_ability_slots();
-        if (you.religion != GOD_XOM)
+        if (!you_worship(GOD_XOM))
             you.piety_max[you.religion] = you.piety;
     }
 }
@@ -1031,7 +1066,7 @@ static void _give_starting_food()
     else
     {
         item.base_type = OBJ_FOOD;
-        if (you.species == SP_HILL_ORC || you.species == SP_KOBOLD
+        if (player_genus(GENPC_ORCISH) || you.species == SP_KOBOLD
             || you.species == SP_OGRE || you.species == SP_TROLL
             || you.species == SP_FELID)
         {
@@ -1103,7 +1138,7 @@ static void _racialise_starting_equipment()
                     set_equip_race(you.inv[i], ISFLAG_ELVEN);
                 else if (you.species == SP_DEEP_DWARF)
                     set_equip_race(you.inv[i], ISFLAG_DWARVEN);
-                else if (you.species == SP_HILL_ORC)
+                else if (player_genus(GENPC_ORCISH))
                     set_equip_race(you.inv[i], ISFLAG_ORCISH);
             }
         }
@@ -1128,7 +1163,7 @@ static void _give_basic_spells(job_type which_job)
         which_spell = SPELL_STING;
         break;
     case JOB_SUMMONER:
-        which_spell = SPELL_SUMMON_SMALL_MAMMALS;
+        which_spell = SPELL_SUMMON_SMALL_MAMMAL;
         break;
     case JOB_NECROMANCER:
         which_spell = SPELL_PAIN;
@@ -1149,6 +1184,9 @@ static void _give_basic_spells(job_type which_job)
     case JOB_EARTH_ELEMENTALIST:
         which_spell = SPELL_SANDBLAST;
         break;
+    case JOB_SKALD:
+        which_spell = SPELL_INFUSION;
+        break;
     case JOB_TRANSMUTER:
         which_spell = SPELL_BEASTLY_APPENDAGE;
         break;
@@ -1323,9 +1361,6 @@ static void _setup_generic(const newgame_def& ng)
     for (int i = 0; i < ENDOFPACK; ++i)
         if (you.inv[i].defined())
         {
-            // XXX: Why is this here? Elsewhere it's only ever used for runes.
-            you.inv[i].flags |= ISFLAG_BEEN_IN_INV;
-
             // Identify all items in pack.
             set_ident_type(you.inv[i], ID_KNOWN_TYPE);
             set_ident_flags(you.inv[i], ISFLAG_IDENT_MASK);
@@ -1351,7 +1386,6 @@ static void _setup_generic(const newgame_def& ng)
 
         // There's little sense in training these skills in ZotDef
         you.train[SK_STEALTH] = 0;
-        you.train[SK_TRAPS]   = 0;
     }
 
     // If the item in slot 'a' is a throwable weapon like a dagger,
@@ -1390,7 +1424,7 @@ static void _setup_generic(const newgame_def& ng)
 
     // Enable sacrificing for all Nemelex gift types
     for (int i = 0; i < NUM_NEMELEX_GIFT_TYPES; ++i)
-        you.nemelex_sacrificing[i] = true;
+        you.nemelex_sacrificing.set(i);
 
     // Get rid of god companions left from previous games
     init_companions();
