@@ -24,6 +24,7 @@
 #include "externs.h"
 #include "options.h"
 
+#include "art-enum.h"
 #include "artefact.h"
 #include "beam.h"
 #include "chardump.h"
@@ -130,6 +131,11 @@ int check_your_resists(int hurted, beam_type flavour, string source,
                                       you.res_water_drowning(), hurted, true);
         if (!hurted && doEffects)
             mpr("You shrug off the wave.");
+        else if (hurted > original && doEffects)
+        {
+            mpr("The water douses you terribly!");
+            xom_is_stimulated(200);
+        }
         break;
 
     case BEAM_STEAM:
@@ -156,6 +162,17 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         }
         break;
 
+    case BEAM_HELLFIRE:
+        if (you.species == SP_DJINNI)
+        {
+            hurted = 0;
+            if (doEffects)
+                mpr("You resist completely.");
+        }
+        // Inconsistency: no penalty for rF-, unlike monsters.  That's
+        // probably good, and monsters should be changed.
+        break;
+
     case BEAM_COLD:
         hurted = resist_adjust_damage(&you, flavour,
                                       player_res_cold(), hurted, true);
@@ -214,21 +231,11 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         break;
 
     case BEAM_NEG:
-        resist = player_prot_life();
-
-        // TSO's protection.
-        if (you.religion == GOD_SHINING_ONE && you.piety > resist * 50)
-        {
-            int unhurted = min(hurted, (you.piety * hurted) / 150);
-
-            if (unhurted > 0)
-                hurted -= unhurted;
-        }
-        else if (resist > 0)
-            hurted -= (resist * hurted) / 3;
+        hurted = resist_adjust_damage(&you, flavour, player_prot_life(),
+                                      hurted, true);
 
         if (doEffects)
-            drain_exp();
+            drain_exp(true, min(75, 35 + original * 2 / 3));
         break;
 
     case BEAM_ICE:
@@ -298,19 +305,19 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         // For mutation damage, we want to count innate mutations for
         // the demonspawn, but not for other species.
         int mutated = how_mutated(you.species == SP_DEMONSPAWN, true);
-        int multiplier = min(mutated * 5, 100);
+        int multiplier = min(mutated * 3, 60);
         if (you.is_chaotic() || player_is_shapechanged())
-            multiplier = 100; // full damage
+            multiplier = 60; // full damage
         else if (you.is_undead || is_chaotic_god(you.religion))
-            multiplier = max(multiplier, 33);
+            multiplier = max(multiplier, 20);
 
-        hurted = hurted * multiplier / 100;
+        hurted = hurted * multiplier / 60;
 
         if (doEffects)
         {
             if (hurted <= 0)
                 canned_msg(MSG_YOU_RESIST);
-            else if (multiplier > 50)
+            else if (multiplier > 30)
                 mpr("The blast sears you terribly!");
             else
                 mpr("The blast sears you!");
@@ -349,6 +356,27 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         break;
     }
 
+    case BEAM_GHOSTLY_FLAME:
+    {
+        if (you.holiness() == MH_UNDEAD)
+        {
+            if (doEffects)
+            {
+                you.heal(roll_dice(2, 9));
+                mpr("You are bolstered by the flame.");
+            }
+            hurted = 0;
+        }
+        else
+        {
+            hurted = resist_adjust_damage(&you, flavour,
+                                          you.res_negative_energy(),
+                                          hurted, true);
+            if (hurted < original && doEffects)
+                canned_msg(MSG_YOU_PARTIALLY_RESIST);
+        }
+    }
+
     default:
         break;
     }                           // end switch
@@ -359,7 +387,7 @@ int check_your_resists(int hurted, beam_type flavour, string source,
     return hurted;
 }
 
-void splash_with_acid(int acid_strength, bool corrode_items, string hurt_message)
+void splash_with_acid(int acid_strength, int death_source, bool corrode_items, string hurt_message)
 {
     int dam = 0;
     const bool wearing_cloak = player_wearing_slot(EQ_CLOAK);
@@ -380,6 +408,10 @@ void splash_with_acid(int acid_strength, bool corrode_items, string hurt_message
         }
     }
 
+    // Covers head, hands and feet.
+    if (player_equip_unrand(UNRAND_LEAR))
+        dam = !wearing_cloak;
+
     // Without fur, clothed people have dam 0 (+2 later), Sp/Tr/Dr/Og ~1
     // (randomized), Fe 5.  Fur helps only against naked spots.
     const int fur = player_mutation_level(MUT_SHAGGY_FUR);
@@ -398,7 +430,7 @@ void splash_with_acid(int acid_strength, bool corrode_items, string hurt_message
         if (post_res_dam < dam)
             canned_msg(MSG_YOU_RESIST);
 
-        ouch(post_res_dam, NON_MONSTER, KILLED_BY_ACID);
+        ouch(post_res_dam, death_source, KILLED_BY_ACID);
     }
 }
 
@@ -456,7 +488,7 @@ static bool _expose_invent_to_element(beam_type flavour, int strength)
     // Fedhas worshipers are exempt from the food destruction effect
     // of spores.
     if (flavour == BEAM_SPORE
-        && you.religion == GOD_FEDHAS)
+        && you_worship(GOD_FEDHAS))
     {
         simple_god_message(" protects your food from the spores.",
                            GOD_FEDHAS);
@@ -498,7 +530,7 @@ static bool _expose_invent_to_element(beam_type flavour, int strength)
                 continue;
             }
 
-            if (you.religion == GOD_JIYVA && !player_under_penance()
+            if (you_worship(GOD_JIYVA) && !player_under_penance()
                 && x_chance_in_y(you.piety, MAX_PIETY))
             {
                 ++jiyva_block;
@@ -703,14 +735,14 @@ static void _lose_level_abilities()
     }
 }
 
-void lose_level()
+void lose_level(int death_source, const char *aux)
 {
     // Because you.experience is unsigned long, if it's going to be
     // negative, must die straightaway.
     if (you.experience_level == 1)
     {
-        ouch(INSTANT_DEATH, NON_MONSTER, KILLED_BY_DRAINING);
-        // Return in case death was canceled via wizard mode
+        ouch(INSTANT_DEATH, death_source, KILLED_BY_DRAINING, aux);
+        // Return in case death was cancelled via wizard mode
         return;
     }
 
@@ -719,7 +751,7 @@ void lose_level()
     mprf(MSGCH_WARN,
          "You are now level %d!", you.experience_level);
 
-    ouch(4, NON_MONSTER, KILLED_BY_DRAINING);
+    ouch(4, death_source, KILLED_BY_DRAINING, aux);
     dec_mp(1);
 
     calc_hp();
@@ -743,10 +775,10 @@ void lose_level()
 
     // Kill the player if maxhp <= 0.  We can't just move the ouch() call past
     // dec_max_hp() since it would decrease hp twice, so here's another one.
-    ouch(0, NON_MONSTER, KILLED_BY_DRAINING);
+    ouch(0, death_source, KILLED_BY_DRAINING, aux);
 }
 
-bool drain_exp(bool announce_full)
+bool drain_exp(bool announce_full, int power)
 {
     const int protection = player_prot_life();
 
@@ -758,55 +790,20 @@ bool drain_exp(bool announce_full)
         return false;
     }
 
-    if (you.experience == 0)
-    {
-        mpr("You are drained of all life!");
-        ouch(INSTANT_DEATH, NON_MONSTER, KILLED_BY_DRAINING);
-
-        // Return in case death was escaped via wizard mode.
-        return true;
-    }
-
-    if (you.experience_level == 1)
-    {
-        mpr("You feel drained.");
-        you.experience = 0;
-
-        return true;
-    }
-
-    unsigned int total_exp = exp_needed(you.experience_level + 1)
-                                  - exp_needed(you.experience_level);
-    unsigned int exp_drained = (total_exp * (5 + random2(11))) / 100;
-
-    // TSO's protection.
-    if (you.religion == GOD_SHINING_ONE && you.piety > protection * 50)
-    {
-        unsigned int undrained = min(exp_drained,
-                                     (you.piety * exp_drained) / 150);
-
-        if (undrained > 0)
-        {
-            simple_god_message(" protects your life force!");
-            if (undrained > 0)
-                exp_drained -= undrained;
-        }
-    }
-    else if (protection > 0)
+    if (protection > 0)
     {
         canned_msg(MSG_YOU_PARTIALLY_RESIST);
-        exp_drained -= (protection * exp_drained) / 3;
+        power /= (protection * 2);
     }
 
-    if (exp_drained > 0)
+    if (power > 0)
     {
         mpr("You feel drained.");
         xom_is_stimulated(15);
-        you.experience -= exp_drained;
 
-        dprf("You lose %d experience points.", exp_drained);
+        you.attribute[ATTR_XP_DRAIN] += power;
 
-        level_change();
+        dprf("Drained by %d points (%d total)", power, you.attribute[ATTR_XP_DRAIN]);
 
         return true;
     }
@@ -817,7 +814,7 @@ bool drain_exp(bool announce_full)
 static void _xom_checks_damage(kill_method_type death_type,
                                int dam, int death_source)
 {
-    if (you.religion == GOD_XOM)
+    if (you_worship(GOD_XOM))
     {
         if (death_type == KILLED_BY_TARGETTING
             || death_type == KILLED_BY_BOUNCE
@@ -927,7 +924,9 @@ static void _maybe_spawn_jellies(int dam, const char* aux,
 
     // Exclude torment damage.
     const bool torment = aux && strstr(aux, "torment");
-    if (you.religion == GOD_JIYVA && you.piety > 160 && !torment)
+    if (you_worship(GOD_JIYVA)
+        && you.piety >= piety_breakpoint(5)
+        && !torment)
     {
         int how_many = 0;
         if (dam >= you.hp_max * 3 / 4)
@@ -1044,15 +1043,6 @@ static void _wizard_restore_life()
         unrot_hp(9999);
     if (you.hp <= 0)
         set_hp(you.hp_max);
-    for (int i = 0; i < NUM_STATS; ++i)
-    {
-        if (you.stat(static_cast<stat_type>(i)) <= 0)
-        {
-            you.stat_loss[i] = 0;
-            you.stat_zero[i] = 0;
-            you.redraw_stats[i] = true;
-        }
-    }
 }
 #endif
 
@@ -1065,7 +1055,8 @@ void reset_damage_counters()
 
 // death_source should be set to NON_MONSTER for non-monsters. {dlb}
 void ouch(int dam, int death_source, kill_method_type death_type,
-          const char *aux, bool see_source, const char *death_source_name)
+          const char *aux, bool see_source, const char *death_source_name,
+          bool attacker_effects)
 {
     ASSERT(!crawl_state.game_is_arena());
     if (you.duration[DUR_TIME_STEP])
@@ -1074,7 +1065,8 @@ void ouch(int dam, int death_source, kill_method_type death_type,
     if (you.dead) // ... but eligible for revival
         return;
 
-    if (dam != INSTANT_DEATH && !invalid_monster_index(death_source)
+    if (attacker_effects && dam != INSTANT_DEATH
+        && !invalid_monster_index(death_source)
         && menv[death_source].has_ench(ENCH_WRETCHED))
     {
         // An abstract boring simulation of reduced stats/etc due to bad muts
@@ -1101,15 +1093,16 @@ void ouch(int dam, int death_source, kill_method_type death_type,
     }
 
     if (dam != INSTANT_DEATH)
+    {
         if (you.petrified())
             dam /= 2;
         else if (you.petrifying())
             dam = dam * 10 / 15;
-
+    }
     ait_hp_loss hpl(dam, death_type);
     interrupt_activity(AI_HP_LOSS, &hpl);
 
-    if (dam > 0)
+    if (dam > 0 && death_type != KILLED_BY_POISON)
         you.check_awaken(500);
 
     const bool non_death = death_type == KILLED_BY_QUITTING
@@ -1124,11 +1117,26 @@ void ouch(int dam, int death_source, kill_method_type death_type,
 
     if (dam != INSTANT_DEATH)
     {
-        if (you.spirit_shield() && death_type != KILLED_BY_POISON)
+        if (you.duration[DUR_SONG_OF_SHIELDING] && you.magic_points > 0)
+        {
+            if (dam > you.magic_points)
+            {
+                dam = dam - you.magic_points;
+                dec_mp(you.magic_points);
+            }
+            else
+            {
+                dec_mp(dam);
+                dam = 0;
+                return;
+            }
+        }
+        if (you.spirit_shield() && death_type != KILLED_BY_POISON
+            && !(aux && strstr(aux, "flay_damage")))
         {
             // round off fairly (important for taking 1 damage at a time)
             int mp = div_rand_round(dam * you.magic_points,
-                                    you.hp + you.magic_points);
+                                    max(you.hp + you.magic_points, 1));
             // but don't kill the player with round-off errors
             mp = max(mp, dam + 1 - you.hp);
             mp = min(mp, you.magic_points);
@@ -1205,7 +1213,7 @@ void ouch(int dam, int death_source, kill_method_type death_type,
 
         // Xom should only kill his worshippers if they're under penance
         // or Xom is bored.
-        if (you.religion == GOD_XOM && !you.penance[GOD_XOM]
+        if (you_worship(GOD_XOM) && !you.penance[GOD_XOM]
             && you.gift_timeout > 0)
         {
             return;
@@ -1214,7 +1222,7 @@ void ouch(int dam, int death_source, kill_method_type death_type,
         // Also don't kill wizards testing Xom acts.
         if ((crawl_state.repeat_cmd == CMD_WIZARD
                 || crawl_state.prev_cmd == CMD_WIZARD)
-            && you.religion != GOD_XOM)
+            && !you_worship(GOD_XOM))
         {
             return;
         }
@@ -1264,6 +1272,7 @@ void ouch(int dam, int death_source, kill_method_type death_type,
 
             if (crawl_state.test || !yesno("Die?", false, 'n'))
             {
+                mpr("Thought so.");
                 take_note(Note(NOTE_DEATH, you.hp, you.hp_max,
                                 death_desc.c_str()), true);
                 _wizard_restore_life();
@@ -1298,7 +1307,8 @@ void ouch(int dam, int death_source, kill_method_type death_type,
 
         // You wouldn't want to lose this accomplishment to a crash, would you?
         // Especially if you manage to trigger one via lua somehow...
-        save_game(false);
+        if (!crawl_state.disables[DIS_SAVE_CHECKPOINTS])
+            save_game(false);
 
         mprnojoin("You die...");
         xom_death_message((kill_method_type) se.get_death_type());
@@ -1345,11 +1355,10 @@ string morgue_name(string char_name, time_t when_crawl_got_even)
 // Delete save files on game end.
 static void _delete_files()
 {
+    crawl_state.need_save = false;
     you.save->unlink();
     delete you.save;
     you.save = 0;
-    // Attempting to save after this point would crash
-    crawl_state.need_save = false;
 }
 
 void screen_end_game(string text)
