@@ -305,10 +305,16 @@ class colour_bar
 {
     typedef unsigned short color_t;
  public:
+    color_t m_default;
+    color_t m_change_pos;
+    color_t m_change_neg;
+    color_t m_empty;
+
     colour_bar(color_t default_colour,
                color_t change_pos,
                color_t change_neg,
-               color_t empty)
+               color_t empty,
+               bool round = false)
         : m_default(default_colour), m_change_pos(change_pos),
           m_change_neg(change_neg), m_empty(empty),
           m_old_disp(-1),
@@ -323,7 +329,7 @@ class colour_bar
                 && you.num_turns >= m_request_redraw_after);
     }
 
-    void draw(int ox, int oy, int val, int max_val)
+    void draw(int ox, int oy, int val, int max_val, bool temp = false)
     {
         ASSERT(val <= max_val);
         if (max_val <= 0)
@@ -332,6 +338,7 @@ class colour_bar
             return;
         }
 
+        const colour_t temp_colour = temperature_colour(temperature());
         const int width = crawl_view.hudsz.x - (ox - 1);
         const int disp  = width * val / max_val;
         const int old_disp = (m_old_disp < 0) ? disp : m_old_disp;
@@ -347,14 +354,14 @@ class colour_bar
             textcolor(BLACK + m_empty * 16);
 
             if (cx < disp)
-                textcolor(BLACK + m_default * 16);
+                textcolor(BLACK + (temp) ? temp_colour * 16 : m_default * 16);
             else if (old_disp > disp && cx < old_disp)
                 textcolor(BLACK + m_change_neg * 16);
             putwch(' ');
 #else
             if (cx < disp && cx < old_disp)
             {
-                textcolor(m_default);
+                textcolor((temp) ? temp_colour : m_default);
                 putwch('=');
             }
             else if (cx < disp)
@@ -435,15 +442,12 @@ class colour_bar
     }
 
  private:
-    const color_t m_default;
-    const color_t m_change_pos;
-    const color_t m_change_neg;
-    const color_t m_empty;
     int m_old_disp;
     int m_request_redraw_after; // force a redraw at this turn count
 };
 
 static colour_bar HP_Bar(LIGHTGREEN, GREEN, RED, DARKGREY);
+static colour_bar EP_Bar(LIGHTMAGENTA, MAGENTA, BLUE, DARKGREY);
 
 #ifdef USE_TILE_LOCAL
 static colour_bar MP_Bar(BLUE, BLUE, LIGHTBLUE, DARKGREY);
@@ -451,6 +455,9 @@ static colour_bar MP_Bar(BLUE, BLUE, LIGHTBLUE, DARKGREY);
 static colour_bar MP_Bar(LIGHTBLUE, BLUE, MAGENTA, DARKGREY);
 #endif
 
+colour_bar Contam_Bar(DARKGREY, DARKGREY, DARKGREY, DARKGREY);
+colour_bar Temp_Bar(RED, LIGHTRED, LIGHTBLUE, DARKGREY);
+
 // ----------------------------------------------------------------------
 // Status display
 // ----------------------------------------------------------------------
@@ -484,7 +491,9 @@ void update_turn_count()
         return;
     }
 
-    CGOTOXY(19+6, 9 + crawl_state.game_is_zotdef(), GOTO_STAT);
+    const int yhack = crawl_state.game_is_zotdef()
+                    + (you.species == SP_LAVA_ORC);
+    CGOTOXY(19+6, 9 + yhack, GOTO_STAT);
 
     // Show the turn count starting from 1. You can still quit on turn 0.
     textcolor(HUD_VALUE_COLOUR);
@@ -511,8 +520,21 @@ static int _count_digits(int val)
     return 1;
 }
 
+static void _print_stats_temperature(int x, int y)
+{
+
+    cgotoxy(x, y, GOTO_STAT);
+    textcolor(HUD_CAPTION_COLOUR);
+    cprintf("Temperature: ");
+
+    Temp_Bar.draw(19, y, temperature(), TEMP_MAX, true);
+}
+
 static void _print_stats_mp(int x, int y)
 {
+    if (you.species == SP_DJINNI)
+        return;
+
     // Calculate colour
     short mp_colour = HUD_VALUE_COLOUR;
 
@@ -553,9 +575,55 @@ static void _print_stats_mp(int x, int y)
     MP_Bar.draw(19, y, you.magic_points, you.max_magic_points);
 }
 
+static void _print_stats_contam(int x, int y)
+{
+    if (you.species != SP_DJINNI)
+        return;
+
+    const int max_contam = 16000;
+    int contam = min(you.magic_contamination, max_contam);
+
+    // Calculate colour
+    int contam_level = get_contamination_level();
+
+    if (contam_level > 3)
+    {
+        Contam_Bar.m_default = RED;
+        Contam_Bar.m_change_pos = Contam_Bar.m_change_neg = RED;
+    }
+    else if (contam_level > 2)
+    {
+        Contam_Bar.m_default = LIGHTRED;
+        Contam_Bar.m_change_pos = Contam_Bar.m_change_neg = RED;
+    }
+    else if (contam_level > 1)
+    {
+        Contam_Bar.m_default = YELLOW;
+        Contam_Bar.m_change_pos = Contam_Bar.m_change_neg = BROWN;
+    }
+    else
+    {
+#ifdef USE_TILE_LOCAL
+        Contam_Bar.m_default = LIGHTGREY;
+#else
+        Contam_Bar.m_default = DARKGREY;
+#endif
+        Contam_Bar.m_change_pos = Contam_Bar.m_change_neg = DARKGREY;
+    }
+
+#ifdef TOUCH_UI
+    if (tiles.is_using_small_layout())
+        Contam_Bar.vdraw(6, 10, contam, max_contam);
+    else
+#endif
+    Contam_Bar.draw(19, y, contam, max_contam);
+}
+
 static void _print_stats_hp(int x, int y)
 {
-    const int max_max_hp = get_real_hp(true, true);
+    int max_max_hp = get_real_hp(true, true);
+    if (you.species == SP_DJINNI)
+        max_max_hp += get_real_mp(true);
 
     // Calculate colour
     short hp_colour = HUD_VALUE_COLOUR;
@@ -579,7 +647,10 @@ static void _print_stats_hp(int x, int y)
     // Health: xxx/yyy (zzz)
     CGOTOXY(x, y, GOTO_STAT);
     textcolor(HUD_CAPTION_COLOUR);
-    CPRINTF(max_max_hp != you.hp_max ? "HP: " : "Health: ");
+    if (you.species == SP_DJINNI)
+        CPRINTF(max_max_hp != you.hp_max ? "EP: " : "Essence: ");
+    else
+        CPRINTF(max_max_hp != you.hp_max ? "HP: " : "Health: ");
     textcolor(hp_colour);
     CPRINTF("%d", you.hp);
     if (!boosted)
@@ -596,15 +667,23 @@ static void _print_stats_hp(int x, int y)
 
 #ifdef USE_TILE_LOCAL
     if (tiles.is_using_small_layout())
-        HP_Bar.vdraw(2, 10, you.hp, you.hp_max);
+    {
+        if (you.species != SP_DJINNI)
+            HP_Bar.vdraw(2, 10, you.hp, you.hp_max);
+        else
+            EP_Bar.vdraw(2, 10, you.hp, you.hp_max);
+    }
     else
 #endif
-    HP_Bar.draw(19, y, you.hp, you.hp_max);
+    if (you.species != SP_DJINNI)
+        HP_Bar.draw(19, y, you.hp, you.hp_max);
+    else
+        EP_Bar.draw(19, y, you.hp, you.hp_max);
 }
 
 static short _get_stat_colour(stat_type stat)
 {
-    if (you.stat_zero[stat] > 0)
+    if (you.stat_zero[stat])
         return LIGHTRED;
 
     // Check the stat_colour option for warning thresholds.
@@ -646,7 +725,7 @@ static void _print_stats_ac(int x, int y)
 {
     // AC:
     CGOTOXY(x+4, y, GOTO_STAT);
-    if (you.duration[DUR_ICY_ARMOUR] || you.duration[DUR_STONESKIN])
+    if (you.duration[DUR_ICY_ARMOUR] || player_stoneskin())
         textcolor(LIGHTBLUE);
     else if (you.duration[DUR_ICEMAIL_DEPLETED] > ICEMAIL_TIME / ICEMAIL_MAX)
         textcolor(RED);
@@ -677,7 +756,9 @@ static void _print_stats_ac(int x, int y)
 static void _print_stats_ev(int x, int y)
 {
     CGOTOXY(x+4, y, GOTO_STAT);
-    textcolor(you.duration[DUR_PHASE_SHIFT] || you.duration[DUR_AGILITY]
+    textcolor(you.duration[DUR_PETRIFYING] || you.duration[DUR_GRASPING_ROOTS]
+              || you.cannot_move() ? RED :
+              you.duration[DUR_PHASE_SHIFT] || you.duration[DUR_AGILITY]
               ? LIGHTBLUE : HUD_VALUE_COLOUR);
     CPRINTF("%2d ", player_evasion());
 }
@@ -761,7 +842,7 @@ static void _print_stats_qv(int y)
     string text;
 
     int q = you.m_quiver->get_fire_item();
-    ASSERT(q >= -1 && q < ENDOFPACK);
+    ASSERT_RANGE(q, -1, ENDOFPACK);
     if (q != -1 && !fire_warn_if_impossible(true))
     {
         const item_def& quiver = you.inv[q];
@@ -857,6 +938,7 @@ static void _get_status_lights(vector<status_light>& out)
         DUR_TELEPORT,
         DUR_DEATHS_DOOR,
         DUR_QUAD_DAMAGE,
+        DUR_ANTIMAGIC,
         STATUS_MISSILES,
         STATUS_REGENERATION,
         DUR_BERSERK,
@@ -879,7 +961,6 @@ static void _get_status_lights(vector<status_light>& out)
         DUR_MISLED,
         DUR_POISONING,
         STATUS_SICK,
-        DUR_NAUSEA,
         STATUS_ROT,
         STATUS_NET,
         STATUS_CONTAMINATION,
@@ -896,6 +977,7 @@ static void _get_status_lights(vector<status_light>& out)
         DUR_MIRROR_DAMAGE,
         DUR_SCRYING,
         STATUS_CLINGING,
+        STATUS_HOVER,
         DUR_TORNADO,
         DUR_LIQUEFYING,
         DUR_HEROISM,
@@ -917,13 +999,28 @@ static void _get_status_lights(vector<status_light>& out)
         DUR_SENTINEL_MARK,
         STATUS_RECALL,
         STATUS_LIQUEFIED,
+        DUR_WATER_HOLD,
+        DUR_FLAYED,
+        DUR_RETCHING,
+        DUR_WEAK,
+        DUR_DIMENSION_ANCHOR,
+        STATUS_BEOGH,
+        DUR_SPIRIT_HOWL,
+        DUR_INFUSION,
+        DUR_SONG_OF_SLAYING,
+        DUR_SONG_OF_SHIELDING,
+        STATUS_DRAINED,
+        DUR_TOXIC_RADIANCE,
+        STATUS_RAY,
+        DUR_RECITE,
+        DUR_GRASPING_ROOTS,
+        DUR_FIRE_VULN,
     };
 
     status_info inf;
     for (unsigned i = 0; i < ARRAYSZ(statuses); ++i)
     {
-        fill_status_info(statuses[i], &inf);
-        if (!inf.light_text.empty())
+        if (fill_status_info(statuses[i], &inf) && !inf.light_text.empty())
         {
             status_light sl(inf.light_colour, inf.light_text);
             out.push_back(sl);
@@ -1086,10 +1183,10 @@ static void _redraw_title(const string &your_name, const string &job_name)
     CGOTOXY(1, 2, GOTO_STAT);
     string species = species_name(you.species);
     NOWRAP_EOL_CPRINTF("%s", species.c_str());
-    if (you.religion != GOD_NO_GOD)
+    if (!you_worship(GOD_NO_GOD))
     {
         string god = " of ";
-        god += you.religion == GOD_JIYVA ? god_name_jiyva(true)
+        god += you_worship(GOD_JIYVA) ? god_name_jiyva(true)
                                          : god_name(you.religion);
         NOWRAP_EOL_CPRINTF("%s", god.c_str());
 
@@ -1125,6 +1222,11 @@ static void _redraw_title(const string &your_name, const string &job_name)
 
 void print_stats(void)
 {
+    int temp = (you.species == SP_LAVA_ORC) ? 1 : 0;
+    int temp_pos = 5;
+    int ac_pos = temp_pos + temp;
+    int ev_pos = temp_pos + temp + 1;
+
     cursor_control coff(false);
     textcolor(LIGHTGREY);
 
@@ -1136,6 +1238,8 @@ void print_stats(void)
         you.redraw_hit_points = true;
     if (MP_Bar.wants_redraw())
         you.redraw_magic_points = true;
+    if (Temp_Bar.wants_redraw() && you.species == SP_LAVA_ORC)
+        you.redraw_temperature = true;
 
 #ifdef USE_TILE_LOCAL
     bool has_changed = _need_stats_printed();
@@ -1148,17 +1252,19 @@ void print_stats(void)
     }
     if (you.redraw_hit_points)   { you.redraw_hit_points = false;   _print_stats_hp (1, 3); }
     if (you.redraw_magic_points) { you.redraw_magic_points = false; _print_stats_mp (1, 4); }
-    if (you.redraw_armour_class) { you.redraw_armour_class = false; _print_stats_ac (1, 5); }
-    if (you.redraw_evasion)      { you.redraw_evasion = false;      _print_stats_ev (1, 6); }
+    _print_stats_contam(1, 4);
+    if (you.redraw_temperature)  { you.redraw_temperature = false;  _print_stats_temperature (1, temp_pos); }
+    if (you.redraw_armour_class) { you.redraw_armour_class = false; _print_stats_ac (1, ac_pos); }
+    if (you.redraw_evasion)      { you.redraw_evasion = false;      _print_stats_ev (1, ev_pos); }
 
     for (int i = 0; i < NUM_STATS; ++i)
         if (you.redraw_stats[i])
-            _print_stat(static_cast<stat_type>(i), 19, 5 + i);
+            _print_stat(static_cast<stat_type>(i), 19, 5 + i + temp);
     you.redraw_stats.init(false);
 
     if (you.redraw_experience)
     {
-        CGOTOXY(1,8, GOTO_STAT);
+        CGOTOXY(1, 8 + temp, GOTO_STAT);
         textcolor(Options.status_caption_colour);
         CPRINTF("XL: ");
         textcolor(HUD_VALUE_COLOUR);
@@ -1174,7 +1280,7 @@ void print_stats(void)
         }
         if (crawl_state.game_is_zotdef())
         {
-            CGOTOXY(1, 9, GOTO_STAT);
+            CGOTOXY(1, 9 + temp, GOTO_STAT);
             textcolor(Options.status_caption_colour);
             CPRINTF("ZP: ");
             textcolor(HUD_VALUE_COLOUR);
@@ -1183,7 +1289,7 @@ void print_stats(void)
         you.redraw_experience = false;
     }
 
-    int yhack = crawl_state.game_is_zotdef();
+    int yhack = crawl_state.game_is_zotdef() + temp;
 
     // If Options.show_gold_turns, line 9 is Gold and Turns
 #ifdef USE_TILE_LOCAL
@@ -1259,7 +1365,10 @@ static string _level_description_string_hud()
 
 void print_stats_level()
 {
-    CGOTOXY(19, 8, GOTO_STAT);
+    int ypos = 8;
+    if (you.species == SP_LAVA_ORC)
+        ypos++;
+    cgotoxy(19, ypos, GOTO_STAT);
     textcolor(HUD_CAPTION_COLOUR);
     CPRINTF("Place: ");
 
@@ -1278,19 +1387,33 @@ void draw_border(void)
 
     textcolor(Options.status_caption_colour);
 
-    //CGOTOXY(1, 3, GOTO_STAT); CPRINTF("Hp:");
-    CGOTOXY(1, 4, GOTO_STAT); CPRINTF("Magic:");
-    CGOTOXY(1, 5, GOTO_STAT); CPRINTF("AC:");
-    CGOTOXY(1, 6, GOTO_STAT); CPRINTF("EV:");
-    CGOTOXY(1, 7, GOTO_STAT); CPRINTF("SH:");
+    int temp = (you.species == SP_LAVA_ORC) ? 1 : 0;
+//    int hp_pos = 3;
+    int mp_pos = 4;
+    int ac_pos = 5 + temp;
+    int ev_pos = 6 + temp;
+    int sh_pos = 7 + temp;
+    int str_pos = ac_pos;
+    int int_pos = ev_pos;
+    int dex_pos = sh_pos;
 
-    CGOTOXY(19, 5, GOTO_STAT); CPRINTF("Str:");
-    CGOTOXY(19, 6, GOTO_STAT); CPRINTF("Int:");
-    CGOTOXY(19, 7, GOTO_STAT); CPRINTF("Dex:");
+    //CGOTOXY(1, 3, GOTO_STAT); CPRINTF("Hp:");
+    CGOTOXY(1, mp_pos, GOTO_STAT);
+    if (you.species == SP_DJINNI)
+        CPRINTF("Contam:");
+    else
+        CPRINTF("Magic:");
+    CGOTOXY(1, ac_pos, GOTO_STAT); CPRINTF("AC:");
+    CGOTOXY(1, ev_pos, GOTO_STAT); CPRINTF("EV:");
+    CGOTOXY(1, sh_pos, GOTO_STAT); CPRINTF("SH:");
+
+    CGOTOXY(19, str_pos, GOTO_STAT); CPRINTF("Str:");
+    CGOTOXY(19, int_pos, GOTO_STAT); CPRINTF("Int:");
+    CGOTOXY(19, dex_pos, GOTO_STAT); CPRINTF("Dex:");
 
     if (Options.show_gold_turns)
     {
-        int yhack = crawl_state.game_is_zotdef();
+        int yhack = crawl_state.game_is_zotdef() + temp;
         CGOTOXY(1, 9 + yhack, GOTO_STAT); CPRINTF("Gold:");
         CGOTOXY(19, 9 + yhack, GOTO_STAT);
         CPRINTF(Options.show_game_turns ? "Time:" : "Turn:");
@@ -1306,31 +1429,19 @@ static string _get_monster_name(const monster_info& mi, int count, bool fullname
 {
     string desc = "";
 
-    bool adj = false;
-    if (mi.attitude == ATT_FRIENDLY)
-    {
-        desc += "friendly ";
-        adj = true;
-    }
-    else if (mi.attitude != ATT_HOSTILE)
-    {
-        desc += "neutral ";
-        adj = true;
-    }
+    const char * const adj = mi.attitude == ATT_FRIENDLY ? "friendly"
+                           : mi.attitude == ATT_HOSTILE  ? nullptr
+                                                         : "neutral";
 
     string monpane_desc;
     int col;
-    mi.to_string(count, monpane_desc, col, fullname);
+    mi.to_string(count, monpane_desc, col, fullname, adj);
 
     if (count == 1)
     {
         if (!mi.is(MB_NAME_THE))
-        {
-            desc = ((!adj && is_vowel(monpane_desc[0])) ? "an "
-                                                        : "a ")
-                   + desc;
-        }
-        else if (adj)
+            desc = (is_vowel(monpane_desc[0]) ? "an " : "a ") + desc;
+        else if (adj || !mi.is(MB_NAME_UNQUALIFIED))
             desc = "the " + desc;
     }
 
@@ -1642,7 +1753,8 @@ static string _status_mut_abilities(int sw);
 
 // helper for print_overview_screen
 static void _print_overview_screen_equip(column_composer& cols,
-                                         vector<char>& equip_chars)
+                                         vector<char>& equip_chars,
+                                         int sw)
 {
     const int e_order[] =
     {
@@ -1652,7 +1764,9 @@ static void _print_overview_screen_equip(column_composer& cols,
         EQ_RING_FIVE, EQ_RING_SIX, EQ_RING_SEVEN, EQ_RING_EIGHT,
     };
 
-    char buf[100];
+    sw = min(max(sw, 79), 640);
+
+    char buf[641];
     for (int i = 0; i < NUM_EQUIP; i++)
     {
         int eqslot = e_order[i];
@@ -1701,7 +1815,7 @@ static void _print_overview_screen_equip(column_composer& cols,
                      equip_char,
                      colname,
                      melded ? "melded " : "",
-                     chop_string(item.name(DESC_PLAIN, true), 42, false).c_str(),
+                     chop_string(item.name(DESC_PLAIN, true), sw - 38, false).c_str(),
                      colname);
             equip_chars.push_back(equip_char);
         }
@@ -1816,7 +1930,7 @@ static string _wiz_god_powers()
 static string _god_powers(bool simple)
 {
     string godpowers = simple ? "" : god_name(you.religion) ;
-    if (you.religion == GOD_XOM)
+    if (you_worship(GOD_XOM))
     {
         if (!you.gift_timeout)
             godpowers += simple ? "- BORED" : " - BORED";
@@ -1825,7 +1939,7 @@ static string _god_powers(bool simple)
         return (simple ? godpowers
                        : colour_string(godpowers, god_colour(you.religion)));
     }
-    else if (you.religion != GOD_NO_GOD)
+    else if (!you_worship(GOD_NO_GOD))
     {
         if (player_under_penance())
             return (simple ? "*" : colour_string("*" + godpowers, RED));
@@ -1833,7 +1947,7 @@ static string _god_powers(bool simple)
         {
             // piety rankings
             int prank = piety_rank() - 1;
-            if (prank < 0 || you.religion == GOD_XOM)
+            if (prank < 0 || you_worship(GOD_XOM))
                 prank = 0;
 
             // Careful about overflow. We erase some of the god's name
@@ -1860,7 +1974,7 @@ static vector<formatted_string> _get_overview_stats()
                                 || you.berserk();
     const bool boosted_mp  = you.duration[DUR_DIVINE_VIGOUR];
     const bool boosted_ac  = you.duration[DUR_ICY_ARMOUR]
-                                || you.duration[DUR_STONESKIN];
+                                || player_stoneskin();
     const bool boosted_ev  = you.duration[DUR_PHASE_SHIFT]
                                 || you.duration[DUR_AGILITY];
     const bool boosted_str = you.duration[DUR_DIVINE_STAMINA]
@@ -2016,6 +2130,15 @@ static vector<formatted_string> _get_overview_stats()
     else
         lives[0] = 0;
 
+    char temperature[20];
+    if (you.species == SP_LAVA_ORC)
+    {
+        snprintf(temperature, sizeof(temperature), "Temperature: %f",
+                 you.temperature);
+    }
+    else
+        temperature[0] = 0;
+
     snprintf(buf, sizeof buf,
              "XL: %d%s\n"
              "God: %s\n"
@@ -2035,8 +2158,7 @@ static vector<formatted_string> _get_overview_stats()
 }
 
 static vector<formatted_string> _get_overview_resistances(
-    vector<char> &equip_chars,
-    bool calc_unid = false)
+    vector<char> &equip_chars, bool calc_unid, int sw)
 {
     char buf[1000];
 
@@ -2050,8 +2172,7 @@ static vector<formatted_string> _get_overview_resistances(
     const int relec = player_res_electricity(calc_unid);
     const int rsust = player_sust_abil(calc_unid);
     const int rmuta = (you.rmut_from_item(calc_unid)
-                       || player_mutation_level(MUT_MUTATION_RESISTANCE) == 3
-                       || you.religion == GOD_ZIN && you.piety >= 150);
+                       || player_mutation_level(MUT_MUTATION_RESISTANCE) == 3);
     const int rrott = you.res_rotting();
 
     snprintf(buf, sizeof buf,
@@ -2138,17 +2259,13 @@ static vector<formatted_string> _get_overview_resistances(
     }
     cols.add_formatted(1, buf, false);
 
-    int rctel = player_control_teleport(calc_unid);
-    rctel = allow_control_teleport(true) ? rctel : -1;
     const int rflyi = you.airborne();
     snprintf(buf, sizeof buf,
-             "%sCtrl.Telep.: %s\n"
              "%sFlight     : %s\n",
-             _determine_colour_string(rctel, 1), _itosym1(rctel),
              _determine_colour_string(rflyi, 1), _itosym1(rflyi));
     cols.add_formatted(1, buf, false);
 
-    _print_overview_screen_equip(cols, equip_chars);
+    _print_overview_screen_equip(cols, equip_chars, sw);
 
     return cols.formatted_lines();
 }
@@ -2158,15 +2275,9 @@ static char _get_overview_screen_results()
 {
     bool calc_unid = false;
     formatted_scroller overview;
+
     overview.set_flags(MF_SINGLESELECT | MF_ALWAYS_SHOW_MORE | MF_NOWRAP);
-    overview.set_more(formatted_string::parse_string(
-#ifdef USE_TILE_LOCAL
-                        "<cyan>[ +/L-click : Page down.   - : Page up."
-                        "           Esc/R-click exits.]"));
-#else
-                        "<cyan>[ + : Page down.   - : Page up."
-                        "                           Esc exits.]"));
-#endif
+    overview.set_more();
     overview.set_tag("resists");
 
     overview.add_text(_overview_screen_title(get_number_of_cols()));
@@ -2178,11 +2289,10 @@ static char _get_overview_screen_results()
         overview.add_text(" ");
     }
 
-
     {
         vector<char> equip_chars;
         vector<formatted_string> blines =
-            _get_overview_resistances(equip_chars, calc_unid);
+            _get_overview_resistances(equip_chars, calc_unid, get_number_of_cols());
 
         for (unsigned int i = 0; i < blines.size(); ++i)
         {
@@ -2214,7 +2324,7 @@ string dump_overview_screen(bool full_id)
     text += "\n";
 
     vector<char> equip_chars;
-    blines = _get_overview_resistances(equip_chars, full_id);
+    blines = _get_overview_resistances(equip_chars, full_id, 640);
     for (unsigned int i = 0; i < blines.size(); ++i)
     {
         text += blines[i];
@@ -2317,6 +2427,7 @@ static string _status_mut_abilities(int sw)
         STATUS_BEHELD,
         DUR_LIQUID_FLAMES,
         DUR_ICY_ARMOUR,
+        DUR_ANTIMAGIC,
         STATUS_MISSILES,
         DUR_JELLY_PRAYER,
         STATUS_REGENERATION,
@@ -2345,7 +2456,6 @@ static string _status_mut_abilities(int sw)
         DUR_FIRE_SHIELD,
         DUR_POISONING,
         STATUS_SICK,
-        DUR_NAUSEA,
         STATUS_CONTAMINATION,
         STATUS_ROT,
         DUR_CONFUSING_TOUCH,
@@ -2371,13 +2481,22 @@ static string _status_mut_abilities(int sw)
         STATUS_SUPPRESSED,
         STATUS_RECALL,
         STATUS_LIQUEFIED,
+        DUR_FLAYED,
+        DUR_RETCHING,
+        DUR_WEAK,
+        DUR_DIMENSION_ANCHOR,
+        DUR_SPIRIT_HOWL,
+        STATUS_DRAINED,
+        DUR_TOXIC_RADIANCE,
+        DUR_RECITE,
+        DUR_GRASPING_ROOTS,
+        DUR_FIRE_VULN,
     };
 
     status_info inf;
     for (unsigned i = 0; i < ARRAYSZ(statuses); ++i)
     {
-        fill_status_info(statuses[i], &inf);
-        if (!inf.short_text.empty())
+        if (fill_status_info(statuses[i], &inf) && !inf.short_text.empty())
             status.push_back(inf.short_text);
     }
 
@@ -2531,6 +2650,16 @@ static string _status_mut_abilities(int sw)
         mutations.push_back(_dragon_abil("breathe steam"));
         break;
 
+    case SP_GARGOYLE:
+        AC_change += 2 + you.experience_level * 2 / 5
+                       + max(0, you.experience_level - 7) * 2 / 5;
+        break;
+
+    case SP_DJINNI:
+        mutations.push_back("fire immunity");
+        mutations.push_back("cold vulnerability");
+        break;
+
     default:
         break;
     }                           //end switch - innate abilities
@@ -2605,23 +2734,24 @@ static string _status_mut_abilities(int sw)
                 AC_change += level;
                 break;
             case MUT_STRONG:
-                Str_change += level;
+                Str_change += level * 2;
                 break;
             case MUT_CLEVER:
-                Int_change += level;
+                Int_change += level * 2;
                 break;
             case MUT_AGILE:
-                Dex_change += level;
+                Dex_change += level * 2;
                 break;
             case MUT_WEAK:
-                Str_change -= level;
+                Str_change -= level * 2;
                 break;
             case MUT_DOPEY:
-                Int_change -= level;
+                Int_change -= level * 2;
                 break;
             case MUT_CLUMSY:
-                Dex_change -= level;
+                Dex_change -= level * 2;
                 break;
+#if TAG_MAJOR_VERSION == 34
             case MUT_STRONG_STIFF:
                 Str_change += level;
                 Dex_change -= level;
@@ -2630,6 +2760,7 @@ static string _status_mut_abilities(int sw)
                 Str_change -= level;
                 Dex_change += level;
                 break;
+#endif
             case MUT_FRAIL:
                 snprintf(info, INFO_SIZE, "-%d%% hp", level*10);
                 current = info;
