@@ -30,11 +30,10 @@ public:
     PlaceInfo();
 
     bool is_global() const;
-    void make_global();
 
     void assert_validity() const;
 
-    const std::string short_name() const;
+    const string short_name() const;
 
     const PlaceInfo &operator += (const PlaceInfo &other);
     const PlaceInfo &operator -= (const PlaceInfo &other);
