@@ -24,6 +24,7 @@
 #include "libutil.h"
 #include "misc.h"
 #include "monster.h"
+#include "spl-damage.h"
 #include "state.h"
 #include "terrain.h"
 #include "transform.h"
@@ -71,6 +72,7 @@ void player::moveto(const coord_def &c, bool clear_net)
     set_position(c);
 
     clear_far_constrictions();
+    end_searing_ray();
 }
 
 bool player::move_to_pos(const coord_def &c, bool clear_net)
@@ -102,7 +104,7 @@ void player::set_position(const coord_def &c)
     {
         reset_prev_move();
 
-        if (you.duration[DUR_QUAD_DAMAGE])
+        if (duration[DUR_QUAD_DAMAGE])
             invalidate_agrid(true);
 
         if (player_has_orb())
@@ -156,7 +158,7 @@ bool player::is_habitable_feat(dungeon_feature_type actual_grid) const
     if (!can_pass_through_feat(actual_grid))
         return false;
 
-    if (airborne())
+    if (airborne() || species == SP_DJINNI)
         return true;
 
     if (actual_grid == DNGN_LAVA
@@ -226,9 +228,9 @@ brand_type player::damage_brand(int)
     brand_type ret = SPWPN_NORMAL;
     const int wpn = equip[EQ_WEAPON];
 
-    if (wpn != -1 && !you.melded[EQ_WEAPON])
+    if (wpn != -1 && !melded[EQ_WEAPON])
     {
-        if (!is_range_weapon(inv[wpn]) && !you.suppressed())
+        if (!is_range_weapon(inv[wpn]) && !suppressed())
             ret = get_weapon_brand(inv[wpn]);
     }
     else if (duration[DUR_CONFUSING_TOUCH])
@@ -270,7 +272,7 @@ brand_type player::damage_brand(int)
 // eq must be in [EQ_WEAPON, EQ_RING_EIGHT], or bad things will happen.
 item_def *player::slot_item(equipment_type eq, bool include_melded) const
 {
-    ASSERT(eq >= EQ_WEAPON && eq < NUM_EQUIP);
+    ASSERT_RANGE(eq, EQ_WEAPON, NUM_EQUIP);
 
     const int item = equip[eq];
     if (item == -1 || !include_melded && melded[eq])
@@ -281,7 +283,7 @@ item_def *player::slot_item(equipment_type eq, bool include_melded) const
 // Returns the item in the player's weapon slot.
 item_def *player::weapon(int /* which_attack */) const
 {
-    if (you.melded[EQ_WEAPON])
+    if (melded[EQ_WEAPON])
         return NULL;
 
     return slot_item(EQ_WEAPON, false);
@@ -344,7 +346,7 @@ bool player::could_wield(const item_def &item, bool ignore_brand,
 }
 
 // Returns the shield the player is wearing, or NULL if none.
-item_def *player::shield()
+item_def *player::shield() const
 {
     return slot_item(EQ_SHIELD, false);
 }
@@ -417,9 +419,9 @@ string player::hand_name(bool plural, bool *can_plural) const
     {
         if (species == SP_FELID)
             str = "paw";
-        else if (you.has_usable_claws())
+        else if (has_usable_claws())
             str = "claw";
-        else if (you.has_usable_tentacles())
+        else if (has_usable_tentacles())
             str = "tentacle";
     }
 
@@ -454,9 +456,9 @@ string player::foot_name(bool plural, bool *can_plural) const
     {
         if (player_mutation_level(MUT_HOOVES) >= 3)
             str = "hoof";
-        else if (you.has_usable_talons())
+        else if (has_usable_talons())
             str = "talon";
-        else if (you.has_usable_tentacles())
+        else if (has_usable_tentacles())
         {
             str         = "tentacles";
             *can_plural = false;
@@ -466,6 +468,8 @@ string player::foot_name(bool plural, bool *can_plural) const
             str         = "underbelly";
             *can_plural = false;
         }
+        else if (species == SP_FELID)
+            str = "paw";
         else if (fishtail)
         {
             str         = "tail";
@@ -594,13 +598,19 @@ void player::attacking(actor *other)
 {
     ASSERT(!crawl_state.game_is_arena());
 
-    if (other && other->is_monster())
+    if (!other)
+        return;
+
+    if (other->is_monster())
     {
         const monster* mon = other->as_monster();
         if (!mon->friendly() && !mon->neutral())
             pet_target = mon->mindex();
     }
 
+    if (mons_is_firewood((monster*) other))
+        return;
+
     const int chance = pow(3, player_mutation_level(MUT_BERSERK) - 1);
     if (player_mutation_level(MUT_BERSERK) && x_chance_in_y(chance, 100))
         go_berserk(false);
@@ -659,13 +669,11 @@ bool player::can_go_berserk(bool intentional, bool potion, bool quiet) const
         return false;
     }
 
-    if (!you.can_bleed(false))
+    if (is_lifeless_undead())
     {
-        // XXX: This message assumes that you're undead.
         if (verbose)
             mpr("You cannot raise a blood rage in your lifeless body.");
 
-        // or else you won't notice -- no message here
         return false;
     }
 
@@ -673,23 +681,23 @@ bool player::can_go_berserk(bool intentional, bool potion, bool quiet) const
     // trigger when the player attempts to activate berserk,
     // auto-iding at that point, but also killing the berserk and
     // wasting a turn.
-    if (you.stasis(false))
+    if (stasis(false))
     {
         if (verbose)
         {
-            const item_def *amulet = you.slot_item(EQ_AMULET, false);
+            const item_def *amulet = slot_item(EQ_AMULET, false);
             mprf("You cannot go berserk with %s on.",
                  amulet? amulet->name(DESC_YOUR).c_str() : "your amulet");
         }
         return false;
     }
 
-    if (!intentional && !potion && you.clarity())
+    if (!intentional && !potion && clarity())
     {
         if (verbose)
         {
             mpr("You're too calm and focused to rage.");
-            if (!you.clarity(false))
+            if (!clarity(false))
                 maybe_id_clarity();
         }
 
@@ -697,7 +705,7 @@ bool player::can_go_berserk(bool intentional, bool potion, bool quiet) const
     }
 
     ASSERT(HUNGER_STARVING - 100 + BERSERK_NUTRITION < 2066);
-    if (you.hunger <= 2066)
+    if (hunger <= 2066)
     {
         if (verbose)
             mpr("You're too hungry to go berserk.");
@@ -709,25 +717,25 @@ bool player::can_go_berserk(bool intentional, bool potion, bool quiet) const
 
 bool player::berserk() const
 {
-    return (duration[DUR_BERSERK]);
+    return duration[DUR_BERSERK];
 }
 
 bool player::can_cling_to_walls() const
 {
-    return you.form == TRAN_SPIDER;
+    return form == TRAN_SPIDER;
 }
 
 bool player::is_web_immune() const
 {
     // Spider form
-    return can_cling_to_walls();
+    return form == TRAN_SPIDER;
 }
 
 bool player::shove(const char* feat_name)
 {
     for (distance_iterator di(pos()); di; ++di)
         if (in_bounds(*di) && !actor_at(*di) && !is_feat_dangerous(grd(*di))
-            && you.can_pass_through_feat(grd(*di)))
+            && can_pass_through_feat(grd(*di)))
         {
             moveto(*di);
             if (*feat_name)
@@ -740,5 +748,5 @@ bool player::shove(const char* feat_name)
 
 int player::constriction_damage() const
 {
-    return roll_dice(2, div_rand_round(you.strength(), 5));
+    return roll_dice(2, div_rand_round(strength(), 5));
 }
